/*
** 2000-05-29
**
** The author disclaims copyright to this source code.  In place of
** a legal notice, here is a blessing:
**
**    May you do good and not evil.
**    May you find forgiveness for yourself and forgive others.
**    May you share freely, never taking more than you give.
**
*************************************************************************
** Driver template for the LEMON parser generator.
**
** The "lemon" program processes an LALR(1) input grammar file, then uses
** this template to construct a parser.  The "lemon" program inserts text
** at each "%%" line.  Also, any "P-a-r-s-e" identifer prefix (without the
** interstitial "-" characters) contained in this template is changed into
** the value of the %name directive from the grammar.  Otherwise, the content
** of this template is copied straight through into the generate parser
** source file.
**
** The following is the concatenation of all %include directives from the
** input grammar file:
*/
#include <stdio.h>
#include <string.h>
#include <assert.h>

#ifdef _MSC_VER
#define CDECL __cdecl
#else
#define CDECL
#endif

/************ Begin %include sections from the grammar ************************/
#line 40 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"

// Allocates a new AST node off the parse state's arena.
#define NEW_AST_NODE(type,name,tok) \
	ZCC_##type *name = static_cast<ZCC_##type *>(stat->InitNode(sizeof(ZCC_##type), AST_##type)); \
	SetNodeLine(name, tok)

static void SetNodeLine(ZCC_TreeNode *name, ZCCToken &tok)
{
	name->SourceLoc = tok.SourceLoc;
}

static void SetNodeLine(ZCC_TreeNode *name, ZCC_TreeNode *node)
{
	if (name == nullptr || node == nullptr)
	{
		I_Error("Fatal parse error");
	}
	name->SourceLoc = node->SourceLoc;
}

static void SetNodeLine(ZCC_TreeNode *name, int line)
{
	name->SourceLoc = line;
}

// If a is non-null, appends b to a. Otherwise, sets a to b.
#define SAFE_APPEND(a,b) \
	if (a == NULL) a = b; else AppendTreeNodeSibling(a, b);

#define UNARY_EXPR(X,T) NEW_AST_NODE(ExprUnary, expr1, X); expr1->Operation = T; expr1->Operand = X; expr1->Type = NULL
#define BINARY_EXPR(X,Y,T) NEW_AST_NODE(ExprBinary, expr2, X); expr2->Operation = T; expr2->Type = NULL; expr2->Left = X; expr2->Right = Y

#define NEW_INTCONST_NODE(name,type,val,tok) \
	NEW_AST_NODE(ExprConstant, name, tok); \
	name->Operation = PEX_ConstValue; \
	name->Type = type; \
	name->IntVal = val

	struct ClassFlagsBlock {
		VM_UWORD Flags;
		ZCC_Identifier *Replaces;
		VersionInfo Version;
	};

	struct StateOpts {
		ZCC_Expression *Offset;
		ZCC_ExprConstant *Lights;
		bool Bright;
		bool Fast;
		bool Slow;
		bool NoDelay;
		bool CanRaise;

		void Zero() {
			Offset = nullptr;
			Lights = nullptr;
			Bright = false;
			Fast = false;
			Slow = false;
			NoDelay = false;
			CanRaise = false;
		}
	};

	struct VarOrFun
	{
		ZCC_VarName *VarNames;
		ZCC_FuncParamDecl *FuncParams;
		ZCC_CompoundStmt *FuncBody;
		ENamedName FuncName;
		int FuncFlags;
		int SourceLoc;
	};
#line 111 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
/**************** End of %include directives **********************************/
/* These constants specify the various numeric values for terminal symbols
** in a format understandable to "makeheaders".  This section is blank unless
** "lemon" is run with the "-m" command-line option.
***************** Begin makeheaders token definitions *************************/
/**************** End makeheaders token definitions ***************************/

/* The next section is a series of control #defines.
** various aspects of the generated parser.
**    YYCODETYPE         is the data type used to store the integer codes
**                       that represent terminal and non-terminal symbols.
**                       "unsigned char" is used if there are fewer than
**                       256 symbols.  Larger types otherwise.
**    YYNOCODE           is a number of type YYCODETYPE that is not used for
**                       any terminal or nonterminal symbol.
**    YYFALLBACK         If defined, this indicates that one or more tokens
**                       (also known as: "terminal symbols") have fall-back
**                       values which should be used if the original symbol
**                       would not parse.  This permits keywords to sometimes
**                       be used as identifiers, for example.
**    YYACTIONTYPE       is the data type used for "action codes" - numbers
**                       that indicate what to do in response to the next
**                       token.
**    ZCCParseTOKENTYPE     is the data type used for minor type for terminal
**                       symbols.  Background: A "minor type" is a semantic
**                       value associated with a terminal or non-terminal
**                       symbols.  For example, for an "ID" terminal symbol,
**                       the minor type might be the name of the identifier.
**                       Each non-terminal can have a different minor type.
**                       Terminal symbols all have the same minor type, though.
**                       This macros defines the minor type for terminal 
**                       symbols.
**    YYMINORTYPE        is the data type used for all minor types.
**                       This is typically a union of many types, one of
**                       which is ZCCParseTOKENTYPE.  The entry in the union
**                       for terminal symbols is called "yy0".
**    YYSTACKDEPTH       is the maximum depth of the parser's stack.  If
**                       zero the stack is dynamically sized using realloc()
**    ZCCParseARG_SDECL     A static variable declaration for the %extra_argument
**    ZCCParseARG_PDECL     A parameter declaration for the %extra_argument
**    ZCCParseARG_STORE     Code to store %extra_argument into yypParser
**    ZCCParseARG_FETCH     Code to extract %extra_argument from yypParser
**    YYERRORSYMBOL      is the code number of the error symbol.  If not
**                       defined, then do no error processing.
**    YYNSTATE           the combined number of states.
**    YYNRULE            the number of rules in the grammar
**    YY_MAX_SHIFT       Maximum value for shift actions
**    YY_MIN_SHIFTREDUCE Minimum value for shift-reduce actions
**    YY_MAX_SHIFTREDUCE Maximum value for shift-reduce actions
**    YY_MIN_REDUCE      Maximum value for reduce actions
**    YY_ERROR_ACTION    The yy_action[] code for syntax error
**    YY_ACCEPT_ACTION   The yy_action[] code for accept
**    YY_NO_ACTION       The yy_action[] code for no-op
*/
#ifndef INTERFACE
# define INTERFACE 1
#endif
/************* Begin control #defines *****************************************/
#define YYCODETYPE unsigned char
#define YYNOCODE 254
#define YYACTIONTYPE unsigned short int
#define ZCCParseTOKENTYPE  ZCCToken 
typedef union {
  int yyinit;
  ZCCParseTOKENTYPE yy0;
  ZCC_ExprFuncCall * yy31;
  ZCC_Default * yy45;
  ZCC_FuncParamDecl * yy49;
  ZCC_FlagStmt * yy60;
  StateOpts yy72;
  ZCC_StaticArrayStatement * yy82;
  ZCC_States * yy86;
  ZCC_BasicType * yy116;
  ZCC_ExpressionStmt * yy124;
  ZCC_Type * yy130;
  ZCC_VarInit * yy161;
  ZCC_LocalVarStmt * yy164;
  ZCC_Expression * yy184;
  ZCC_StatePart * yy188;
  ZCC_CompoundStmt * yy215;
  ZCC_Enum * yy245;
  ZCC_AssignStmt * yy263;
  ClassFlagsBlock yy271;
  ZCC_Class * yy272;
  ZCC_ExprConstant * yy273;
  ZCC_Property * yy291;
  ZCC_CaseStmt * yy304;
  ZCC_Identifier * yy311;
  ZCC_IfStmt * yy312;
  ZCC_Statement * yy367;
  VarOrFun yy372;
  ZCC_TreeNode * yy392;
  ZCC_VarName * yy393;
  ZCC_Declarator * yy401;
  ZCC_ConstantDef * yy419;
  ZCC_PropertyStmt * yy447;
  ZCC_FuncParm * yy470;
  ZCC_DeclFlags * yy491;
  ZCC_Struct * yy505;
  int yy507;
} YYMINORTYPE;
#ifndef YYSTACKDEPTH
#define YYSTACKDEPTH 0
#endif
#define ZCCParseARG_SDECL  ZCCParseState *stat ;
#define ZCCParseARG_PDECL , ZCCParseState *stat 
#define ZCCParseARG_FETCH  ZCCParseState *stat  = yypParser->stat 
#define ZCCParseARG_STORE yypParser->stat  = stat 
#define YYERRORSYMBOL 153
#define YYERRSYMDT yy507
#define YYFALLBACK 1
#define YYNSTATE             362
#define YYNRULE              343
#define YY_MAX_SHIFT         361
#define YY_MIN_SHIFTREDUCE   602
#define YY_MAX_SHIFTREDUCE   944
#define YY_MIN_REDUCE        945
#define YY_MAX_REDUCE        1287
#define YY_ERROR_ACTION      1288
#define YY_ACCEPT_ACTION     1289
#define YY_NO_ACTION         1290
/************* End control #defines *******************************************/

/* Define the yytestcase() macro to be a no-op if is not already defined
** otherwise.
**
** Applications can choose to define yytestcase() in the %include section
** to a macro that can assist in verifying code coverage.  For production
** code the yytestcase() macro should be turned off.  But it is useful
** for testing.
*/
#ifndef yytestcase
# define yytestcase(X)
#endif


/* Next are the tables used to determine what action to take based on the
** current state and lookahead token.  These tables are used to implement
** functions that take a state number and lookahead value and return an
** action integer.  
**
** Suppose the action integer is N.  Then the action is determined as
** follows
**
**   0 <= N <= YY_MAX_SHIFT             Shift N.  That is, push the lookahead
**                                      token onto the stack and goto state N.
**
**   N between YY_MIN_SHIFTREDUCE       Shift to an arbitrary state then
**     and YY_MAX_SHIFTREDUCE           reduce by rule N-YY_MIN_SHIFTREDUCE.
**
**   N between YY_MIN_REDUCE            Reduce by rule N-YY_MIN_REDUCE
**     and YY_MAX_REDUCE
**
**   N == YY_ERROR_ACTION               A syntax error has occurred.
**
**   N == YY_ACCEPT_ACTION              The parser accepts its input.
**
**   N == YY_NO_ACTION                  No such action.  Denotes unused
**                                      slots in the yy_action[] table.
**
** The action table is constructed as a single large table named yy_action[].
** Given state S and lookahead X, the action is computed as either:
**
**    (A)   N = yy_action[ yy_shift_ofst[S] + X ]
**    (B)   N = yy_default[S]
**
** The (A) formula is preferred.  The B formula is used instead if:
**    (1)  The yy_shift_ofst[S]+X value is out of range, or
**    (2)  yy_lookahead[yy_shift_ofst[S]+X] is not equal to X, or
**    (3)  yy_shift_ofst[S] equal YY_SHIFT_USE_DFLT.
** (Implementation note: YY_SHIFT_USE_DFLT is chosen so that
** YY_SHIFT_USE_DFLT+X will be out of range for all possible lookaheads X.
** Hence only tests (1) and (2) need to be evaluated.)
**
** The formulas above are for computing the action when the lookahead is
** a terminal symbol.  If the lookahead is a non-terminal (as occurs after
** a reduce action) then the yy_reduce_ofst[] array is used in place of
** the yy_shift_ofst[] array and YY_REDUCE_USE_DFLT is used in place of
** YY_SHIFT_USE_DFLT.
**
** The following are the tables generated in this section:
**
**  yy_action[]        A single table containing all actions.
**  yy_lookahead[]     A table containing the lookahead for each entry in
**                     yy_action.  Used to detect hash collisions.
**  yy_shift_ofst[]    For each state, the offset into yy_action for
**                     shifting terminals.
**  yy_reduce_ofst[]   For each state, the offset into yy_action for
**                     shifting non-terminals after a reduce.
**  yy_default[]       Default action for each state.
**
*********** Begin parsing tables **********************************************/
#define YY_ACTTAB_COUNT (2648)
static const YYACTIONTYPE yy_action[] = {
 /*     0 */   109,  108,  117,  604,  606,  607,  608,  609,  610,  106,
 /*    10 */   107,  153,   29,   32,  132,  336,  868,   41,  286,   36,
 /*    20 */   152,  320,  674,  675,  676,  162,  633,  227,  859,  786,
 /*    30 */   295,  733,    2,  882,  635,  634,  638,   93,   92,   91,
 /*    40 */    89,   88,   90,  994, 1127,  632,  795,  351,  339,   57,
 /*    50 */   639,  636,  637,  640,  719,  720,  721,  722,  723,  724,
 /*    60 */   725,  726,  727,  728,  729,  730,  731,  732,  734,  335,
 /*    70 */   328,  116,  329,  325,   72,   73,   74,   87,   86,   85,
 /*    80 */    95,   98,   93,   92,   91,   89,   88,   90,  753,  785,
 /*    90 */   189,  348,  234,  234,   57,  357,   14,  105,  104,  103,
 /*   100 */   102,  861,  862,  863,  864,  865,  866,  867,   39,  306,
 /*   110 */   305,   28,    9,  301,  891,  892,  297,  783,  296,   47,
 /*   120 */    95,   98,   93,   92,   91,   89,   88,   90,  230,  712,
 /*   130 */   321,  109,  108,    2,   57,  289,  289,   38,  661,  626,
 /*   140 */   106,  107,  153,   29,   32,  735,  708,  868,  627,  628,
 /*   150 */   660,  152,  320,   21,  226,  189,  796,  230,  230,  859,
 /*   160 */    40,  295,  733,    2,  883,  705,  746,  735,  747,  121,
 /*   170 */   322,  112,  322,  155,  337,  155, 1262,  795,  605,  745,
 /*   180 */   351,  339,  761, 1289,   22,  719,  720,  721,  722,  723,
 /*   190 */   724,  725,  726,  727,  728,  729,  730,  731,  732,  734,
 /*   200 */   335,  328,  227,  329,  325,   36,   73,   74,   87,   86,
 /*   210 */    85,   95,   98,   93,   92,   91,   89,   88,   90,  719,
 /*   220 */   720,  721,  722,  723,  724,   57,  687,  163,  105,  104,
 /*   230 */   103,  102,  861,  862,  863,  864,  865,  866,  867,   39,
 /*   240 */   306,  305,   28,    9,  301,  891,  892,  297,  115,  296,
 /*   250 */    47,  754,  754,  130,  130,  228,  619,  620,  621,  622,
 /*   260 */   134,  256,  109,  108,  292,  629,  111,   36,  787,   38,
 /*   270 */   140,  106,  107,  153,   29,   32,  149,  149,  868,   27,
 /*   280 */   264,    1,  152,  320,  360,  353,  684,  351,  339,  143,
 /*   290 */   859,  272,  295,  733,    2,  153,  689,  690,  691,  692,
 /*   300 */   693,  274,  273,  695,  152,  736,  358,  356,  795,   36,
 /*   310 */   100,  709,  713,  714,  682,  733,  719,  720,  721,  722,
 /*   320 */   723,  724,  725,  726,  727,  728,  729,  730,  731,  732,
 /*   330 */   734,  335,  328,  754,  329,  325,  186,  348,  719,  720,
 /*   340 */   721,  722,  723,  724,  725,  726,  727,  728,  729,  730,
 /*   350 */   731,  732,  734,  335,  328,  683,  329,  325,   39,  105,
 /*   360 */   104,  103,  102,  861,  862,  863,  864,  865,  866,  867,
 /*   370 */    39,  306,  305,   28,    9,  301,  891,  892,  297,  153,
 /*   380 */   296,   47,  804,  805,  346,   17,   54,   90,  152,  736,
 /*   390 */   127,  765,  777,  778,   57,  281,  735,  293,  293,  733,
 /*   400 */   226,  186,  796,  666,  779,  150,  150,  673,  896,  752,
 /*   410 */   232,  678,  679,  680,  681,  129,  238,  746,  735,  747,
 /*   420 */   288,  266,  719,  720,  721,  722,  723,  724,  725,  726,
 /*   430 */   727,  728,  729,  730,  731,  732,  734,  335,  334,  302,
 /*   440 */   329,  325,  750,  891,  892,  677,  265,  110,  145,  284,
 /*   450 */   766,  767,  768,  769,  770,  771,  772,  774,  775,  776,
 /*   460 */   780,   69,   66,   65,   64,   68,   67,   63,   62,   60,
 /*   470 */    59,   58,   61,   56,  613,   70,   71,   77,   76,   75,
 /*   480 */    83,   82,   81,   80,   79,   78,   84,   72,   73,   74,
 /*   490 */    87,   86,   85,   95,   98,   93,   92,   91,   89,   88,
 /*   500 */    90,  717,   52,   52,   44,  755,  146,   57,  881,   52,
 /*   510 */    96,  285,  264,  253,  133,  630,  360,  353,  348,  351,
 /*   520 */   339,  143,  798,  668,   69,   66,   65,   64,   68,   67,
 /*   530 */    63,   62,   60,   59,   58,   61,   56,  625,   70,   71,
 /*   540 */    77,   76,   75,   83,   82,   81,   80,   79,   78,   84,
 /*   550 */    72,   73,   74,   87,   86,   85,   95,   98,   93,   92,
 /*   560 */    91,   89,   88,   90,  257,  294,  109,  108,  166,  160,
 /*   570 */    57,   15,   52,   97,  261,  106,  107,  153,   29,  345,
 /*   580 */   262,  226,  813,  796,  161,  799,  152,  320,  909,  126,
 /*   590 */    39,  348,  735,  128,  859,  168,  348,  733,  874,  703,
 /*   600 */    74,   87,   86,   85,   95,   98,   93,   92,   91,   89,
 /*   610 */    88,   90,  795,  746,  735,  747,  121,  269,   57,  749,
 /*   620 */   719,  720,  721,  722,  723,  724,  725,  726,  727,  728,
 /*   630 */   729,  730,  731,  732,  734,  335,  328,   52,  329,  325,
 /*   640 */    87,   86,   85,   95,   98,   93,   92,   91,   89,   88,
 /*   650 */    90,  189,  348,  910,  226,  812,  796,   57,  696,  226,
 /*   660 */   168,  796,  231,  105,  104,  103,  102,  861,  862,  863,
 /*   670 */   864,  865,  866,  867,   69,   66,   65,   64,   68,   67,
 /*   680 */    63,   62,   60,   59,   58,   61,   56,  144,   70,   71,
 /*   690 */    77,   76,   75,   83,   82,   81,   80,   79,   78,   84,
 /*   700 */    72,   73,   74,   87,   86,   85,   95,   98,   93,   92,
 /*   710 */    91,   89,   88,   90,  164,  226,  189,  796,  855,  855,
 /*   720 */    57,  333,   69,   66,   65,   64,   68,   67,   63,   62,
 /*   730 */    60,   59,   58,   61,   56,  694,   70,   71,   77,   76,
 /*   740 */    75,   83,   82,   81,   80,   79,   78,   84,   72,   73,
 /*   750 */    74,   87,   86,   85,   95,   98,   93,   92,   91,   89,
 /*   760 */    88,   90,  311,  669,  233,  762,  118,  759,   57,  332,
 /*   770 */   316,   42,  912,   69,   66,   65,   64,   68,   67,   63,
 /*   780 */    62,   60,   59,   58,   61,   56,  902,   70,   71,   77,
 /*   790 */    76,   75,   83,   82,   81,   80,   79,   78,   84,   72,
 /*   800 */    73,   74,   87,   86,   85,   95,   98,   93,   92,   91,
 /*   810 */    89,   88,   90,  782,  114,  244,  151,  330,  743,   57,
 /*   820 */   662,   69,   66,   65,   64,   68,   67,   63,   62,   60,
 /*   830 */    59,   58,   61,   56,  154,   70,   71,   77,   76,   75,
 /*   840 */    83,   82,   81,   80,   79,   78,   84,   72,   73,   74,
 /*   850 */    87,   86,   85,   95,   98,   93,   92,   91,   89,   88,
 /*   860 */    90,  922,  915,  658,  125,  338,  644,   57,  859,   69,
 /*   870 */    66,   65,   64,   68,   67,   63,   62,   60,   59,   58,
 /*   880 */    61,   56,    5,   70,   71,   77,   76,   75,   83,   82,
 /*   890 */    81,   80,   79,   78,   84,   72,   73,   74,   87,   86,
 /*   900 */    85,   95,   98,   93,   92,   91,   89,   88,   90,  361,
 /*   910 */   224,  267,   12,  225,  268,   57,   13,   69,   66,   65,
 /*   920 */    64,   68,   67,   63,   62,   60,   59,   58,   61,   56,
 /*   930 */     6,   70,   71,   77,   76,   75,   83,   82,   81,   80,
 /*   940 */    79,   78,   84,   72,   73,   74,   87,   86,   85,   95,
 /*   950 */    98,   93,   92,   91,   89,   88,   90,  275,  227,  624,
 /*   960 */   254,  135,  255,   57,  614,   69,   66,   65,   64,   68,
 /*   970 */    67,   63,   62,   60,   59,   58,   61,   56,  889,   70,
 /*   980 */    71,   77,   76,   75,   83,   82,   81,   80,   79,   78,
 /*   990 */    84,   72,   73,   74,   87,   86,   85,   95,   98,   93,
 /*  1000 */    92,   91,   89,   88,   90,  259,  712,   37,  138,  139,
 /*  1010 */   700,   57,  923,   69,   66,   65,   64,   68,   67,   63,
 /*  1020 */    62,   60,   59,   58,   61,   56,   10,   70,   71,   77,
 /*  1030 */    76,   75,   83,   82,   81,   80,   79,   78,   84,   72,
 /*  1040 */    73,   74,   87,   86,   85,   95,   98,   93,   92,   91,
 /*  1050 */    89,   88,   90,  186,  348,  299,  187,  348,  701,   57,
 /*  1060 */   699,   69,   66,   65,   64,   68,   67,   63,   62,   60,
 /*  1070 */    59,   58,   61,   56,   55,   70,   71,   77,   76,   75,
 /*  1080 */    83,   82,   81,   80,   79,   78,   84,   72,   73,   74,
 /*  1090 */    87,   86,   85,   95,   98,   93,   92,   91,   89,   88,
 /*  1100 */    90,  323,  187,  348,   30,  182,  348,   57,  698,  697,
 /*  1110 */   142,   43,  123,  650,  276,  277,    8,  226,  186,  796,
 /*  1120 */   226,  187,  796,   52,  802,  897,   69,   66,   65,   64,
 /*  1130 */    68,   67,   63,   62,   60,   59,   58,   61,   56,  307,
 /*  1140 */    70,   71,   77,   76,   75,   83,   82,   81,   80,   79,
 /*  1150 */    78,   84,   72,   73,   74,   87,   86,   85,   95,   98,
 /*  1160 */    93,   92,   91,   89,   88,   90,  226,  187,  796,  226,
 /*  1170 */   182,  796,   57,  764,   69,   66,   65,   64,   68,   67,
 /*  1180 */    63,   62,   60,   59,   58,   61,   56,  797,   70,   71,
 /*  1190 */    77,   76,   75,   83,   82,   81,   80,   79,   78,   84,
 /*  1200 */    72,   73,   74,   87,   86,   85,   95,   98,   93,   92,
 /*  1210 */    91,   89,   88,   90,  279,  280,  763,  282,  670,  283,
 /*  1220 */    57,  756,  657,   45,   69,   66,   65,   64,   68,   67,
 /*  1230 */    63,   62,   60,   59,   58,   61,   56,  348,   70,   71,
 /*  1240 */    77,   76,   75,   83,   82,   81,   80,   79,   78,   84,
 /*  1250 */    72,   73,   74,   87,   86,   85,   95,   98,   93,   92,
 /*  1260 */    91,   89,   88,   90,  287,  119,   30,  911,   31,   56,
 /*  1270 */    57,   70,   71,   77,   76,   75,   83,   82,   81,   80,
 /*  1280 */    79,   78,   84,   72,   73,   74,   87,   86,   85,   95,
 /*  1290 */    98,   93,   92,   91,   89,   88,   90,  153,  189,  348,
 /*  1300 */   226,  811,  796,   57,  652,  654,  152,  736,  348,  147,
 /*  1310 */    46,  903,  180,  348,  655,  656,   48,  733,   84,   72,
 /*  1320 */    73,   74,   87,   86,   85,   95,   98,   93,   92,   91,
 /*  1330 */    89,   88,   90,  352,  101,  101,  246,  263,   49,   57,
 /*  1340 */   719,  720,  721,  722,  723,  724,  725,  726,  727,  728,
 /*  1350 */   729,  730,  731,  732,  734,  335,  328,   21,  329,  325,
 /*  1360 */    20,   27,  226,  189,  796,  246,  246,  348,    7,  801,
 /*  1370 */    52,  226,  810,  796,  291,   14,  226,  180,  796,   33,
 /*  1380 */   791,  792,  793,  649,  646,  647,  312,  278,   11,   50,
 /*  1390 */   185,  348,   18,  710,  713,  714,  648,   71,   77,   76,
 /*  1400 */    75,   83,   82,   81,   80,   79,   78,   84,   72,   73,
 /*  1410 */    74,   87,   86,   85,   95,   98,   93,   92,   91,   89,
 /*  1420 */    88,   90,  735,  141,  348,   21,  189,  348,   57,  945,
 /*  1430 */   226,  809,  796,  235,   51,  874,  735,  800,   34,  186,
 /*  1440 */   348,  879,  878,  746,  735,  747,  121,  735,  308,  324,
 /*  1450 */   877,  875,  884,  310,  226,  185,  796,  746,  735,  747,
 /*  1460 */   121,  309,  735,  326,  247,  876,  313,   35,  746,  735,
 /*  1470 */   747,  242,  314,  315,  270,  873,    3,  913, 1079,  872,
 /*  1480 */   159,  260,  258,  746,  735,  747,  120,  226,  808,  796,
 /*  1490 */   226,  189,  796,  247,  247,  148,  742,  353,  871,  351,
 /*  1500 */   339,   23,  751,  226,  186,  796,   24,   25,  870,  885,
 /*  1510 */   869,  319,  885,  885,  885,  318,  317,  303,  741,  245,
 /*  1520 */   298,   77,   76,   75,   83,   82,   81,   80,   79,   78,
 /*  1530 */    84,   72,   73,   74,   87,   86,   85,   95,   98,   93,
 /*  1540 */    92,   91,   89,   88,   90,  185,  348,   26,  331,  136,
 /*  1550 */   137,   57,  243,  169,  348,  739,  738,  170,  348,   53,
 /*  1560 */   185,  348,  109,  108,  737,  711,  156,  113,  186,  348,
 /*  1570 */   625,  106,  107,  227,   29,  735,  157,   16,  718,  340,
 /*  1580 */   875,  341,  706,  794,   57,  342,  185,  348,  229,  343,
 /*  1590 */   859,  735,   94,  803,   99,  350,  746,  735,  747,  121,
 /*  1600 */   933,  860,  327,  239,  165,    4, 1013,  354,  795,  226,
 /*  1610 */   185,  796,  746,  735,  747,  120,  348,  226,  169,  796,
 /*  1620 */   348,  226,  170,  796,  226,  185,  796,  185,  348,  236,
 /*  1630 */   355,  158,  226,  186,  796, 1012,  641,  870,  885,  869,
 /*  1640 */   319,  885,  885,  885,  318,  317,  303,  122,  359,  298,
 /*  1650 */   226,  185,  796,  947,  947,  136,  137,  947,  304,  105,
 /*  1660 */   104,  103,  102,  861,  862,  863,  864,  865,  866,  867,
 /*  1670 */   237,  711,  947,  947,  186,  348,  625,  947,  947,  226,
 /*  1680 */   807,  796,  947,  226,  806,  796,  875,  947,  707,  947,
 /*  1690 */   947,  226,  185,  796,  947,  947,  304,  735,  947,  185,
 /*  1700 */   348,  947,  124,  348,  947,  181,  348,  947,  947,  271,
 /*  1710 */   947,  947,  186,  348,  947,  947,  947,  947,  746,  735,
 /*  1720 */   747,  120,  947,  947,  875,  947,  947,  947,  947,  947,
 /*  1730 */   185,  348,  947,  183,  348,  735,  947,  947,  226,  186,
 /*  1740 */   796,  947,  240,  870,  886,  869,  319,  886,  886,  886,
 /*  1750 */   318,  317,  303,  947,  947,  298,  746,  735,  747,  120,
 /*  1760 */   171,  348,  947,  226,  185,  796,  226,  124,  796,  226,
 /*  1770 */   181,  796,  947,  241,  947,  947,  226,  186,  796,  947,
 /*  1780 */   947,  870,  886,  869,  319,  886,  886,  886,  318,  317,
 /*  1790 */   303,  304,  947,  298,  226,  185,  796,  226,  183,  796,
 /*  1800 */   947,  947,  947,  947,  947,  947,  947,  186,  348,  947,
 /*  1810 */   947,  947,  947,  947,  947,  947,  947,  947,  947,  875,
 /*  1820 */   947,  947,  947,  947,  226,  171,  796,  947,  947,  304,
 /*  1830 */   735,  172,  348,  947,  173,  348,  947,  174,  348,  947,
 /*  1840 */   175,  348,  947,  947,  947,  186,  348,  947,  947,  947,
 /*  1850 */   947,  746,  735,  747,  120,  947,  947,  875,  947,  947,
 /*  1860 */   947,  947,  947,  947,  947,  947,  184,  348,  735,  188,
 /*  1870 */   348,  226,  186,  796,  947,  947,  870,  901,  869,  319,
 /*  1880 */   901,  901,  901,  318,  317,  303,  947,  947,  298,  746,
 /*  1890 */   735,  747,  120,  947,  947,  226,  172,  796,  226,  173,
 /*  1900 */   796,  226,  174,  796,  226,  175,  796,  947,  947,  226,
 /*  1910 */   186,  796,  304,  947,  870,  900,  869,  319,  900,  900,
 /*  1920 */   900,  318,  317,  303,  947,  947,  298,  947,  186,  348,
 /*  1930 */   226,  184,  796,  226,  188,  796,  947,  947,  947,  947,
 /*  1940 */   875,  947,  947,  947,  947,  947,  176,  348,  947,  947,
 /*  1950 */   947,  735,  203,  348,  947,  177,  348,  947,  947,  947,
 /*  1960 */   947,  852,  348,  947,  190,  348,  947,  191,  348,  947,
 /*  1970 */   947,  947,  746,  735,  747,  120,  947,  192,  348,  947,
 /*  1980 */   947,  947,  947,  947,  947,  947,  947,  947,  947,  193,
 /*  1990 */   348,  947,  226,  186,  796,  947,  947,  870,  899,  869,
 /*  2000 */   319,  899,  899,  899,  318,  317,  303,  304,  947,  298,
 /*  2010 */   226,  176,  796,  947,  947,  947,  226,  203,  796,  226,
 /*  2020 */   177,  796,  947,  186,  348,  226,  852,  796,  226,  190,
 /*  2030 */   796,  226,  191,  796,  947,  875,  947,  947,  947,  947,
 /*  2040 */   947,  226,  192,  796,  947,  304,  735,  194,  348,  947,
 /*  2050 */   195,  348,  947,  226,  193,  796,  947,  947,  196,  348,
 /*  2060 */   947,  186,  348,  947,  947,  947,  947,  746,  735,  747,
 /*  2070 */   120,  947,  947,  875,  947,  947,  947,  947,  947,  947,
 /*  2080 */   947,  947,  197,  348,  735,  198,  348,  226,  186,  796,
 /*  2090 */   947,  947,  870,  890,  869,  319,  890,  890,  890,  318,
 /*  2100 */   317,  303,  947,  947,  298,  746,  735,  747,  120,  947,
 /*  2110 */   654,  226,  194,  796,  226,  195,  796,  947,  947,  655,
 /*  2120 */   656,  947,  226,  196,  796,  226,  186,  796,  304,  947,
 /*  2130 */   870,  131,  869,  319,  131,  131,  131,  318,  317,  303,
 /*  2140 */   653,  947,  298,  947,  186,  348,  226,  197,  796,  226,
 /*  2150 */   198,  796,  947,  947,  947,  947,  875,  947,  947,  947,
 /*  2160 */   947,  947,  199,  348,  947,  109,  108,  735,  947,  947,
 /*  2170 */   947,  947,  947,  947,  106,  107,  947,   29,  947,  947,
 /*  2180 */    14,  880,  947,  947,  947,  947,  794,  947,  746,  735,
 /*  2190 */   747,  120,  947,  859,  200,  348,  947,  947,  947,  947,
 /*  2200 */   947,  947,  947,  947,  947,  947,  947,  947,  226,  186,
 /*  2210 */   796,  795,  947,  870,  888,  869,  319,  888,  888,  888,
 /*  2220 */   318,  317,  303,  201,  348,  298,  226,  199,  796,   83,
 /*  2230 */    82,   81,   80,   79,   78,   84,   72,   73,   74,   87,
 /*  2240 */    86,   85,   95,   98,   93,   92,   91,   89,   88,   90,
 /*  2250 */   947,  947,  947,  947,  947,  947,   57,  947,  226,  200,
 /*  2260 */   796,  947,  105,  104,  103,  102,  861,  862,  863,  864,
 /*  2270 */   865,  866,  867,  109,  108,  204,  348,  947,  947,  947,
 /*  2280 */   947,  947,  106,  107,  947,   29,  947,  226,  201,  796,
 /*  2290 */   109,  108,  947,  344,  794,  205,  348,  947,  947,  106,
 /*  2300 */   107,  859,   29,  109,  108,  947,  947,  947,  947,  947,
 /*  2310 */   947,  794,  106,  107,  947,   29,  109,  108,  859,  795,
 /*  2320 */   216,  348,   19,  947,  349,  106,  107,  947,   29,  947,
 /*  2330 */   947,  859,  947,  947,  947,  947,  795,  794,  947,  226,
 /*  2340 */   204,  796,  947,  947,  859,  947,  947,  947,  947,  795,
 /*  2350 */   947,  947,  947,  947,  947,  947,  947,  947,  947,  226,
 /*  2360 */   205,  796,  795,  217,  348,  947,  947,  947,  947,  947,
 /*  2370 */   105,  104,  103,  102,  861,  862,  863,  864,  865,  866,
 /*  2380 */   867,  218,  348,  947,  226,  216,  796,  105,  104,  103,
 /*  2390 */   102,  861,  862,  863,  864,  865,  866,  867,  206,  348,
 /*  2400 */   105,  104,  103,  102,  861,  862,  863,  864,  865,  866,
 /*  2410 */   867,  186,  348,  105,  104,  103,  102,  861,  862,  863,
 /*  2420 */   864,  865,  866,  867,  947,  947,  947,  226,  217,  796,
 /*  2430 */   207,  348,  947,  947,  735,  208,  348,  947,  209,  348,
 /*  2440 */   947,  210,  348,  947,  947,  226,  218,  796,  947,  947,
 /*  2450 */   947,  947,  947,  211,  348,  746,  735,  747,  120,  212,
 /*  2460 */   348,  947,  226,  206,  796,  213,  348,  947,  947,  214,
 /*  2470 */   348,  947,  215,  348,  947,  226,  186,  796,  947,  947,
 /*  2480 */   947,  219,  348,  896,  947,  220,  348,  947,  893,  947,
 /*  2490 */   300,  290,  221,  348,  226,  207,  796,  947,  947,  226,
 /*  2500 */   208,  796,  226,  209,  796,  226,  210,  796,  947,  248,
 /*  2510 */   348,  947,  947,  947,  249,  348,  947,  226,  211,  796,
 /*  2520 */   947,  947,  947,  226,  212,  796,  947,  947,  947,  226,
 /*  2530 */   213,  796,  947,  226,  214,  796,  226,  215,  796,  947,
 /*  2540 */   347,  348,  947,  250,  348,  226,  219,  796,  947,  226,
 /*  2550 */   220,  796,  251,  348,  947,  947,  226,  221,  796,  252,
 /*  2560 */   348,  947,  202,  348,  947,  223,  348,  947,  178,  348,
 /*  2570 */   947,  167,  348,  226,  248,  796,  222,  348,  226,  249,
 /*  2580 */   796,  179,  348,  947,  947,  947,  947,  947,  947,  947,
 /*  2590 */   947,  947,  947,  947,  947,  947,  947,  947,  947,  947,
 /*  2600 */   947,  947,  947,  947,  226,  347,  796,  226,  250,  796,
 /*  2610 */   947,  947,  947,  947,  947,  947,  226,  251,  796,  947,
 /*  2620 */   947,  947,  947,  226,  252,  796,  226,  202,  796,  226,
 /*  2630 */   223,  796,  226,  178,  796,  226,  167,  796,  947,  947,
 /*  2640 */   226,  222,  796,  947,  947,  226,  179,  796,
};
static const YYCODETYPE yy_lookahead[] = {
 /*     0 */    33,   34,   54,  160,  161,  162,  163,  164,  165,   42,
 /*    10 */    43,   44,   45,   46,  171,   54,   49,   34,  153,   46,
 /*    20 */    53,   54,  194,  195,  196,  197,  154,   44,   61,  126,
 /*    30 */    63,   64,   65,   66,  162,  163,  164,   35,   36,   37,
 /*    40 */    38,   39,   40,   66,   62,  173,   79,   70,   71,   47,
 /*    50 */   178,  179,  180,  181,   87,   88,   89,   90,   91,   92,
 /*    60 */    93,   94,   95,   96,   97,   98,   99,  100,  101,  102,
 /*    70 */   103,   54,  105,  106,   27,   28,   29,   30,   31,   32,
 /*    80 */    33,   34,   35,   36,   37,   38,   39,   40,  223,  107,
 /*    90 */   169,  170,  227,  228,   47,   54,  224,  130,  131,  132,
 /*   100 */   133,  134,  135,  136,  137,  138,  139,  140,  141,  142,
 /*   110 */   143,  144,  145,  146,  147,  148,  149,   49,  151,  152,
 /*   120 */    33,   34,   35,   36,   37,   38,   39,   40,  207,   49,
 /*   130 */   225,   33,   34,   65,   47,  230,  231,  232,  153,   54,
 /*   140 */    42,   43,   44,   45,   46,  192,   66,   49,   63,   64,
 /*   150 */   192,   53,   54,   50,  233,  234,  235,  236,  237,   61,
 /*   160 */     1,   63,   64,   65,   66,   62,  213,  214,  215,  216,
 /*   170 */   217,  218,  219,  188,  189,  190,   66,   79,  153,   21,
 /*   180 */    70,   71,  229,  158,  159,   87,   88,   89,   90,   91,
 /*   190 */    92,   93,   94,   95,   96,   97,   98,   99,  100,  101,
 /*   200 */   102,  103,   44,  105,  106,   46,   28,   29,   30,   31,
 /*   210 */    32,   33,   34,   35,   36,   37,   38,   39,   40,   87,
 /*   220 */    88,   89,   90,   91,   92,   47,  199,  200,  130,  131,
 /*   230 */   132,  133,  134,  135,  136,  137,  138,  139,  140,  141,
 /*   240 */   142,  143,  144,  145,  146,  147,  148,  149,  202,  151,
 /*   250 */   152,  156,  157,  221,  222,  153,   55,   56,   57,   58,
 /*   260 */    59,   60,   33,   34,    1,   48,   45,   46,  231,  232,
 /*   270 */    54,   42,   43,   44,   45,   46,  221,  222,   49,  177,
 /*   280 */    63,   65,   53,   54,   67,   68,  198,   70,   71,   72,
 /*   290 */    61,   50,   63,   64,   65,   44,   80,   81,   82,   83,
 /*   300 */    84,   85,   86,   62,   53,   54,  185,  186,   79,   46,
 /*   310 */   208,  209,  210,  211,  198,   64,   87,   88,   89,   90,
 /*   320 */    91,   92,   93,   94,   95,   96,   97,   98,   99,  100,
 /*   330 */   101,  102,  103,  238,  105,  106,  169,  170,   87,   88,
 /*   340 */    89,   90,   91,   92,   93,   94,   95,   96,   97,   98,
 /*   350 */    99,  100,  101,  102,  103,  198,  105,  106,  141,  130,
 /*   360 */   131,  132,  133,  134,  135,  136,  137,  138,  139,  140,
 /*   370 */   141,  142,  143,  144,  145,  146,  147,  148,  149,   44,
 /*   380 */   151,  152,   42,   43,   44,   45,   46,   40,   53,   54,
 /*   390 */   177,   56,   57,   58,   47,   60,  192,  251,  252,   64,
 /*   400 */   233,  234,  235,   66,   69,  221,  222,  153,  241,  222,
 /*   410 */    73,   74,   75,   76,   77,   78,  249,  213,  214,  215,
 /*   420 */   216,   54,   87,   88,   89,   90,   91,   92,   93,   94,
 /*   430 */    95,   96,   97,   98,   99,  100,  101,  102,  103,  247,
 /*   440 */   105,  106,  107,  147,  148,   14,   79,  193,  113,  114,
 /*   450 */   115,  116,  117,  118,  119,  120,  121,  122,  123,  124,
 /*   460 */   125,    1,    2,    3,    4,    5,    6,    7,    8,    9,
 /*   470 */    10,   11,   12,   13,  174,   15,   16,   17,   18,   19,
 /*   480 */    20,   21,   22,   23,   24,   25,   26,   27,   28,   29,
 /*   490 */    30,   31,   32,   33,   34,   35,   36,   37,   38,   39,
 /*   500 */    40,   49,   50,   50,   73,   49,   50,   47,   49,   50,
 /*   510 */    50,   50,   63,  177,   14,   66,   67,   68,  170,   70,
 /*   520 */    71,   72,   62,   62,    1,    2,    3,    4,    5,    6,
 /*   530 */     7,    8,    9,   10,   11,   12,   13,   54,   15,   16,
 /*   540 */    17,   18,   19,   20,   21,   22,   23,   24,   25,   26,
 /*   550 */    27,   28,   29,   30,   31,   32,   33,   34,   35,   36,
 /*   560 */    37,   38,   39,   40,  177,  112,   33,   34,   49,  175,
 /*   570 */    47,   45,   50,   50,  177,   42,   43,   44,   45,  153,
 /*   580 */   177,  233,  234,  235,   65,   62,   53,   54,   66,  177,
 /*   590 */   141,  170,  192,  177,   61,  169,  170,   64,   49,  201,
 /*   600 */    29,   30,   31,   32,   33,   34,   35,   36,   37,   38,
 /*   610 */    39,   40,   79,  213,  214,  215,  216,  204,   47,  219,
 /*   620 */    87,   88,   89,   90,   91,   92,   93,   94,   95,   96,
 /*   630 */    97,   98,   99,  100,  101,  102,  103,   50,  105,  106,
 /*   640 */    30,   31,   32,   33,   34,   35,   36,   37,   38,   39,
 /*   650 */    40,  169,  170,   66,  233,  234,  235,   47,   61,  233,
 /*   660 */   234,  235,  205,  130,  131,  132,  133,  134,  135,  136,
 /*   670 */   137,  138,  139,  140,    1,    2,    3,    4,    5,    6,
 /*   680 */     7,    8,    9,   10,   11,   12,   13,   45,   15,   16,
 /*   690 */    17,   18,   19,   20,   21,   22,   23,   24,   25,   26,
 /*   700 */    27,   28,   29,   30,   31,   32,   33,   34,   35,   36,
 /*   710 */    37,   38,   39,   40,  203,  233,  234,  235,  236,  237,
 /*   720 */    47,   54,    1,    2,    3,    4,    5,    6,    7,    8,
 /*   730 */     9,   10,   11,   12,   13,   62,   15,   16,   17,   18,
 /*   740 */    19,   20,   21,   22,   23,   24,   25,   26,   27,   28,
 /*   750 */    29,   30,   31,   32,   33,   34,   35,   36,   37,   38,
 /*   760 */    39,   40,   46,   54,  186,  203,   54,  228,   47,  102,
 /*   770 */    54,   50,  252,    1,    2,    3,    4,    5,    6,    7,
 /*   780 */     8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
 /*   790 */    18,   19,   20,   21,   22,   23,   24,   25,   26,   27,
 /*   800 */    28,   29,   30,   31,   32,   33,   34,   35,   36,   37,
 /*   810 */    38,   39,   40,   70,  226,  177,   20,  177,  220,   47,
 /*   820 */   190,    1,    2,    3,    4,    5,    6,    7,    8,    9,
 /*   830 */    10,   11,   12,   13,   50,   15,   16,   17,   18,   19,
 /*   840 */    20,   21,   22,   23,   24,   25,   26,   27,   28,   29,
 /*   850 */    30,   31,   32,   33,   34,   35,   36,   37,   38,   39,
 /*   860 */    40,  167,   49,  166,   14,  191,  166,   47,   61,    1,
 /*   870 */     2,    3,    4,    5,    6,    7,    8,    9,   10,   11,
 /*   880 */    12,   13,   62,   15,   16,   17,   18,   19,   20,   21,
 /*   890 */    22,   23,   24,   25,   26,   27,   28,   29,   30,   31,
 /*   900 */    32,   33,   34,   35,   36,   37,   38,   39,   40,  170,
 /*   910 */   176,  204,  172,  187,  204,   47,  172,    1,    2,    3,
 /*   920 */     4,    5,    6,    7,    8,    9,   10,   11,   12,   13,
 /*   930 */    62,   15,   16,   17,   18,   19,   20,   21,   22,   23,
 /*   940 */    24,   25,   26,   27,   28,   29,   30,   31,   32,   33,
 /*   950 */    34,   35,   36,   37,   38,   39,   40,  204,   44,   62,
 /*   960 */    61,   54,   45,   47,   54,    1,    2,    3,    4,    5,
 /*   970 */     6,    7,    8,    9,   10,   11,   12,   13,   62,   15,
 /*   980 */    16,   17,   18,   19,   20,   21,   22,   23,   24,   25,
 /*   990 */    26,   27,   28,   29,   30,   31,   32,   33,   34,   35,
 /*  1000 */    36,   37,   38,   39,   40,   53,   49,   65,   47,   47,
 /*  1010 */    66,   47,   49,    1,    2,    3,    4,    5,    6,    7,
 /*  1020 */     8,    9,   10,   11,   12,   13,   62,   15,   16,   17,
 /*  1030 */    18,   19,   20,   21,   22,   23,   24,   25,   26,   27,
 /*  1040 */    28,   29,   30,   31,   32,   33,   34,   35,   36,   37,
 /*  1050 */    38,   39,   40,  169,  170,  168,  169,  170,   49,   47,
 /*  1060 */    66,    1,    2,    3,    4,    5,    6,    7,    8,    9,
 /*  1070 */    10,   11,   12,   13,   14,   15,   16,   17,   18,   19,
 /*  1080 */    20,   21,   22,   23,   24,   25,   26,   27,   28,   29,
 /*  1090 */    30,   31,   32,   33,   34,   35,   36,   37,   38,   39,
 /*  1100 */    40,  168,  169,  170,   50,  169,  170,   47,   66,   61,
 /*  1110 */    45,   45,   65,   62,   61,   45,   62,  233,  234,  235,
 /*  1120 */   233,  234,  235,   50,  112,  241,    1,    2,    3,    4,
 /*  1130 */     5,    6,    7,    8,    9,   10,   11,   12,   13,   66,
 /*  1140 */    15,   16,   17,   18,   19,   20,   21,   22,   23,   24,
 /*  1150 */    25,   26,   27,   28,   29,   30,   31,   32,   33,   34,
 /*  1160 */    35,   36,   37,   38,   39,   40,  233,  234,  235,  233,
 /*  1170 */   234,  235,   47,   62,    1,    2,    3,    4,    5,    6,
 /*  1180 */     7,    8,    9,   10,   11,   12,   13,   62,   15,   16,
 /*  1190 */    17,   18,   19,   20,   21,   22,   23,   24,   25,   26,
 /*  1200 */    27,   28,   29,   30,   31,   32,   33,   34,   35,   36,
 /*  1210 */    37,   38,   39,   40,   61,   45,   62,   61,   54,   45,
 /*  1220 */    47,   49,   49,    1,    1,    2,    3,    4,    5,    6,
 /*  1230 */     7,    8,    9,   10,   11,   12,   13,  170,   15,   16,
 /*  1240 */    17,   18,   19,   20,   21,   22,   23,   24,   25,   26,
 /*  1250 */    27,   28,   29,   30,   31,   32,   33,   34,   35,   36,
 /*  1260 */    37,   38,   39,   40,   54,   50,   50,   66,   65,   13,
 /*  1270 */    47,   15,   16,   17,   18,   19,   20,   21,   22,   23,
 /*  1280 */    24,   25,   26,   27,   28,   29,   30,   31,   32,   33,
 /*  1290 */    34,   35,   36,   37,   38,   39,   40,   44,  169,  170,
 /*  1300 */   233,  234,  235,   47,  153,  154,   53,   54,  170,   50,
 /*  1310 */     1,   14,  169,  170,  163,  164,   45,   64,   26,   27,
 /*  1320 */    28,   29,   30,   31,   32,   33,   34,   35,   36,   37,
 /*  1330 */    38,   39,   40,  182,  183,  184,  207,  153,   45,   47,
 /*  1340 */    87,   88,   89,   90,   91,   92,   93,   94,   95,   96,
 /*  1350 */    97,   98,   99,  100,  101,  102,  103,   50,  105,  106,
 /*  1360 */    49,  177,  233,  234,  235,  236,  237,  170,  150,   62,
 /*  1370 */    50,  233,  234,  235,  153,  224,  233,  234,  235,   49,
 /*  1380 */   127,  128,  129,   56,   57,   58,   66,   60,   45,   45,
 /*  1390 */   169,  170,   65,  209,  210,  211,   69,   16,   17,   18,
 /*  1400 */    19,   20,   21,   22,   23,   24,   25,   26,   27,   28,
 /*  1410 */    29,   30,   31,   32,   33,   34,   35,   36,   37,   38,
 /*  1420 */    39,   40,  192,  153,  170,   50,  169,  170,   47,    0,
 /*  1430 */   233,  234,  235,  212,   45,   49,  192,   62,   65,  169,
 /*  1440 */   170,   49,   49,  213,  214,  215,  216,  192,    1,  219,
 /*  1450 */    49,  181,   66,  112,  233,  234,  235,  213,  214,  215,
 /*  1460 */   216,   54,  192,  219,  207,   49,    1,   65,  213,  214,
 /*  1470 */   215,  216,  112,   46,  204,   49,  206,   48,   54,   49,
 /*  1480 */    51,   52,   53,  213,  214,  215,  216,  233,  234,  235,
 /*  1490 */   233,  234,  235,  236,  237,   62,   21,   68,   49,   70,
 /*  1500 */    71,   50,  112,  233,  234,  235,   20,   50,  238,  239,
 /*  1510 */   240,  241,  242,  243,  244,  245,  246,  247,   21,   20,
 /*  1520 */   250,   17,   18,   19,   20,   21,   22,   23,   24,   25,
 /*  1530 */    26,   27,   28,   29,   30,   31,   32,   33,   34,   35,
 /*  1540 */    36,   37,   38,   39,   40,  169,  170,   20,   54,   33,
 /*  1550 */    34,   47,  153,  169,  170,   21,   21,  169,  170,    1,
 /*  1560 */   169,  170,   33,   34,   54,   49,   66,   65,  169,  170,
 /*  1570 */    54,   42,   43,   44,   45,  192,   54,   45,   49,   62,
 /*  1580 */   181,   21,   66,   54,   47,   54,  169,  170,  212,   20,
 /*  1590 */    61,  192,   14,   54,    1,   54,  213,  214,  215,  216,
 /*  1600 */    62,   61,  219,  212,   54,  206,   50,   54,   79,  233,
 /*  1610 */   234,  235,  213,  214,  215,  216,  170,  233,  234,  235,
 /*  1620 */   170,  233,  234,  235,  233,  234,  235,  169,  170,  212,
 /*  1630 */    50,   66,  233,  234,  235,   50,   49,  238,  239,  240,
 /*  1640 */   241,  242,  243,  244,  245,  246,  247,   14,   54,  250,
 /*  1650 */   233,  234,  235,  253,  253,   33,   34,  253,  153,  130,
 /*  1660 */   131,  132,  133,  134,  135,  136,  137,  138,  139,  140,
 /*  1670 */   212,   49,  253,  253,  169,  170,   54,  253,  253,  233,
 /*  1680 */   234,  235,  253,  233,  234,  235,  181,  253,   66,  253,
 /*  1690 */   253,  233,  234,  235,  253,  253,  153,  192,  253,  169,
 /*  1700 */   170,  253,  169,  170,  253,  169,  170,  253,  253,  204,
 /*  1710 */   253,  253,  169,  170,  253,  253,  253,  253,  213,  214,
 /*  1720 */   215,  216,  253,  253,  181,  253,  253,  253,  253,  253,
 /*  1730 */   169,  170,  253,  169,  170,  192,  253,  253,  233,  234,
 /*  1740 */   235,  253,  212,  238,  239,  240,  241,  242,  243,  244,
 /*  1750 */   245,  246,  247,  253,  253,  250,  213,  214,  215,  216,
 /*  1760 */   169,  170,  253,  233,  234,  235,  233,  234,  235,  233,
 /*  1770 */   234,  235,  253,  212,  253,  253,  233,  234,  235,  253,
 /*  1780 */   253,  238,  239,  240,  241,  242,  243,  244,  245,  246,
 /*  1790 */   247,  153,  253,  250,  233,  234,  235,  233,  234,  235,
 /*  1800 */   253,  253,  253,  253,  253,  253,  253,  169,  170,  253,
 /*  1810 */   253,  253,  253,  253,  253,  253,  253,  253,  253,  181,
 /*  1820 */   253,  253,  253,  253,  233,  234,  235,  253,  253,  153,
 /*  1830 */   192,  169,  170,  253,  169,  170,  253,  169,  170,  253,
 /*  1840 */   169,  170,  253,  253,  253,  169,  170,  253,  253,  253,
 /*  1850 */   253,  213,  214,  215,  216,  253,  253,  181,  253,  253,
 /*  1860 */   253,  253,  253,  253,  253,  253,  169,  170,  192,  169,
 /*  1870 */   170,  233,  234,  235,  253,  253,  238,  239,  240,  241,
 /*  1880 */   242,  243,  244,  245,  246,  247,  253,  253,  250,  213,
 /*  1890 */   214,  215,  216,  253,  253,  233,  234,  235,  233,  234,
 /*  1900 */   235,  233,  234,  235,  233,  234,  235,  253,  253,  233,
 /*  1910 */   234,  235,  153,  253,  238,  239,  240,  241,  242,  243,
 /*  1920 */   244,  245,  246,  247,  253,  253,  250,  253,  169,  170,
 /*  1930 */   233,  234,  235,  233,  234,  235,  253,  253,  253,  253,
 /*  1940 */   181,  253,  253,  253,  253,  253,  169,  170,  253,  253,
 /*  1950 */   253,  192,  169,  170,  253,  169,  170,  253,  253,  253,
 /*  1960 */   253,  169,  170,  253,  169,  170,  253,  169,  170,  253,
 /*  1970 */   253,  253,  213,  214,  215,  216,  253,  169,  170,  253,
 /*  1980 */   253,  253,  253,  253,  253,  253,  253,  253,  253,  169,
 /*  1990 */   170,  253,  233,  234,  235,  253,  253,  238,  239,  240,
 /*  2000 */   241,  242,  243,  244,  245,  246,  247,  153,  253,  250,
 /*  2010 */   233,  234,  235,  253,  253,  253,  233,  234,  235,  233,
 /*  2020 */   234,  235,  253,  169,  170,  233,  234,  235,  233,  234,
 /*  2030 */   235,  233,  234,  235,  253,  181,  253,  253,  253,  253,
 /*  2040 */   253,  233,  234,  235,  253,  153,  192,  169,  170,  253,
 /*  2050 */   169,  170,  253,  233,  234,  235,  253,  253,  169,  170,
 /*  2060 */   253,  169,  170,  253,  253,  253,  253,  213,  214,  215,
 /*  2070 */   216,  253,  253,  181,  253,  253,  253,  253,  253,  253,
 /*  2080 */   253,  253,  169,  170,  192,  169,  170,  233,  234,  235,
 /*  2090 */   253,  253,  238,  239,  240,  241,  242,  243,  244,  245,
 /*  2100 */   246,  247,  253,  253,  250,  213,  214,  215,  216,  253,
 /*  2110 */   154,  233,  234,  235,  233,  234,  235,  253,  253,  163,
 /*  2120 */   164,  253,  233,  234,  235,  233,  234,  235,  153,  253,
 /*  2130 */   238,  239,  240,  241,  242,  243,  244,  245,  246,  247,
 /*  2140 */   184,  253,  250,  253,  169,  170,  233,  234,  235,  233,
 /*  2150 */   234,  235,  253,  253,  253,  253,  181,  253,  253,  253,
 /*  2160 */   253,  253,  169,  170,  253,   33,   34,  192,  253,  253,
 /*  2170 */   253,  253,  253,  253,   42,   43,  253,   45,  253,  253,
 /*  2180 */   224,   49,  253,  253,  253,  253,   54,  253,  213,  214,
 /*  2190 */   215,  216,  253,   61,  169,  170,  253,  253,  253,  253,
 /*  2200 */   253,  253,  253,  253,  253,  253,  253,  253,  233,  234,
 /*  2210 */   235,   79,  253,  238,  239,  240,  241,  242,  243,  244,
 /*  2220 */   245,  246,  247,  169,  170,  250,  233,  234,  235,   20,
 /*  2230 */    21,   22,   23,   24,   25,   26,   27,   28,   29,   30,
 /*  2240 */    31,   32,   33,   34,   35,   36,   37,   38,   39,   40,
 /*  2250 */   253,  253,  253,  253,  253,  253,   47,  253,  233,  234,
 /*  2260 */   235,  253,  130,  131,  132,  133,  134,  135,  136,  137,
 /*  2270 */   138,  139,  140,   33,   34,  169,  170,  253,  253,  253,
 /*  2280 */   253,  253,   42,   43,  253,   45,  253,  233,  234,  235,
 /*  2290 */    33,   34,  253,   53,   54,  169,  170,  253,  253,   42,
 /*  2300 */    43,   61,   45,   33,   34,  253,  253,  253,  253,  253,
 /*  2310 */   253,   54,   42,   43,  253,   45,   33,   34,   61,   79,
 /*  2320 */   169,  170,   65,  253,   54,   42,   43,  253,   45,  253,
 /*  2330 */   253,   61,  253,  253,  253,  253,   79,   54,  253,  233,
 /*  2340 */   234,  235,  253,  253,   61,  253,  253,  253,  253,   79,
 /*  2350 */   253,  253,  253,  253,  253,  253,  253,  253,  253,  233,
 /*  2360 */   234,  235,   79,  169,  170,  253,  253,  253,  253,  253,
 /*  2370 */   130,  131,  132,  133,  134,  135,  136,  137,  138,  139,
 /*  2380 */   140,  169,  170,  253,  233,  234,  235,  130,  131,  132,
 /*  2390 */   133,  134,  135,  136,  137,  138,  139,  140,  169,  170,
 /*  2400 */   130,  131,  132,  133,  134,  135,  136,  137,  138,  139,
 /*  2410 */   140,  169,  170,  130,  131,  132,  133,  134,  135,  136,
 /*  2420 */   137,  138,  139,  140,  253,  253,  253,  233,  234,  235,
 /*  2430 */   169,  170,  253,  253,  192,  169,  170,  253,  169,  170,
 /*  2440 */   253,  169,  170,  253,  253,  233,  234,  235,  253,  253,
 /*  2450 */   253,  253,  253,  169,  170,  213,  214,  215,  216,  169,
 /*  2460 */   170,  253,  233,  234,  235,  169,  170,  253,  253,  169,
 /*  2470 */   170,  253,  169,  170,  253,  233,  234,  235,  253,  253,
 /*  2480 */   253,  169,  170,  241,  253,  169,  170,  253,  246,  253,
 /*  2490 */   248,  249,  169,  170,  233,  234,  235,  253,  253,  233,
 /*  2500 */   234,  235,  233,  234,  235,  233,  234,  235,  253,  169,
 /*  2510 */   170,  253,  253,  253,  169,  170,  253,  233,  234,  235,
 /*  2520 */   253,  253,  253,  233,  234,  235,  253,  253,  253,  233,
 /*  2530 */   234,  235,  253,  233,  234,  235,  233,  234,  235,  253,
 /*  2540 */   169,  170,  253,  169,  170,  233,  234,  235,  253,  233,
 /*  2550 */   234,  235,  169,  170,  253,  253,  233,  234,  235,  169,
 /*  2560 */   170,  253,  169,  170,  253,  169,  170,  253,  169,  170,
 /*  2570 */   253,  169,  170,  233,  234,  235,  169,  170,  233,  234,
 /*  2580 */   235,  169,  170,  253,  253,  253,  253,  253,  253,  253,
 /*  2590 */   253,  253,  253,  253,  253,  253,  253,  253,  253,  253,
 /*  2600 */   253,  253,  253,  253,  233,  234,  235,  233,  234,  235,
 /*  2610 */   253,  253,  253,  253,  253,  253,  233,  234,  235,  253,
 /*  2620 */   253,  253,  253,  233,  234,  235,  233,  234,  235,  233,
 /*  2630 */   234,  235,  233,  234,  235,  233,  234,  235,  253,  253,
 /*  2640 */   233,  234,  235,  253,  253,  233,  234,  235,
};
#define YY_SHIFT_USE_DFLT (2648)
#define YY_SHIFT_COUNT    (361)
#define YY_SHIFT_MIN      (-97)
#define YY_SHIFT_MAX      (2283)
static const short yy_shift_ofst[] = {
 /*     0 */  2648,  229,  -33,  229,   98,  229,  229,  229,  229,  229,
 /*    10 */   229,  533,  449,  217,  335, 2270, 2270, 2270,  -23, 2283,
 /*    20 */  2283, 2270, 1429,  251,  251,  251,  251, 1529, 2132, 2240,
 /*    30 */  2283, 2283, 2283, 2283, 2283, 2283, 2283, 1516, 1253,  251,
 /*    40 */  2257, 2283, 2283, 2283, 2283, 2283, 2283, 2283, 2283, 2283,
 /*    50 */  2283, 2283, 2283, 2283, 2283, 2283, 2283, 2283, 2283, 2283,
 /*    60 */  2283, 2283, 2283, 2283, 2283, 2283, 2283, 2283, 2283, 2283,
 /*    70 */  2283, 2283, 2283, 2283, 2283, 2283, 2283, 2283, 2283, 2283,
 /*    80 */  2283, 2283, 2283, 2283, 2283, 2283, 2283, 2283, 2283, 2283,
 /*    90 */  2283, 2283, 2283, 2283, 2283, 2283, 2283, 2283, 2283, 2283,
 /*   100 */  1622,  110, 2283, 2283, 2283, 2283, 2283, 2283, 2283, 2283,
 /*   110 */   337,  -18,  -52,  -39,   68,  216,  159,  221,  -27,  -97,
 /*   120 */    17,  -27,   41, 2648, 1223,  132,  -17,  -17,  -17,  367,
 /*   130 */   263,  296,  519,  483,  483,  500,  483,  483,  483,  483,
 /*   140 */   526,  549,  597,  642,  709,  642,  712,   17,  743,  -27,
 /*   150 */   -27,  483,  796,  483,  -39,  784,  813,  850,  813,  807,
 /*   160 */  2648, 2648, 2648, 2648, 2648, 2648, 2648,  460,  523,  673,
 /*   170 */   721,  772,  820,  868,  916,  964, 1012, 1060, 1125, 1173,
 /*   180 */  1223, 1223, 1223, 1223, 1223, 1223, 1223, 1223, 1223, 1223,
 /*   190 */  1223, 1223, 1223, 1223, 1223, 1223, 1223, 1223, 1223, 1223,
 /*   200 */  1223, 1223, 1223, 1256, 1381, 1504, 2209, 2209, 2209, 1292,
 /*   210 */  1292, 1292, 1292, 1292, 1292,   47,  178,  571,  610,   87,
 /*   220 */    87,   87,    2,    2,  201, 1327,  340,   85,   80,  452,
 /*   230 */   103,  241,  431,  461,  456,  522,  587,  453, 1054,  459,
 /*   240 */  1073, 1320,  716, 1386,  158,  667, 1307, 1375,  347,  347,
 /*   250 */   347,  347,  347,  914,  897,  899,  917,  914,  907,  910,
 /*   260 */   952,  914,  914,  957,  942,  961,  962,  963, 1009,  944,
 /*   270 */   994, 1042, 1048, 1065, 1066, 1047, 1051, 1053, 1070, 1111,
 /*   280 */  1153, 1170, 1154, 1156, 1174, 1164, 1172, 1222, 1210, 1215,
 /*   290 */  1216, 1201, 1203, 1259, 1309, 1297, 1271, 1293, 1218, 1311,
 /*   300 */  1330, 1343, 1344, 1389,  549, 1392, 1393, 1401, 1373, 1447,
 /*   310 */  1407, 1341, 1416, 1402, 1465, 1360, 1427, 1426, 1430, 1449,
 /*   320 */  1424, 1433, 1451, 1390, 1475, 1486, 1497, 1457, 1499, 1527,
 /*   330 */   914, 1534, 1494, 1535, 1499, 1510, 1558, 1500, 1502, 1522,
 /*   340 */  1532, 1517, 1560, 1531, 1569, 1538, 1539, 1537, 1540, 1578,
 /*   350 */  1593, 1541, 1565, 1550, 1556, 1553, 1580, 1585, 1587, 1633,
 /*   360 */  1594, 1540,
};
#define YY_REDUCE_USE_DFLT (-173)
#define YY_REDUCE_COUNT (166)
#define YY_REDUCE_MIN   (-172)
#define YY_REDUCE_MAX   (2412)
static const short yy_reduce_ofst[] = {
 /*     0 */    25, 1270, 1399, 1505, 1543, 1638, 1676, 1759, 1854, 1892,
 /*    10 */  1975, 2242, -128, -128,  -47,  -79, 1129, 1257, 1151, 1221,
 /*    20 */   167,  482, -157,  400, 1230, 1244, 1383, 1376, 1391,  426,
 /*    30 */   884, 1417, 1458,  887, 1530, 1561,  933,  102,  204, 1255,
 /*    40 */   936, 1143, 1384, 1388, 1533, 1536, 1564, 1591, 1662, 1665,
 /*    50 */  1668, 1671, 1697, 1700, 1777, 1783, 1786, 1792, 1795, 1798,
 /*    60 */  1808, 1820, 1878, 1881, 1889, 1913, 1916, 1993, 2025, 2054,
 /*    70 */  2106, 2126, 2151, 2194, 2212, 2229, 2261, 2266, 2269, 2272,
 /*    80 */  2284, 2290, 2296, 2300, 2303, 2312, 2316, 2323, 2340, 2345,
 /*    90 */  2371, 2374, 2383, 2390, 2393, 2396, 2399, 2402, 2407, 2412,
 /*   100 */  1184, 1956,  348,  421, 1067, 1138, 1197, 1254, 1446, 1450,
 /*   110 */  -172,  -95, -135,  -15,   95,   27,   32,   55,   55,   37,
 /*   120 */   146,  184,  121,  254,   46,  -42,   88,  116,  157,  213,
 /*   130 */   187,  192,  300,  336,  387,  394,  397,  403,  412,  416,
 /*   140 */   398,  413,  457,  511,  578,  562,  539,  520,  588,  187,
 /*   150 */   187,  638,  598,  640,  630,  694,  697,  674,  700,  739,
 /*   160 */   734,  740,  707,  710,  753,  726,  744,
};
static const YYACTIONTYPE yy_default[] = {
 /*     0 */   946, 1014, 1288, 1014, 1288, 1288, 1288, 1288, 1288, 1288,
 /*    10 */  1288, 1238, 1103, 1103, 1288, 1199, 1199, 1199, 1103, 1288,
 /*    20 */  1238, 1199, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288,
 /*    30 */  1288, 1288, 1288,  954, 1288, 1288,  954, 1288, 1288, 1288,
 /*    40 */  1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288,
 /*    50 */  1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288,
 /*    60 */  1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288,
 /*    70 */  1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288,
 /*    80 */  1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288,
 /*    90 */  1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288,
 /*   100 */  1288, 1103, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288,
 /*   110 */  1288, 1133, 1288, 1006, 1288, 1045, 1249, 1100, 1100, 1133,
 /*   120 */  1288, 1268, 1288, 1015, 1031, 1288, 1028, 1028, 1028, 1288,
 /*   130 */  1250, 1288, 1288, 1288, 1288,  959, 1288, 1288, 1288, 1288,
 /*   140 */  1047, 1014, 1288, 1010, 1288, 1010, 1288, 1288, 1124, 1101,
 /*   150 */  1091, 1288, 1087, 1288, 1260, 1259, 1257, 1002, 1257, 1288,
 /*   160 */   961,  974, 1014, 1014, 1014,  988,  974, 1288, 1288, 1288,
 /*   170 */  1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288,
 /*   180 */  1029, 1132, 1251, 1247, 1197, 1279, 1230, 1261, 1008, 1201,
 /*   190 */  1194, 1193, 1192, 1191, 1190, 1189, 1188, 1187, 1186, 1185,
 /*   200 */  1184, 1183, 1200, 1196, 1182, 1181, 1177, 1176, 1175, 1174,
 /*   210 */  1173, 1172, 1171, 1170, 1169, 1168, 1180, 1179, 1178, 1167,
 /*   220 */  1166, 1165, 1157, 1158,  958, 1288, 1277, 1288, 1288, 1288,
 /*   230 */  1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288,
 /*   240 */  1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1164, 1163,
 /*   250 */  1161, 1160, 1159,  960, 1288, 1288, 1288,  966, 1288, 1288,
 /*   260 */  1288, 1059, 1058, 1288, 1288, 1288,  968, 1288, 1288, 1288,
 /*   270 */  1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288,
 /*   280 */  1288, 1288, 1288, 1288, 1288, 1288, 1288, 1131, 1288, 1274,
 /*   290 */  1237, 1288, 1288, 1248, 1288, 1288, 1288, 1288, 1241, 1288,
 /*   300 */  1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288,
 /*   310 */  1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288, 1288,
 /*   320 */  1137, 1288, 1270, 1288, 1288, 1288, 1288, 1288, 1288, 1288,
 /*   330 */  1083, 1288, 1288, 1288, 1116, 1288, 1007, 1288, 1288, 1288,
 /*   340 */  1288, 1288, 1288, 1288, 1288, 1288, 1288, 1162, 1282, 1137,
 /*   350 */  1288, 1288, 1288, 1288,  986, 1288, 1288,  985, 1288, 1288,
 /*   360 */  1288,  955,
};
/********** End of lemon-generated parsing tables *****************************/

/* The next table maps tokens (terminal symbols) into fallback tokens.  
** If a construct like the following:
** 
**      %fallback ID X Y Z.
**
** appears in the grammar, then ID becomes a fallback token for X, Y,
** and Z.  Whenever one of the tokens X, Y, or Z is input to the parser
** but it does not parse, the type of the token is changed to ID and
** the parse is retried before an error is thrown.
**
** This feature can be used, for example, to cause some keywords in a language
** to revert to identifiers if they keyword does not apply in the context where
** it appears.
*/
#ifdef YYFALLBACK
static const YYCODETYPE yyFallback[] = {
    0,  /*          $ => nothing */
    0,  /*         EQ => nothing */
    0,  /*      MULEQ => nothing */
    0,  /*      DIVEQ => nothing */
    0,  /*      MODEQ => nothing */
    0,  /*      ADDEQ => nothing */
    0,  /*      SUBEQ => nothing */
    0,  /*      LSHEQ => nothing */
    0,  /*      RSHEQ => nothing */
    0,  /*      ANDEQ => nothing */
    0,  /*       OREQ => nothing */
    0,  /*      XOREQ => nothing */
    0,  /*     URSHEQ => nothing */
    0,  /*   QUESTION => nothing */
    0,  /*      COLON => nothing */
    0,  /*       OROR => nothing */
    0,  /*     ANDAND => nothing */
    0,  /*       EQEQ => nothing */
    0,  /*        NEQ => nothing */
    0,  /*   APPROXEQ => nothing */
    0,  /*         LT => nothing */
    0,  /*         GT => nothing */
    0,  /*       LTEQ => nothing */
    0,  /*       GTEQ => nothing */
    0,  /*     LTGTEQ => nothing */
    0,  /*         IS => nothing */
    0,  /*     DOTDOT => nothing */
    0,  /*         OR => nothing */
    0,  /*        XOR => nothing */
    0,  /*        AND => nothing */
    0,  /*        LSH => nothing */
    0,  /*        RSH => nothing */
    0,  /*       URSH => nothing */
    0,  /*        SUB => nothing */
    0,  /*        ADD => nothing */
    0,  /*        MUL => nothing */
    0,  /*        DIV => nothing */
    0,  /*        MOD => nothing */
    0,  /*  CROSSPROD => nothing */
    0,  /*    DOTPROD => nothing */
    0,  /*        POW => nothing */
    0,  /*      UNARY => nothing */
    0,  /*     ADDADD => nothing */
    0,  /*     SUBSUB => nothing */
    0,  /*        DOT => nothing */
    0,  /*     LPAREN => nothing */
    0,  /*   LBRACKET => nothing */
    0,  /*      SCOPE => nothing */
    0,  /*        EOF => nothing */
    0,  /*  SEMICOLON => nothing */
    0,  /*      COMMA => nothing */
    0,  /*    INCLUDE => nothing */
    0,  /*     EXTEND => nothing */
    0,  /*      CLASS => nothing */
    0,  /* IDENTIFIER => nothing */
    0,  /*   ABSTRACT => nothing */
    0,  /*     NATIVE => nothing */
    0,  /*         UI => nothing */
    0,  /*       PLAY => nothing */
    0,  /*   REPLACES => nothing */
    0,  /*    VERSION => nothing */
    0,  /*   STRCONST => nothing */
    0,  /*     RPAREN => nothing */
   54,  /*    DEFAULT => IDENTIFIER */
   54,  /*      COLOR => IDENTIFIER */
    0,  /*     LBRACE => nothing */
    0,  /*     RBRACE => nothing */
   54,  /*   PROPERTY => IDENTIFIER */
    0,  /*     STRUCT => nothing */
    0,  /* CLEARSCOPE => nothing */
    0,  /*      CONST => nothing */
    0,  /*       ENUM => nothing */
    0,  /*     STATES => nothing */
    0,  /*        NWS => nothing */
    0,  /*       STOP => nothing */
    0,  /*       WAIT => nothing */
    0,  /*       FAIL => nothing */
    0,  /*       LOOP => nothing */
    0,  /*       GOTO => nothing */
    0,  /*      SUPER => nothing */
    0,  /*     BRIGHT => nothing */
    0,  /*       FAST => nothing */
    0,  /*       SLOW => nothing */
    0,  /*    NODELAY => nothing */
    0,  /*   CANRAISE => nothing */
    0,  /*     OFFSET => nothing */
    0,  /*      LIGHT => nothing */
   54,  /*      SBYTE => IDENTIFIER */
   54,  /*       BYTE => IDENTIFIER */
   54,  /*      SHORT => IDENTIFIER */
   54,  /*     USHORT => IDENTIFIER */
   54,  /*        INT => IDENTIFIER */
   54,  /*       UINT => IDENTIFIER */
   54,  /*       BOOL => IDENTIFIER */
   54,  /*      FLOAT => IDENTIFIER */
   54,  /*     DOUBLE => IDENTIFIER */
   54,  /*    VECTOR2 => IDENTIFIER */
   54,  /*    VECTOR3 => IDENTIFIER */
   54,  /*       NAME => IDENTIFIER */
   54,  /*      SOUND => IDENTIFIER */
   54,  /*      STATE => IDENTIFIER */
    0,  /*        LET => nothing */
    0,  /*     ATSIGN => nothing */
    0,  /*   READONLY => nothing */
   54,  /*     STRING => IDENTIFIER */
   54,  /*        MAP => IDENTIFIER */
   54,  /*      ARRAY => IDENTIFIER */
   54,  /*       VOID => IDENTIFIER */
   54,  /*      UINT8 => IDENTIFIER */
   54,  /*       INT8 => IDENTIFIER */
   54,  /*     UINT16 => IDENTIFIER */
   54,  /*      INT16 => IDENTIFIER */
};
#endif /* YYFALLBACK */

/* The following structure represents a single element of the
** parser's stack.  Information stored includes:
**
**   +  The state number for the parser at this level of the stack.
**
**   +  The value of the token stored at this level of the stack.
**      (In other words, the "major" token.)
**
**   +  The semantic value stored at this level of the stack.  This is
**      the information used by the action routines in the grammar.
**      It is sometimes called the "minor" token.
**
** After the "shift" half of a SHIFTREDUCE action, the stateno field
** actually contains the reduce action for the second half of the
** SHIFTREDUCE.
*/
struct yyStackEntry {
  YYACTIONTYPE stateno;  /* The state-number, or reduce action in SHIFTREDUCE */
  YYCODETYPE major;      /* The major token value.  This is the code
                         ** number for the token at this stack level */
  YYMINORTYPE minor;     /* The user-supplied minor token value.  This
                         ** is the value of the token  */
};
typedef struct yyStackEntry yyStackEntry;

/* The state of the parser is completely contained in an instance of
** the following structure */
struct yyParser {
  yyStackEntry *yytos;          /* Pointer to top element of the stack */
#ifdef YYTRACKMAXSTACKDEPTH
  int yyhwm;                    /* High-water mark of the stack */
#endif
#ifndef YYNOERRORRECOVERY
  int yyerrcnt;                 /* Shifts left before out of the error */
#endif
  ZCCParseARG_SDECL                /* A place to hold %extra_argument */
#if YYSTACKDEPTH<=0
  int yystksz;                  /* Current side of the stack */
  yyStackEntry *yystack;        /* The parser's stack */
  yyStackEntry yystk0;          /* First stack entry */
#else
  yyStackEntry yystack[YYSTACKDEPTH];  /* The parser's stack */
#endif
};
typedef struct yyParser yyParser;

#ifndef NDEBUG
#include <stdio.h>
static FILE *yyTraceFILE = 0;
static char *yyTracePrompt = 0;
#endif /* NDEBUG */

#ifndef NDEBUG
/* 
** Turn parser tracing on by giving a stream to which to write the trace
** and a prompt to preface each trace message.  Tracing is turned off
** by making either argument NULL 
**
** Inputs:
** <ul>
** <li> A FILE* to which trace output should be written.
**      If NULL, then tracing is turned off.
** <li> A prefix string written at the beginning of every
**      line of trace output.  If NULL, then tracing is
**      turned off.
** </ul>
**
** Outputs:
** None.
*/
void ZCCParseTrace(FILE *TraceFILE, char *zTracePrompt){
  yyTraceFILE = TraceFILE;
  yyTracePrompt = zTracePrompt;
  if( yyTraceFILE==0 ) yyTracePrompt = 0;
  else if( yyTracePrompt==0 ) yyTraceFILE = 0;
}
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing shifts, the names of all terminals and nonterminals
** are required.  The following table supplies these names */
static const char *const yyTokenName[] = { 
  "$",             "EQ",            "MULEQ",         "DIVEQ",       
  "MODEQ",         "ADDEQ",         "SUBEQ",         "LSHEQ",       
  "RSHEQ",         "ANDEQ",         "OREQ",          "XOREQ",       
  "URSHEQ",        "QUESTION",      "COLON",         "OROR",        
  "ANDAND",        "EQEQ",          "NEQ",           "APPROXEQ",    
  "LT",            "GT",            "LTEQ",          "GTEQ",        
  "LTGTEQ",        "IS",            "DOTDOT",        "OR",          
  "XOR",           "AND",           "LSH",           "RSH",         
  "URSH",          "SUB",           "ADD",           "MUL",         
  "DIV",           "MOD",           "CROSSPROD",     "DOTPROD",     
  "POW",           "UNARY",         "ADDADD",        "SUBSUB",      
  "DOT",           "LPAREN",        "LBRACKET",      "SCOPE",       
  "EOF",           "SEMICOLON",     "COMMA",         "INCLUDE",     
  "EXTEND",        "CLASS",         "IDENTIFIER",    "ABSTRACT",    
  "NATIVE",        "UI",            "PLAY",          "REPLACES",    
  "VERSION",       "STRCONST",      "RPAREN",        "DEFAULT",     
  "COLOR",         "LBRACE",        "RBRACE",        "PROPERTY",    
  "STRUCT",        "CLEARSCOPE",    "CONST",         "ENUM",        
  "STATES",        "NWS",           "STOP",          "WAIT",        
  "FAIL",          "LOOP",          "GOTO",          "SUPER",       
  "BRIGHT",        "FAST",          "SLOW",          "NODELAY",     
  "CANRAISE",      "OFFSET",        "LIGHT",         "SBYTE",       
  "BYTE",          "SHORT",         "USHORT",        "INT",         
  "UINT",          "BOOL",          "FLOAT",         "DOUBLE",      
  "VECTOR2",       "VECTOR3",       "NAME",          "SOUND",       
  "STATE",         "LET",           "ATSIGN",        "READONLY",    
  "STRING",        "MAP",           "ARRAY",         "VOID",        
  "UINT8",         "INT8",          "UINT16",        "INT16",       
  "RBRACKET",      "ACTION",        "DEPRECATED",    "STATIC",      
  "PRIVATE",       "PROTECTED",     "LATENT",        "FINAL",       
  "META",          "TRANSIENT",     "VIRTUAL",       "OVERRIDE",    
  "VARARG",        "VIRTUALSCOPE",  "ELLIPSIS",      "IN",          
  "OUT",           "OPTIONAL",      "TILDE",         "BANG",        
  "SIZEOF",        "ALIGNOF",       "INTCONST",      "UINTCONST",   
  "FLOATCONST",    "NAMECONST",     "FALSE",         "TRUE",        
  "NULLPTR",       "STATICCONST",   "CONTINUE",      "BREAK",       
  "RETURN",        "DO",            "FOR",           "WHILE",       
  "UNTIL",         "IF",            "ELSE",          "SWITCH",      
  "CASE",          "error",         "declarator",    "declarator_no_fun",
  "opt_func_body",  "function_body",  "main",          "translation_unit",
  "external_declaration",  "class_definition",  "struct_def",    "enum_def",    
  "const_def",     "include_def",   "opt_semicolon",  "opt_comma",   
  "opt_expr",      "expr",          "string_constant",  "class_head",  
  "class_innards",  "class_member",  "class_body",    "class_ancestry",
  "class_flags",   "dottable_id",   "property_def",  "states_def",  
  "default_def",   "staticarray_statement",  "opt_struct_body",  "struct_body", 
  "struct_member",  "identifier_list",  "states_opt",    "struct_flags",
  "enum_list",     "opt_enum_list",  "enumerator",    "enum_type",   
  "int_type",      "states_body",   "state_line",    "state_label", 
  "state_flow",    "state_flow_type",  "state_goto_offset",  "state_action",
  "state_call",    "state_call_params",  "state_opts",    "states_opts", 
  "scanner_mode",  "light_list",    "statement_list",  "func_expr_list",
  "default_statement_list",  "default_statement",  "property_statement",  "flag_statement",
  "expr_list",     "type_name",     "type_name1",    "aggregate_type",
  "type",          "type_list",     "type_list_or_void",  "type_or_array",
  "class_restrictor",  "array_size",    "array_size_expr",  "variables_or_function",
  "decl_flags",    "func_params",   "func_const",    "variable_list",
  "variable_name",  "decl_flag",     "func_param_list",  "func_param",  
  "func_param_flags",  "primary",       "unary_expr",    "constant",    
  "func_expr_item",  "named_expr",    "compound_statement",  "statement",   
  "labeled_statement",  "expression_statement",  "selection_statement",  "iteration_statement",
  "jump_statement",  "assign_statement",  "local_var",     "while_or_until",
  "for_init",      "for_bump",      "if_front",      "variable_list_with_init",
  "var_init",    
};
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing reduce actions, the names of all rules are required.
*/
static const char *const yyRuleName[] = {
 /*   0 */ "main ::= translation_unit",
 /*   1 */ "translation_unit ::=",
 /*   2 */ "translation_unit ::= translation_unit external_declaration",
 /*   3 */ "translation_unit ::= error",
 /*   4 */ "external_declaration ::= class_definition",
 /*   5 */ "external_declaration ::= struct_def",
 /*   6 */ "external_declaration ::= enum_def",
 /*   7 */ "external_declaration ::= const_def",
 /*   8 */ "external_declaration ::= include_def",
 /*   9 */ "opt_expr ::=",
 /*  10 */ "include_def ::= INCLUDE string_constant",
 /*  11 */ "class_definition ::= class_head class_body",
 /*  12 */ "class_head ::= EXTEND CLASS IDENTIFIER",
 /*  13 */ "class_head ::= CLASS IDENTIFIER class_ancestry class_flags",
 /*  14 */ "class_ancestry ::=",
 /*  15 */ "class_ancestry ::= COLON dottable_id",
 /*  16 */ "class_flags ::=",
 /*  17 */ "class_flags ::= class_flags ABSTRACT",
 /*  18 */ "class_flags ::= class_flags NATIVE",
 /*  19 */ "class_flags ::= class_flags UI",
 /*  20 */ "class_flags ::= class_flags PLAY",
 /*  21 */ "class_flags ::= class_flags REPLACES dottable_id",
 /*  22 */ "class_flags ::= class_flags VERSION LPAREN STRCONST RPAREN",
 /*  23 */ "dottable_id ::= IDENTIFIER",
 /*  24 */ "dottable_id ::= dottable_id DOT IDENTIFIER",
 /*  25 */ "dottable_id ::= dottable_id DOT DEFAULT",
 /*  26 */ "dottable_id ::= dottable_id DOT COLOR",
 /*  27 */ "class_body ::= SEMICOLON class_innards EOF",
 /*  28 */ "class_body ::= LBRACE class_innards RBRACE",
 /*  29 */ "class_innards ::=",
 /*  30 */ "class_innards ::= class_innards class_member",
 /*  31 */ "class_member ::= declarator",
 /*  32 */ "class_member ::= enum_def",
 /*  33 */ "class_member ::= struct_def",
 /*  34 */ "class_member ::= states_def",
 /*  35 */ "class_member ::= default_def",
 /*  36 */ "class_member ::= const_def",
 /*  37 */ "class_member ::= property_def",
 /*  38 */ "class_member ::= staticarray_statement",
 /*  39 */ "property_def ::= PROPERTY IDENTIFIER COLON identifier_list SEMICOLON",
 /*  40 */ "identifier_list ::= IDENTIFIER",
 /*  41 */ "identifier_list ::= states_opt COMMA IDENTIFIER",
 /*  42 */ "struct_def ::= STRUCT IDENTIFIER struct_flags LBRACE opt_struct_body RBRACE opt_semicolon",
 /*  43 */ "struct_flags ::=",
 /*  44 */ "struct_flags ::= struct_flags UI",
 /*  45 */ "struct_flags ::= struct_flags PLAY",
 /*  46 */ "struct_flags ::= struct_flags CLEARSCOPE",
 /*  47 */ "struct_flags ::= struct_flags NATIVE",
 /*  48 */ "struct_flags ::= struct_flags VERSION LPAREN STRCONST RPAREN",
 /*  49 */ "opt_struct_body ::=",
 /*  50 */ "opt_struct_body ::= error",
 /*  51 */ "struct_body ::= struct_body struct_member",
 /*  52 */ "struct_member ::= declarator",
 /*  53 */ "struct_member ::= enum_def",
 /*  54 */ "struct_member ::= const_def",
 /*  55 */ "const_def ::= CONST IDENTIFIER EQ expr SEMICOLON",
 /*  56 */ "enum_def ::= ENUM IDENTIFIER enum_type LBRACE opt_enum_list RBRACE opt_semicolon",
 /*  57 */ "enum_type ::=",
 /*  58 */ "enum_type ::= COLON int_type",
 /*  59 */ "enum_list ::= error",
 /*  60 */ "enum_list ::= enum_list COMMA enumerator",
 /*  61 */ "opt_enum_list ::=",
 /*  62 */ "enumerator ::= IDENTIFIER",
 /*  63 */ "enumerator ::= IDENTIFIER EQ expr",
 /*  64 */ "states_def ::= STATES states_opts scanner_mode LBRACE states_body RBRACE",
 /*  65 */ "states_opts ::=",
 /*  66 */ "states_opts ::= LPAREN states_opt RPAREN",
 /*  67 */ "states_opt ::= IDENTIFIER",
 /*  68 */ "states_opt ::= states_opt COMMA IDENTIFIER",
 /*  69 */ "scanner_mode ::=",
 /*  70 */ "states_body ::=",
 /*  71 */ "states_body ::= error",
 /*  72 */ "states_body ::= states_body state_line",
 /*  73 */ "states_body ::= states_body state_label",
 /*  74 */ "states_body ::= states_body state_flow",
 /*  75 */ "state_label ::= NWS COLON",
 /*  76 */ "state_flow_type ::= STOP",
 /*  77 */ "state_flow_type ::= WAIT",
 /*  78 */ "state_flow_type ::= FAIL",
 /*  79 */ "state_flow_type ::= LOOP",
 /*  80 */ "state_flow_type ::= GOTO dottable_id state_goto_offset",
 /*  81 */ "state_flow_type ::= GOTO IDENTIFIER SCOPE dottable_id state_goto_offset",
 /*  82 */ "state_flow_type ::= GOTO SUPER SCOPE dottable_id state_goto_offset",
 /*  83 */ "state_goto_offset ::=",
 /*  84 */ "state_goto_offset ::= ADD expr",
 /*  85 */ "state_line ::= NWS NWS expr state_opts state_action",
 /*  86 */ "state_opts ::=",
 /*  87 */ "state_opts ::= state_opts BRIGHT",
 /*  88 */ "state_opts ::= state_opts FAST",
 /*  89 */ "state_opts ::= state_opts SLOW",
 /*  90 */ "state_opts ::= state_opts NODELAY",
 /*  91 */ "state_opts ::= state_opts CANRAISE",
 /*  92 */ "state_opts ::= state_opts OFFSET LPAREN expr COMMA expr RPAREN",
 /*  93 */ "state_opts ::= state_opts LIGHT LPAREN light_list RPAREN",
 /*  94 */ "light_list ::= STRCONST",
 /*  95 */ "light_list ::= light_list COMMA STRCONST",
 /*  96 */ "state_action ::= LBRACE statement_list scanner_mode RBRACE",
 /*  97 */ "state_action ::= LBRACE scanner_mode RBRACE",
 /*  98 */ "state_action ::= LBRACE error scanner_mode RBRACE",
 /*  99 */ "state_action ::= state_call scanner_mode SEMICOLON",
 /* 100 */ "state_call ::=",
 /* 101 */ "state_call ::= IDENTIFIER state_call_params",
 /* 102 */ "state_call_params ::=",
 /* 103 */ "state_call_params ::= LPAREN func_expr_list RPAREN",
 /* 104 */ "default_def ::= DEFAULT LBRACE RBRACE",
 /* 105 */ "default_def ::= DEFAULT LBRACE default_statement_list RBRACE",
 /* 106 */ "default_def ::= DEFAULT LBRACE error RBRACE",
 /* 107 */ "default_statement_list ::= default_statement",
 /* 108 */ "default_statement_list ::= default_statement_list default_statement",
 /* 109 */ "default_statement ::= SEMICOLON",
 /* 110 */ "default_statement ::= error SEMICOLON",
 /* 111 */ "default_statement ::= property_statement",
 /* 112 */ "default_statement ::= flag_statement",
 /* 113 */ "flag_statement ::= ADD dottable_id",
 /* 114 */ "flag_statement ::= SUB dottable_id",
 /* 115 */ "property_statement ::= dottable_id expr_list SEMICOLON",
 /* 116 */ "property_statement ::= dottable_id SEMICOLON",
 /* 117 */ "int_type ::= SBYTE",
 /* 118 */ "int_type ::= BYTE",
 /* 119 */ "int_type ::= SHORT",
 /* 120 */ "int_type ::= USHORT",
 /* 121 */ "int_type ::= INT",
 /* 122 */ "int_type ::= UINT",
 /* 123 */ "type_name1 ::= BOOL",
 /* 124 */ "type_name1 ::= FLOAT",
 /* 125 */ "type_name1 ::= DOUBLE",
 /* 126 */ "type_name1 ::= VECTOR2",
 /* 127 */ "type_name1 ::= VECTOR3",
 /* 128 */ "type_name1 ::= NAME",
 /* 129 */ "type_name1 ::= SOUND",
 /* 130 */ "type_name1 ::= STATE",
 /* 131 */ "type_name1 ::= COLOR",
 /* 132 */ "type_name1 ::= LET",
 /* 133 */ "type_name ::= type_name1",
 /* 134 */ "type_name ::= IDENTIFIER",
 /* 135 */ "type_name ::= ATSIGN IDENTIFIER",
 /* 136 */ "type_name ::= READONLY LT IDENTIFIER GT",
 /* 137 */ "type_name ::= READONLY LT ATSIGN IDENTIFIER GT",
 /* 138 */ "type_name ::= DOT dottable_id",
 /* 139 */ "aggregate_type ::= MAP LT type_or_array COMMA type_or_array GT",
 /* 140 */ "aggregate_type ::= ARRAY LT type_or_array GT",
 /* 141 */ "aggregate_type ::= CLASS class_restrictor",
 /* 142 */ "class_restrictor ::=",
 /* 143 */ "class_restrictor ::= LT dottable_id GT",
 /* 144 */ "type ::= type_name",
 /* 145 */ "type ::= aggregate_type",
 /* 146 */ "type_or_array ::= type array_size",
 /* 147 */ "type_list ::= type_list COMMA type_or_array",
 /* 148 */ "type_list_or_void ::= VOID",
 /* 149 */ "array_size_expr ::= LBRACKET opt_expr RBRACKET",
 /* 150 */ "array_size ::= array_size array_size_expr",
 /* 151 */ "declarator ::= decl_flags type_list_or_void variables_or_function",
 /* 152 */ "variables_or_function ::= IDENTIFIER LPAREN func_params RPAREN func_const opt_func_body",
 /* 153 */ "variables_or_function ::= variable_list SEMICOLON",
 /* 154 */ "variables_or_function ::= error SEMICOLON",
 /* 155 */ "variable_name ::= IDENTIFIER",
 /* 156 */ "variable_name ::= IDENTIFIER array_size",
 /* 157 */ "variable_list ::= variable_list COMMA variable_name",
 /* 158 */ "decl_flags ::=",
 /* 159 */ "decl_flags ::= decl_flags decl_flag",
 /* 160 */ "decl_flags ::= decl_flags ACTION states_opts",
 /* 161 */ "decl_flags ::= decl_flags DEPRECATED LPAREN STRCONST RPAREN",
 /* 162 */ "decl_flags ::= decl_flags VERSION LPAREN STRCONST RPAREN",
 /* 163 */ "decl_flag ::= NATIVE",
 /* 164 */ "decl_flag ::= STATIC",
 /* 165 */ "decl_flag ::= PRIVATE",
 /* 166 */ "decl_flag ::= PROTECTED",
 /* 167 */ "decl_flag ::= LATENT",
 /* 168 */ "decl_flag ::= FINAL",
 /* 169 */ "decl_flag ::= META",
 /* 170 */ "decl_flag ::= TRANSIENT",
 /* 171 */ "decl_flag ::= READONLY",
 /* 172 */ "decl_flag ::= VIRTUAL",
 /* 173 */ "decl_flag ::= OVERRIDE",
 /* 174 */ "decl_flag ::= VARARG",
 /* 175 */ "decl_flag ::= UI",
 /* 176 */ "decl_flag ::= PLAY",
 /* 177 */ "decl_flag ::= CLEARSCOPE",
 /* 178 */ "decl_flag ::= VIRTUALSCOPE",
 /* 179 */ "func_const ::=",
 /* 180 */ "func_const ::= CONST",
 /* 181 */ "opt_func_body ::= SEMICOLON",
 /* 182 */ "func_params ::=",
 /* 183 */ "func_params ::= VOID",
 /* 184 */ "func_params ::= func_param_list COMMA ELLIPSIS",
 /* 185 */ "func_param_list ::= func_param_list COMMA func_param",
 /* 186 */ "func_param ::= func_param_flags type IDENTIFIER",
 /* 187 */ "func_param ::= func_param_flags type IDENTIFIER EQ expr",
 /* 188 */ "func_param_flags ::=",
 /* 189 */ "func_param_flags ::= func_param_flags IN",
 /* 190 */ "func_param_flags ::= func_param_flags OUT",
 /* 191 */ "func_param_flags ::= func_param_flags OPTIONAL",
 /* 192 */ "primary ::= IDENTIFIER",
 /* 193 */ "primary ::= SUPER",
 /* 194 */ "primary ::= constant",
 /* 195 */ "primary ::= LPAREN expr COMMA expr COMMA expr RPAREN",
 /* 196 */ "primary ::= LPAREN expr COMMA expr RPAREN",
 /* 197 */ "primary ::= LPAREN expr RPAREN",
 /* 198 */ "primary ::= primary LPAREN func_expr_list RPAREN",
 /* 199 */ "primary ::= LPAREN CLASS LT IDENTIFIER GT RPAREN LPAREN func_expr_list RPAREN",
 /* 200 */ "primary ::= primary LBRACKET expr RBRACKET",
 /* 201 */ "primary ::= primary DOT IDENTIFIER",
 /* 202 */ "primary ::= primary ADDADD",
 /* 203 */ "primary ::= primary SUBSUB",
 /* 204 */ "unary_expr ::= SUB unary_expr",
 /* 205 */ "unary_expr ::= ADD unary_expr",
 /* 206 */ "unary_expr ::= SUBSUB unary_expr",
 /* 207 */ "unary_expr ::= ADDADD unary_expr",
 /* 208 */ "unary_expr ::= TILDE unary_expr",
 /* 209 */ "unary_expr ::= BANG unary_expr",
 /* 210 */ "unary_expr ::= SIZEOF unary_expr",
 /* 211 */ "unary_expr ::= ALIGNOF unary_expr",
 /* 212 */ "expr ::= expr ADD expr",
 /* 213 */ "expr ::= expr SUB expr",
 /* 214 */ "expr ::= expr MUL expr",
 /* 215 */ "expr ::= expr DIV expr",
 /* 216 */ "expr ::= expr MOD expr",
 /* 217 */ "expr ::= expr POW expr",
 /* 218 */ "expr ::= expr CROSSPROD expr",
 /* 219 */ "expr ::= expr DOTPROD expr",
 /* 220 */ "expr ::= expr LSH expr",
 /* 221 */ "expr ::= expr RSH expr",
 /* 222 */ "expr ::= expr URSH expr",
 /* 223 */ "expr ::= expr DOTDOT expr",
 /* 224 */ "expr ::= expr LT expr",
 /* 225 */ "expr ::= expr GT expr",
 /* 226 */ "expr ::= expr LTEQ expr",
 /* 227 */ "expr ::= expr GTEQ expr",
 /* 228 */ "expr ::= expr LTGTEQ expr",
 /* 229 */ "expr ::= expr IS expr",
 /* 230 */ "expr ::= expr EQEQ expr",
 /* 231 */ "expr ::= expr NEQ expr",
 /* 232 */ "expr ::= expr APPROXEQ expr",
 /* 233 */ "expr ::= expr AND expr",
 /* 234 */ "expr ::= expr XOR expr",
 /* 235 */ "expr ::= expr OR expr",
 /* 236 */ "expr ::= expr ANDAND expr",
 /* 237 */ "expr ::= expr OROR expr",
 /* 238 */ "expr ::= expr EQ expr",
 /* 239 */ "expr ::= expr ADDEQ expr",
 /* 240 */ "expr ::= expr SUBEQ expr",
 /* 241 */ "expr ::= expr MULEQ expr",
 /* 242 */ "expr ::= expr DIVEQ expr",
 /* 243 */ "expr ::= expr MODEQ expr",
 /* 244 */ "expr ::= expr LSHEQ expr",
 /* 245 */ "expr ::= expr RSHEQ expr",
 /* 246 */ "expr ::= expr URSHEQ expr",
 /* 247 */ "expr ::= expr ANDEQ expr",
 /* 248 */ "expr ::= expr OREQ expr",
 /* 249 */ "expr ::= expr XOREQ expr",
 /* 250 */ "expr ::= expr SCOPE expr",
 /* 251 */ "expr ::= expr QUESTION expr COLON expr",
 /* 252 */ "expr_list ::= expr_list COMMA expr",
 /* 253 */ "func_expr_list ::= func_expr_list COMMA func_expr_item",
 /* 254 */ "func_expr_item ::=",
 /* 255 */ "named_expr ::= IDENTIFIER COLON expr",
 /* 256 */ "named_expr ::= expr",
 /* 257 */ "string_constant ::= STRCONST",
 /* 258 */ "string_constant ::= string_constant STRCONST",
 /* 259 */ "constant ::= INTCONST",
 /* 260 */ "constant ::= UINTCONST",
 /* 261 */ "constant ::= FLOATCONST",
 /* 262 */ "constant ::= NAMECONST",
 /* 263 */ "constant ::= FALSE",
 /* 264 */ "constant ::= TRUE",
 /* 265 */ "constant ::= NULLPTR",
 /* 266 */ "statement ::= SEMICOLON",
 /* 267 */ "statement ::= labeled_statement",
 /* 268 */ "statement ::= compound_statement",
 /* 269 */ "statement ::= expression_statement SEMICOLON",
 /* 270 */ "statement ::= assign_statement SEMICOLON",
 /* 271 */ "statement ::= local_var SEMICOLON",
 /* 272 */ "statement ::= error SEMICOLON",
 /* 273 */ "statement ::= staticarray_statement",
 /* 274 */ "staticarray_statement ::= STATICCONST type IDENTIFIER LBRACKET RBRACKET EQ LBRACE expr_list RBRACE SEMICOLON",
 /* 275 */ "staticarray_statement ::= STATICCONST type LBRACKET RBRACKET IDENTIFIER EQ LBRACE expr_list RBRACE SEMICOLON",
 /* 276 */ "jump_statement ::= CONTINUE SEMICOLON",
 /* 277 */ "jump_statement ::= BREAK SEMICOLON",
 /* 278 */ "jump_statement ::= RETURN SEMICOLON",
 /* 279 */ "jump_statement ::= RETURN expr_list SEMICOLON",
 /* 280 */ "compound_statement ::= LBRACE RBRACE",
 /* 281 */ "compound_statement ::= LBRACE statement_list RBRACE",
 /* 282 */ "compound_statement ::= LBRACE error RBRACE",
 /* 283 */ "statement_list ::= statement",
 /* 284 */ "statement_list ::= statement_list statement",
 /* 285 */ "expression_statement ::= expr",
 /* 286 */ "iteration_statement ::= while_or_until LPAREN expr RPAREN statement",
 /* 287 */ "iteration_statement ::= DO statement while_or_until LPAREN expr RPAREN",
 /* 288 */ "iteration_statement ::= FOR LPAREN for_init SEMICOLON opt_expr SEMICOLON for_bump RPAREN statement",
 /* 289 */ "while_or_until ::= WHILE",
 /* 290 */ "while_or_until ::= UNTIL",
 /* 291 */ "for_init ::= local_var",
 /* 292 */ "for_init ::= for_bump",
 /* 293 */ "for_bump ::=",
 /* 294 */ "for_bump ::= expression_statement",
 /* 295 */ "for_bump ::= for_bump COMMA expression_statement",
 /* 296 */ "selection_statement ::= if_front",
 /* 297 */ "selection_statement ::= if_front ELSE statement",
 /* 298 */ "if_front ::= IF LPAREN expr RPAREN statement",
 /* 299 */ "selection_statement ::= SWITCH LPAREN expr RPAREN statement",
 /* 300 */ "labeled_statement ::= CASE expr COLON",
 /* 301 */ "labeled_statement ::= DEFAULT COLON",
 /* 302 */ "assign_statement ::= LBRACKET expr_list RBRACKET EQ expr",
 /* 303 */ "local_var ::= type variable_list_with_init",
 /* 304 */ "var_init ::= IDENTIFIER",
 /* 305 */ "var_init ::= IDENTIFIER array_size",
 /* 306 */ "var_init ::= IDENTIFIER EQ expr",
 /* 307 */ "var_init ::= IDENTIFIER EQ LBRACE expr_list RBRACE",
 /* 308 */ "var_init ::= IDENTIFIER array_size EQ LBRACE expr_list RBRACE",
 /* 309 */ "var_init ::= IDENTIFIER EQ LBRACE error RBRACE",
 /* 310 */ "variable_list_with_init ::= variable_list_with_init COMMA var_init",
 /* 311 */ "translation_unit ::= translation_unit EOF",
 /* 312 */ "opt_semicolon ::=",
 /* 313 */ "opt_semicolon ::= SEMICOLON",
 /* 314 */ "opt_comma ::=",
 /* 315 */ "opt_comma ::= COMMA",
 /* 316 */ "opt_expr ::= expr",
 /* 317 */ "opt_struct_body ::= struct_body",
 /* 318 */ "struct_body ::= struct_member",
 /* 319 */ "enum_list ::= enumerator",
 /* 320 */ "opt_enum_list ::= enum_list opt_comma",
 /* 321 */ "state_flow ::= state_flow_type scanner_mode SEMICOLON",
 /* 322 */ "type_name1 ::= int_type",
 /* 323 */ "type_or_array ::= type",
 /* 324 */ "type_list ::= type_or_array",
 /* 325 */ "type_list_or_void ::= type_list",
 /* 326 */ "array_size ::= array_size_expr",
 /* 327 */ "variable_list ::= variable_name",
 /* 328 */ "opt_func_body ::= function_body",
 /* 329 */ "func_params ::= func_param_list",
 /* 330 */ "func_param_list ::= func_param",
 /* 331 */ "primary ::= LPAREN error RPAREN",
 /* 332 */ "unary_expr ::= primary",
 /* 333 */ "expr ::= unary_expr",
 /* 334 */ "expr_list ::= expr",
 /* 335 */ "func_expr_list ::= func_expr_item",
 /* 336 */ "func_expr_item ::= named_expr",
 /* 337 */ "constant ::= string_constant",
 /* 338 */ "function_body ::= compound_statement",
 /* 339 */ "statement ::= selection_statement",
 /* 340 */ "statement ::= iteration_statement",
 /* 341 */ "statement ::= jump_statement",
 /* 342 */ "variable_list_with_init ::= var_init",
};
#endif /* NDEBUG */


#if YYSTACKDEPTH<=0
/*
** Try to increase the size of the parser stack.  Return the number
** of errors.  Return 0 on success.
*/
static int yyGrowStack(yyParser *p){
  int newSize;
  int idx;
  yyStackEntry *pNew;

  newSize = p->yystksz*2 + 100;
  idx = p->yytos ? (int)(p->yytos - p->yystack) : 0;
  if( p->yystack==&p->yystk0 ){
    pNew = (yyStackEntry *)malloc(newSize*sizeof(pNew[0]));
    if( pNew ) pNew[0] = p->yystk0;
  }else{
    pNew = (yyStackEntry *)realloc(p->yystack, newSize*sizeof(pNew[0]));
  }
  if( pNew ){
    p->yystack = pNew;
    p->yytos = &p->yystack[idx];
#ifndef NDEBUG
    if( yyTraceFILE ){
      fprintf(yyTraceFILE,"%sStack grows from %d to %d entries.\n",
              yyTracePrompt, p->yystksz, newSize);
      fflush(yyTraceFILE);
    }
#endif
    p->yystksz = newSize;
  }
  return pNew==0; 
}
#endif

/* Datatype of the argument to the memory allocated passed as the
** second argument to ZCCParseAlloc() below.  This can be changed by
** putting an appropriate #define in the %include section of the input
** grammar.
*/
#ifndef YYMALLOCARGTYPE
# define YYMALLOCARGTYPE size_t
#endif

/* 
** This function allocates a new parser.
** The only argument is a pointer to a function which works like
** malloc.
**
** Inputs:
** A pointer to the function used to allocate memory.
**
** Outputs:
** A pointer to a parser.  This pointer is used in subsequent calls
** to ZCCParse and ZCCParseFree.
*/
void *ZCCParseAlloc(void *(CDECL *mallocProc)(YYMALLOCARGTYPE)){
  yyParser *pParser;
  pParser = (yyParser*)(*mallocProc)( (YYMALLOCARGTYPE)sizeof(yyParser) );
  if( pParser ){
#ifdef YYTRACKMAXSTACKDEPTH
    pParser->yyhwm = 0;
#endif
#if YYSTACKDEPTH<=0
    pParser->yytos = NULL;
    pParser->yystack = NULL;
    pParser->yystksz = 0;
    if( yyGrowStack(pParser) ){
      pParser->yystack = &pParser->yystk0;
      pParser->yystksz = 1;
    }
#endif
#ifndef YYNOERRORRECOVERY
    pParser->yyerrcnt = -1;
#endif
    pParser->yytos = pParser->yystack;
    pParser->yystack[0].stateno = 0;
    pParser->yystack[0].major = 0;
  }
  return pParser;
}

/* The following function deletes the "minor type" or semantic value
** associated with a symbol.  The symbol can be either a terminal
** or nonterminal. "yymajor" is the symbol code, and "yypminor" is
** a pointer to the value to be deleted.  The code used to do the 
** deletions is derived from the %destructor and/or %token_destructor
** directives of the input grammar.
*/
static void yy_destructor(
  yyParser *yypParser,    /* The parser */
  YYCODETYPE yymajor,     /* Type code for object to destroy */
  YYMINORTYPE *yypminor   /* The object to be destroyed */
){
  ZCCParseARG_FETCH;
  switch( yymajor ){
    /* Here is inserted the actions which take place when a
    ** terminal or non-terminal is destroyed.  This can happen
    ** when the symbol is popped from the stack during a
    ** reduce or during error processing or when a parser is 
    ** being destroyed before it is finished parsing.
    **
    ** Note: during a reduce, the only symbols destroyed are those
    ** which appear on the RHS of the rule, but which are *not* used
    ** inside the C code.
    */
/********* Begin destructor definitions ***************************************/
      /* TERMINAL Destructor */
    case 1: /* EQ */
    case 2: /* MULEQ */
    case 3: /* DIVEQ */
    case 4: /* MODEQ */
    case 5: /* ADDEQ */
    case 6: /* SUBEQ */
    case 7: /* LSHEQ */
    case 8: /* RSHEQ */
    case 9: /* ANDEQ */
    case 10: /* OREQ */
    case 11: /* XOREQ */
    case 12: /* URSHEQ */
    case 13: /* QUESTION */
    case 14: /* COLON */
    case 15: /* OROR */
    case 16: /* ANDAND */
    case 17: /* EQEQ */
    case 18: /* NEQ */
    case 19: /* APPROXEQ */
    case 20: /* LT */
    case 21: /* GT */
    case 22: /* LTEQ */
    case 23: /* GTEQ */
    case 24: /* LTGTEQ */
    case 25: /* IS */
    case 26: /* DOTDOT */
    case 27: /* OR */
    case 28: /* XOR */
    case 29: /* AND */
    case 30: /* LSH */
    case 31: /* RSH */
    case 32: /* URSH */
    case 33: /* SUB */
    case 34: /* ADD */
    case 35: /* MUL */
    case 36: /* DIV */
    case 37: /* MOD */
    case 38: /* CROSSPROD */
    case 39: /* DOTPROD */
    case 40: /* POW */
    case 41: /* UNARY */
    case 42: /* ADDADD */
    case 43: /* SUBSUB */
    case 44: /* DOT */
    case 45: /* LPAREN */
    case 46: /* LBRACKET */
    case 47: /* SCOPE */
    case 48: /* EOF */
    case 49: /* SEMICOLON */
    case 50: /* COMMA */
    case 51: /* INCLUDE */
    case 52: /* EXTEND */
    case 53: /* CLASS */
    case 54: /* IDENTIFIER */
    case 55: /* ABSTRACT */
    case 56: /* NATIVE */
    case 57: /* UI */
    case 58: /* PLAY */
    case 59: /* REPLACES */
    case 60: /* VERSION */
    case 61: /* STRCONST */
    case 62: /* RPAREN */
    case 63: /* DEFAULT */
    case 64: /* COLOR */
    case 65: /* LBRACE */
    case 66: /* RBRACE */
    case 67: /* PROPERTY */
    case 68: /* STRUCT */
    case 69: /* CLEARSCOPE */
    case 70: /* CONST */
    case 71: /* ENUM */
    case 72: /* STATES */
    case 73: /* NWS */
    case 74: /* STOP */
    case 75: /* WAIT */
    case 76: /* FAIL */
    case 77: /* LOOP */
    case 78: /* GOTO */
    case 79: /* SUPER */
    case 80: /* BRIGHT */
    case 81: /* FAST */
    case 82: /* SLOW */
    case 83: /* NODELAY */
    case 84: /* CANRAISE */
    case 85: /* OFFSET */
    case 86: /* LIGHT */
    case 87: /* SBYTE */
    case 88: /* BYTE */
    case 89: /* SHORT */
    case 90: /* USHORT */
    case 91: /* INT */
    case 92: /* UINT */
    case 93: /* BOOL */
    case 94: /* FLOAT */
    case 95: /* DOUBLE */
    case 96: /* VECTOR2 */
    case 97: /* VECTOR3 */
    case 98: /* NAME */
    case 99: /* SOUND */
    case 100: /* STATE */
    case 101: /* LET */
    case 102: /* ATSIGN */
    case 103: /* READONLY */
    case 104: /* STRING */
    case 105: /* MAP */
    case 106: /* ARRAY */
    case 107: /* VOID */
    case 108: /* UINT8 */
    case 109: /* INT8 */
    case 110: /* UINT16 */
    case 111: /* INT16 */
    case 112: /* RBRACKET */
    case 113: /* ACTION */
    case 114: /* DEPRECATED */
    case 115: /* STATIC */
    case 116: /* PRIVATE */
    case 117: /* PROTECTED */
    case 118: /* LATENT */
    case 119: /* FINAL */
    case 120: /* META */
    case 121: /* TRANSIENT */
    case 122: /* VIRTUAL */
    case 123: /* OVERRIDE */
    case 124: /* VARARG */
    case 125: /* VIRTUALSCOPE */
    case 126: /* ELLIPSIS */
    case 127: /* IN */
    case 128: /* OUT */
    case 129: /* OPTIONAL */
    case 130: /* TILDE */
    case 131: /* BANG */
    case 132: /* SIZEOF */
    case 133: /* ALIGNOF */
    case 134: /* INTCONST */
    case 135: /* UINTCONST */
    case 136: /* FLOATCONST */
    case 137: /* NAMECONST */
    case 138: /* FALSE */
    case 139: /* TRUE */
    case 140: /* NULLPTR */
    case 141: /* STATICCONST */
    case 142: /* CONTINUE */
    case 143: /* BREAK */
    case 144: /* RETURN */
    case 145: /* DO */
    case 146: /* FOR */
    case 147: /* WHILE */
    case 148: /* UNTIL */
    case 149: /* IF */
    case 150: /* ELSE */
    case 151: /* SWITCH */
    case 152: /* CASE */
{
#line 117 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"

#line 1839 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
}
      break;
/********* End destructor definitions *****************************************/
    default:  break;   /* If no destructor action specified: do nothing */
  }
}

/*
** Pop the parser's stack once.
**
** If there is a destructor routine associated with the token which
** is popped from the stack, then call it.
*/
static void yy_pop_parser_stack(yyParser *pParser){
  yyStackEntry *yytos;
  assert( pParser->yytos!=0 );
  assert( pParser->yytos > pParser->yystack );
  yytos = pParser->yytos--;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sPopping %s\n",
      yyTracePrompt,
      yyTokenName[yytos->major]);
    fflush(yyTraceFILE);
  }
#endif
  yy_destructor(pParser, yytos->major, &yytos->minor);
}

/* 
** Deallocate and destroy a parser.  Destructors are called for
** all stack elements before shutting the parser down.
**
** If the YYPARSEFREENEVERNULL macro exists (for example because it
** is defined in a %include section of the input grammar) then it is
** assumed that the input pointer is never NULL.
*/
void ZCCParseFree(
  void *p,                    /* The parser to be deleted */
  void (CDECL *freeProc)(void*)     /* Function used to reclaim memory */
){
  yyParser *pParser = (yyParser*)p;
#ifndef YYPARSEFREENEVERNULL
  if( pParser==0 ) return;
#endif
  while( pParser->yytos>pParser->yystack ) yy_pop_parser_stack(pParser);
#if YYSTACKDEPTH<=0
  if( pParser->yystack!=&pParser->yystk0 ) free(pParser->yystack);
#endif
  (*freeProc)((void*)pParser);
}

/*
** Return the peak depth of the stack for a parser.
*/
#ifdef YYTRACKMAXSTACKDEPTH
int ZCCParseStackPeak(void *p){
  yyParser *pParser = (yyParser*)p;
  return pParser->yyhwm;
}
#endif

/*
** Find the appropriate action for a parser given the terminal
** look-ahead token iLookAhead.
*/
static unsigned int yy_find_shift_action(
  yyParser *pParser,        /* The parser */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
  int stateno = pParser->yytos->stateno;
 
  if( stateno>=YY_MIN_REDUCE ) return stateno;
  assert( stateno <= YY_SHIFT_COUNT );
  do{
    i = yy_shift_ofst[stateno];
    assert( iLookAhead!=YYNOCODE );
    i += iLookAhead;
    if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
#ifdef YYFALLBACK
      YYCODETYPE iFallback;            /* Fallback token */
      if( iLookAhead<sizeof(yyFallback)/sizeof(yyFallback[0])
             && (iFallback = yyFallback[iLookAhead])!=0 ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE, "%sFALLBACK %s => %s\n",
             yyTracePrompt, yyTokenName[iLookAhead], yyTokenName[iFallback]);
          fflush(yyTraceFILE);
        }
#endif
        assert( yyFallback[iFallback]==0 ); /* Fallback loop must terminate */
        iLookAhead = iFallback;
        continue;
      }
#endif
#ifdef YYWILDCARD
      {
        int j = i - iLookAhead + YYWILDCARD;
        if( 
#if YY_SHIFT_MIN+YYWILDCARD<0
          j>=0 &&
#endif
#if YY_SHIFT_MAX+YYWILDCARD>=YY_ACTTAB_COUNT
          j<YY_ACTTAB_COUNT &&
#endif
          yy_lookahead[j]==YYWILDCARD && iLookAhead>0
        ){
#ifndef NDEBUG
          if( yyTraceFILE ){
            fprintf(yyTraceFILE, "%sWILDCARD %s => %s\n",
               yyTracePrompt, yyTokenName[iLookAhead],
               yyTokenName[YYWILDCARD]);
            fflush(yyTraceFILE);
          }
#endif /* NDEBUG */
          return yy_action[j];
        }
      }
#endif /* YYWILDCARD */
      return yy_default[stateno];
    }else{
      return yy_action[i];
    }
  }while(1);
}

/*
** Find the appropriate action for a parser given the non-terminal
** look-ahead token iLookAhead.
*/
static int yy_find_reduce_action(
  int stateno,              /* Current state number */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
#ifdef YYERRORSYMBOL
  if( stateno>YY_REDUCE_COUNT ){
    return yy_default[stateno];
  }
#else
  assert( stateno<=YY_REDUCE_COUNT );
#endif
  i = yy_reduce_ofst[stateno];
  assert( i!=YY_REDUCE_USE_DFLT );
  assert( iLookAhead!=YYNOCODE );
  i += iLookAhead;
#ifdef YYERRORSYMBOL
  if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
    return yy_default[stateno];
  }
#else
  assert( i>=0 && i<YY_ACTTAB_COUNT );
  assert( yy_lookahead[i]==iLookAhead );
#endif
  return yy_action[i];
}

/*
** The following routine is called if the stack overflows.
*/
static void yyStackOverflow(yyParser *yypParser){
   ZCCParseARG_FETCH;
   yypParser->yytos--;
#ifndef NDEBUG
   if( yyTraceFILE ){
     fprintf(yyTraceFILE,"%sStack Overflow!\n",yyTracePrompt);
     fflush(yyTraceFILE);
   }
#endif
   while( yypParser->yytos>yypParser->yystack ) yy_pop_parser_stack(yypParser);
   /* Here code is inserted which will execute if the parser
   ** stack every overflows */
/******** Begin %stack_overflow code ******************************************/
/******** End %stack_overflow code ********************************************/
   ZCCParseARG_STORE; /* Suppress warning about unused %extra_argument var */
}

/*
** Print tracing information for a SHIFT action
*/
#ifndef NDEBUG
static void yyTraceShift(yyParser *yypParser, int yyNewState){
  if( yyTraceFILE ){
    if( yyNewState<YYNSTATE ){
      fprintf(yyTraceFILE,"%sShift '%s', go to state %d\n",
         yyTracePrompt,yyTokenName[yypParser->yytos->major],
         yyNewState);
    }else{
      fprintf(yyTraceFILE,"%sShift '%s'\n",
         yyTracePrompt,yyTokenName[yypParser->yytos->major]);
    }
    fflush(yyTraceFILE);
  }
}
#else
# define yyTraceShift(X,Y)
#endif

/*
** Perform a shift action.
*/
static void yy_shift(
  yyParser *yypParser,          /* The parser to be shifted */
  int yyNewState,               /* The new state to shift in */
  int yyMajor,                  /* The major token to shift in */
  ZCCParseTOKENTYPE yyMinor        /* The minor token to shift in */
){
  yyStackEntry *yytos;
  yypParser->yytos++;
#ifdef YYTRACKMAXSTACKDEPTH
  if( (int)(yypParser->yytos - yypParser->yystack)>yypParser->yyhwm ){
    yypParser->yyhwm++;
    assert( yypParser->yyhwm == (int)(yypParser->yytos - yypParser->yystack) );
  }
#endif
#if YYSTACKDEPTH>0 
  if( yypParser->yytos>=&yypParser->yystack[YYSTACKDEPTH] ){
    yyStackOverflow(yypParser);
    return;
  }
#else
  if( yypParser->yytos>=&yypParser->yystack[yypParser->yystksz] ){
    if( yyGrowStack(yypParser) ){
      yyStackOverflow(yypParser);
      return;
    }
  }
#endif
  if( yyNewState > YY_MAX_SHIFT ){
    yyNewState += YY_MIN_REDUCE - YY_MIN_SHIFTREDUCE;
  }
  yytos = yypParser->yytos;
  yytos->stateno = (YYACTIONTYPE)yyNewState;
  yytos->major = (YYCODETYPE)yyMajor;
  yytos->minor.yy0 = yyMinor;
  yyTraceShift(yypParser, yyNewState);
}

/* The following table contains information about every rule that
** is used during the reduce.
*/
static const struct {
  YYCODETYPE lhs;         /* Symbol on the left-hand side of the rule */
  unsigned char nrhs;     /* Number of right-hand side symbols in the rule */
} yyRuleInfo[] = {
  { 158, 1 },
  { 159, 0 },
  { 159, 2 },
  { 159, 1 },
  { 160, 1 },
  { 160, 1 },
  { 160, 1 },
  { 160, 1 },
  { 160, 1 },
  { 168, 0 },
  { 165, 2 },
  { 161, 2 },
  { 171, 3 },
  { 171, 4 },
  { 175, 0 },
  { 175, 2 },
  { 176, 0 },
  { 176, 2 },
  { 176, 2 },
  { 176, 2 },
  { 176, 2 },
  { 176, 3 },
  { 176, 5 },
  { 177, 1 },
  { 177, 3 },
  { 177, 3 },
  { 177, 3 },
  { 174, 3 },
  { 174, 3 },
  { 172, 0 },
  { 172, 2 },
  { 173, 1 },
  { 173, 1 },
  { 173, 1 },
  { 173, 1 },
  { 173, 1 },
  { 173, 1 },
  { 173, 1 },
  { 173, 1 },
  { 178, 5 },
  { 185, 1 },
  { 185, 3 },
  { 162, 7 },
  { 187, 0 },
  { 187, 2 },
  { 187, 2 },
  { 187, 2 },
  { 187, 2 },
  { 187, 5 },
  { 182, 0 },
  { 182, 1 },
  { 183, 2 },
  { 184, 1 },
  { 184, 1 },
  { 184, 1 },
  { 164, 5 },
  { 163, 7 },
  { 191, 0 },
  { 191, 2 },
  { 188, 1 },
  { 188, 3 },
  { 189, 0 },
  { 190, 1 },
  { 190, 3 },
  { 179, 6 },
  { 203, 0 },
  { 203, 3 },
  { 186, 1 },
  { 186, 3 },
  { 204, 0 },
  { 193, 0 },
  { 193, 1 },
  { 193, 2 },
  { 193, 2 },
  { 193, 2 },
  { 195, 2 },
  { 197, 1 },
  { 197, 1 },
  { 197, 1 },
  { 197, 1 },
  { 197, 3 },
  { 197, 5 },
  { 197, 5 },
  { 198, 0 },
  { 198, 2 },
  { 194, 5 },
  { 202, 0 },
  { 202, 2 },
  { 202, 2 },
  { 202, 2 },
  { 202, 2 },
  { 202, 2 },
  { 202, 7 },
  { 202, 5 },
  { 205, 1 },
  { 205, 3 },
  { 199, 4 },
  { 199, 3 },
  { 199, 4 },
  { 199, 3 },
  { 200, 0 },
  { 200, 2 },
  { 201, 0 },
  { 201, 3 },
  { 180, 3 },
  { 180, 4 },
  { 180, 4 },
  { 208, 1 },
  { 208, 2 },
  { 209, 1 },
  { 209, 2 },
  { 209, 1 },
  { 209, 1 },
  { 211, 2 },
  { 211, 2 },
  { 210, 3 },
  { 210, 2 },
  { 192, 1 },
  { 192, 1 },
  { 192, 1 },
  { 192, 1 },
  { 192, 1 },
  { 192, 1 },
  { 214, 1 },
  { 214, 1 },
  { 214, 1 },
  { 214, 1 },
  { 214, 1 },
  { 214, 1 },
  { 214, 1 },
  { 214, 1 },
  { 214, 1 },
  { 214, 1 },
  { 213, 1 },
  { 213, 1 },
  { 213, 2 },
  { 213, 4 },
  { 213, 5 },
  { 213, 2 },
  { 215, 6 },
  { 215, 4 },
  { 215, 2 },
  { 220, 0 },
  { 220, 3 },
  { 216, 1 },
  { 216, 1 },
  { 219, 2 },
  { 217, 3 },
  { 218, 1 },
  { 222, 3 },
  { 221, 2 },
  { 154, 3 },
  { 223, 6 },
  { 223, 2 },
  { 223, 2 },
  { 228, 1 },
  { 228, 2 },
  { 227, 3 },
  { 224, 0 },
  { 224, 2 },
  { 224, 3 },
  { 224, 5 },
  { 224, 5 },
  { 229, 1 },
  { 229, 1 },
  { 229, 1 },
  { 229, 1 },
  { 229, 1 },
  { 229, 1 },
  { 229, 1 },
  { 229, 1 },
  { 229, 1 },
  { 229, 1 },
  { 229, 1 },
  { 229, 1 },
  { 229, 1 },
  { 229, 1 },
  { 229, 1 },
  { 229, 1 },
  { 226, 0 },
  { 226, 1 },
  { 156, 1 },
  { 225, 0 },
  { 225, 1 },
  { 225, 3 },
  { 230, 3 },
  { 231, 3 },
  { 231, 5 },
  { 232, 0 },
  { 232, 2 },
  { 232, 2 },
  { 232, 2 },
  { 233, 1 },
  { 233, 1 },
  { 233, 1 },
  { 233, 7 },
  { 233, 5 },
  { 233, 3 },
  { 233, 4 },
  { 233, 9 },
  { 233, 4 },
  { 233, 3 },
  { 233, 2 },
  { 233, 2 },
  { 234, 2 },
  { 234, 2 },
  { 234, 2 },
  { 234, 2 },
  { 234, 2 },
  { 234, 2 },
  { 234, 2 },
  { 234, 2 },
  { 169, 3 },
  { 169, 3 },
  { 169, 3 },
  { 169, 3 },
  { 169, 3 },
  { 169, 3 },
  { 169, 3 },
  { 169, 3 },
  { 169, 3 },
  { 169, 3 },
  { 169, 3 },
  { 169, 3 },
  { 169, 3 },
  { 169, 3 },
  { 169, 3 },
  { 169, 3 },
  { 169, 3 },
  { 169, 3 },
  { 169, 3 },
  { 169, 3 },
  { 169, 3 },
  { 169, 3 },
  { 169, 3 },
  { 169, 3 },
  { 169, 3 },
  { 169, 3 },
  { 169, 3 },
  { 169, 3 },
  { 169, 3 },
  { 169, 3 },
  { 169, 3 },
  { 169, 3 },
  { 169, 3 },
  { 169, 3 },
  { 169, 3 },
  { 169, 3 },
  { 169, 3 },
  { 169, 3 },
  { 169, 3 },
  { 169, 5 },
  { 212, 3 },
  { 207, 3 },
  { 236, 0 },
  { 237, 3 },
  { 237, 1 },
  { 170, 1 },
  { 170, 2 },
  { 235, 1 },
  { 235, 1 },
  { 235, 1 },
  { 235, 1 },
  { 235, 1 },
  { 235, 1 },
  { 235, 1 },
  { 239, 1 },
  { 239, 1 },
  { 239, 1 },
  { 239, 2 },
  { 239, 2 },
  { 239, 2 },
  { 239, 2 },
  { 239, 1 },
  { 181, 10 },
  { 181, 10 },
  { 244, 2 },
  { 244, 2 },
  { 244, 2 },
  { 244, 3 },
  { 238, 2 },
  { 238, 3 },
  { 238, 3 },
  { 206, 1 },
  { 206, 2 },
  { 241, 1 },
  { 243, 5 },
  { 243, 6 },
  { 243, 9 },
  { 247, 1 },
  { 247, 1 },
  { 248, 1 },
  { 248, 1 },
  { 249, 0 },
  { 249, 1 },
  { 249, 3 },
  { 242, 1 },
  { 242, 3 },
  { 250, 5 },
  { 242, 5 },
  { 240, 3 },
  { 240, 2 },
  { 245, 5 },
  { 246, 2 },
  { 252, 1 },
  { 252, 2 },
  { 252, 3 },
  { 252, 5 },
  { 252, 6 },
  { 252, 5 },
  { 251, 3 },
  { 159, 2 },
  { 166, 0 },
  { 166, 1 },
  { 167, 0 },
  { 167, 1 },
  { 168, 1 },
  { 182, 1 },
  { 183, 1 },
  { 188, 1 },
  { 189, 2 },
  { 196, 3 },
  { 214, 1 },
  { 219, 1 },
  { 217, 1 },
  { 218, 1 },
  { 221, 1 },
  { 227, 1 },
  { 156, 1 },
  { 225, 1 },
  { 230, 1 },
  { 233, 3 },
  { 234, 1 },
  { 169, 1 },
  { 212, 1 },
  { 207, 1 },
  { 236, 1 },
  { 235, 1 },
  { 157, 1 },
  { 239, 1 },
  { 239, 1 },
  { 239, 1 },
  { 251, 1 },
};

static void yy_accept(yyParser*);  /* Forward Declaration */

/*
** Perform a reduce action and the shift that must immediately
** follow the reduce.
*/
static void yy_reduce(
  yyParser *yypParser,         /* The parser */
  unsigned int yyruleno        /* Number of the rule by which to reduce */
){
  int yygoto;                     /* The next state */
  int yyact;                      /* The next action */
  yyStackEntry *yymsp;            /* The top of the parser's stack */
  int yysize;                     /* Amount to pop the stack */
  ZCCParseARG_FETCH;
  yymsp = yypParser->yytos;
#ifndef NDEBUG
  if( yyTraceFILE && yyruleno<(int)(sizeof(yyRuleName)/sizeof(yyRuleName[0])) ){
    yysize = yyRuleInfo[yyruleno].nrhs;
    fprintf(yyTraceFILE, "%sReduce [%s], go to state %d.\n", yyTracePrompt,
      yyRuleName[yyruleno], yymsp[-yysize].stateno);
    fflush(yyTraceFILE);
  }
#endif /* NDEBUG */

  /* Check that the stack is large enough to grow by a single entry
  ** if the RHS of the rule is empty.  This ensures that there is room
  ** enough on the stack to push the LHS value */
  if( yyRuleInfo[yyruleno].nrhs==0 ){
#ifdef YYTRACKMAXSTACKDEPTH
    if( (int)(yypParser->yytos - yypParser->yystack)>yypParser->yyhwm ){
      yypParser->yyhwm++;
      assert( yypParser->yyhwm == (int)(yypParser->yytos - yypParser->yystack));
    }
#endif
#if YYSTACKDEPTH>0 
    if( yypParser->yytos>=&yypParser->yystack[YYSTACKDEPTH-1] ){
      yyStackOverflow(yypParser);
      return;
    }
#else
    if( yypParser->yytos>=&yypParser->yystack[yypParser->yystksz-1] ){
      if( yyGrowStack(yypParser) ){
        yyStackOverflow(yypParser);
        return;
      }
      yymsp = yypParser->yytos;
    }
#endif
  }

  switch( yyruleno ){
  /* Beginning here are the reduction cases.  A typical example
  ** follows:
  **   case 0:
  **  #line <lineno> <grammarfile>
  **     { ... }           // User supplied code
  **  #line <lineno> <thisfile>
  **     break;
  */
/********** Begin reduce actions **********************************************/
        YYMINORTYPE yylhsminor;
      case 0: /* main ::= translation_unit */
#line 173 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ stat->TopNode = yymsp[0].minor.yy392; DPrintf(DMSG_SPAMMY, "Parse complete\n"); }
#line 2496 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 1: /* translation_unit ::= */
      case 29: /*class_innards ::= */ yytestcase(yyruleno==29);
      case 49: /*opt_struct_body ::= */ yytestcase(yyruleno==49);
#line 176 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy392 = NULL; }
#line 2503 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 2: /* translation_unit ::= translation_unit external_declaration */
      case 30: /*class_innards ::= class_innards class_member */ yytestcase(yyruleno==30);
#line 177 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ SAFE_APPEND(yymsp[-1].minor.yy392,yymsp[0].minor.yy392); }
#line 2509 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 3: /* translation_unit ::= error */
      case 50: /*opt_struct_body ::= error */ yytestcase(yyruleno==50);
#line 179 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy392 = NULL; }
#line 2515 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 4: /* external_declaration ::= class_definition */
#line 182 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy392 = yymsp[0].minor.yy272; /*X-overwrites-A*/ }
#line 2520 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 5: /* external_declaration ::= struct_def */
      case 33: /*class_member ::= struct_def */ yytestcase(yyruleno==33);
#line 183 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy392 = yymsp[0].minor.yy505; /*X-overwrites-A*/ }
#line 2526 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 6: /* external_declaration ::= enum_def */
      case 32: /*class_member ::= enum_def */ yytestcase(yyruleno==32);
      case 53: /*struct_member ::= enum_def */ yytestcase(yyruleno==53);
#line 184 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy392 = yymsp[0].minor.yy245; /*X-overwrites-A*/ }
#line 2533 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 7: /* external_declaration ::= const_def */
      case 36: /*class_member ::= const_def */ yytestcase(yyruleno==36);
      case 54: /*struct_member ::= const_def */ yytestcase(yyruleno==54);
#line 185 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy392 = yymsp[0].minor.yy419; /*X-overwrites-A*/ }
#line 2540 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 8: /* external_declaration ::= include_def */
#line 186 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy392 = nullptr; }
#line 2545 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 9: /* opt_expr ::= */
#line 197 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	yymsp[1].minor.yy184 = NULL;
}
#line 2552 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 10: /* include_def ::= INCLUDE string_constant */
{  yy_destructor(yypParser,51,&yymsp[-1].minor);
#line 204 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	AddInclude(yymsp[0].minor.yy273);
}
#line 2560 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
}
        break;
      case 11: /* class_definition ::= class_head class_body */
#line 218 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	yymsp[-1].minor.yy272->Body = yymsp[0].minor.yy392;
	yymsp[-1].minor.yy272 = yymsp[-1].minor.yy272; /*X-overwrites-A*/
}
#line 2569 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 12: /* class_head ::= EXTEND CLASS IDENTIFIER */
{  yy_destructor(yypParser,52,&yymsp[-2].minor);
#line 224 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Class,head,yymsp[-1].minor.yy0);
	head->NodeName = yymsp[0].minor.yy0.Name();
	head->ParentName = nullptr;
	head->Flags =  ZCC_Extension;
	head->Replaces = nullptr;
	head->Version = {0, 0};
	head->Type = nullptr;
	head->Symbol = nullptr;
	yymsp[-2].minor.yy272 = head;
}
#line 2585 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
}
        break;
      case 13: /* class_head ::= CLASS IDENTIFIER class_ancestry class_flags */
#line 237 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Class,head,yymsp[-3].minor.yy0);
	head->NodeName = yymsp[-2].minor.yy0.Name();
	head->ParentName = yymsp[-1].minor.yy311;
	head->Flags = yymsp[0].minor.yy271.Flags;
	head->Replaces = yymsp[0].minor.yy271.Replaces;
	head->Version = yymsp[0].minor.yy271.Version;
	head->Type = nullptr;
	head->Symbol = nullptr;
	yylhsminor.yy272 = head;
}
#line 2601 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[-3].minor.yy272 = yylhsminor.yy272;
        break;
      case 14: /* class_ancestry ::= */
      case 142: /*class_restrictor ::= */ yytestcase(yyruleno==142);
#line 250 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy311 = NULL; }
#line 2608 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 15: /* class_ancestry ::= COLON dottable_id */
{  yy_destructor(yypParser,14,&yymsp[-1].minor);
#line 251 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy311 = yymsp[0].minor.yy311; /*yymsp[-1].minor.yy311-overwrites-yymsp[0].minor.yy311*/ }
#line 2614 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
}
        break;
      case 16: /* class_flags ::= */
#line 254 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy271.Flags = 0; yymsp[1].minor.yy271.Replaces = NULL; yymsp[1].minor.yy271.Version = {0,0}; }
#line 2620 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 17: /* class_flags ::= class_flags ABSTRACT */
#line 255 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy271.Flags = yymsp[-1].minor.yy271.Flags | ZCC_Abstract; yylhsminor.yy271.Replaces = yymsp[-1].minor.yy271.Replaces; }
#line 2625 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,55,&yymsp[0].minor);
  yymsp[-1].minor.yy271 = yylhsminor.yy271;
        break;
      case 18: /* class_flags ::= class_flags NATIVE */
#line 256 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy271.Flags = yymsp[-1].minor.yy271.Flags | ZCC_Native; yylhsminor.yy271.Replaces = yymsp[-1].minor.yy271.Replaces; }
#line 2632 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,56,&yymsp[0].minor);
  yymsp[-1].minor.yy271 = yylhsminor.yy271;
        break;
      case 19: /* class_flags ::= class_flags UI */
#line 257 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy271.Flags = yymsp[-1].minor.yy271.Flags | ZCC_UIFlag; yylhsminor.yy271.Replaces = yymsp[-1].minor.yy271.Replaces; }
#line 2639 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,57,&yymsp[0].minor);
  yymsp[-1].minor.yy271 = yylhsminor.yy271;
        break;
      case 20: /* class_flags ::= class_flags PLAY */
#line 258 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy271.Flags = yymsp[-1].minor.yy271.Flags | ZCC_Play; yylhsminor.yy271.Replaces = yymsp[-1].minor.yy271.Replaces; }
#line 2646 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,58,&yymsp[0].minor);
  yymsp[-1].minor.yy271 = yylhsminor.yy271;
        break;
      case 21: /* class_flags ::= class_flags REPLACES dottable_id */
#line 259 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy271.Flags = yymsp[-2].minor.yy271.Flags; yylhsminor.yy271.Replaces = yymsp[0].minor.yy311; }
#line 2653 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,59,&yymsp[-1].minor);
  yymsp[-2].minor.yy271 = yylhsminor.yy271;
        break;
      case 22: /* class_flags ::= class_flags VERSION LPAREN STRCONST RPAREN */
#line 260 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy271.Flags = yymsp[-4].minor.yy271.Flags | ZCC_Version; yylhsminor.yy271.Replaces = yymsp[-4].minor.yy271.Replaces; yylhsminor.yy271.Version = yymsp[-1].minor.yy0.String->GetChars(); }
#line 2660 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,60,&yymsp[-3].minor);
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
  yymsp[-4].minor.yy271 = yylhsminor.yy271;
        break;
      case 23: /* dottable_id ::= IDENTIFIER */
      case 40: /*identifier_list ::= IDENTIFIER */ yytestcase(yyruleno==40);
      case 67: /*states_opt ::= IDENTIFIER */ yytestcase(yyruleno==67);
#line 268 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Identifier,id,yymsp[0].minor.yy0);
	id->Id = yymsp[0].minor.yy0.Name();
	yylhsminor.yy311 = id;
}
#line 2675 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy311 = yylhsminor.yy311;
        break;
      case 24: /* dottable_id ::= dottable_id DOT IDENTIFIER */
#line 274 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Identifier,id2,yymsp[-2].minor.yy311);
	id2->Id = yymsp[0].minor.yy0.Name();
	AppendTreeNodeSibling(yymsp[-2].minor.yy311, id2);
	yymsp[-2].minor.yy311 = yymsp[-2].minor.yy311; /*X-overwrites-A*/
}
#line 2686 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,44,&yymsp[-1].minor);
        break;
      case 25: /* dottable_id ::= dottable_id DOT DEFAULT */
#line 281 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Identifier,id2,yymsp[-2].minor.yy311);
	id2->Id = NAME_Default;
	AppendTreeNodeSibling(yymsp[-2].minor.yy311, id2);
	yymsp[-2].minor.yy311 = yymsp[-2].minor.yy311; /*X-overwrites-A*/
}
#line 2697 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,44,&yymsp[-1].minor);
  yy_destructor(yypParser,63,&yymsp[0].minor);
        break;
      case 26: /* dottable_id ::= dottable_id DOT COLOR */
#line 292 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Identifier,id2,yymsp[-2].minor.yy311);
	id2->Id = NAME_Color;
	AppendTreeNodeSibling(yymsp[-2].minor.yy311, id2);
	yymsp[-2].minor.yy311 = yymsp[-2].minor.yy311; /*X-overwrites-A*/
}
#line 2709 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,44,&yymsp[-1].minor);
  yy_destructor(yypParser,64,&yymsp[0].minor);
        break;
      case 27: /* class_body ::= SEMICOLON class_innards EOF */
{  yy_destructor(yypParser,49,&yymsp[-2].minor);
#line 309 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-2].minor.yy392 = yymsp[-1].minor.yy392; /*yymsp[-2].minor.yy392-overwrites-yymsp[-1].minor.yy392*/ }
#line 2717 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,48,&yymsp[0].minor);
}
        break;
      case 28: /* class_body ::= LBRACE class_innards RBRACE */
{  yy_destructor(yypParser,65,&yymsp[-2].minor);
#line 310 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-2].minor.yy392 = yymsp[-1].minor.yy392; /*yymsp[-2].minor.yy392-overwrites-yymsp[-1].minor.yy392*/ }
#line 2725 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
}
        break;
      case 31: /* class_member ::= declarator */
      case 52: /*struct_member ::= declarator */ yytestcase(yyruleno==52);
#line 321 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy392 = yymsp[0].minor.yy401; /*X-overwrites-A*/ }
#line 2733 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 34: /* class_member ::= states_def */
#line 324 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy392 = yymsp[0].minor.yy86; /*X-overwrites-A*/ }
#line 2738 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 35: /* class_member ::= default_def */
#line 325 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy392 = yymsp[0].minor.yy45; /*X-overwrites-A*/ }
#line 2743 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 37: /* class_member ::= property_def */
#line 327 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy392 = yymsp[0].minor.yy291; /*X-overwrites-A*/ }
#line 2748 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 38: /* class_member ::= staticarray_statement */
#line 328 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy392 = yymsp[0].minor.yy82; /*X-overwrites-A*/ }
#line 2753 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 39: /* property_def ::= PROPERTY IDENTIFIER COLON identifier_list SEMICOLON */
#line 340 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Property,def,yymsp[-4].minor.yy0);
	def->NodeName = yymsp[-3].minor.yy0.Name();
	def->Body = yymsp[-1].minor.yy311;
	yylhsminor.yy291 = def;
}
#line 2763 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,14,&yymsp[-2].minor);
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-4].minor.yy291 = yylhsminor.yy291;
        break;
      case 41: /* identifier_list ::= states_opt COMMA IDENTIFIER */
      case 68: /*states_opt ::= states_opt COMMA IDENTIFIER */ yytestcase(yyruleno==68);
#line 355 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Identifier,id,yymsp[0].minor.yy0);
	id->Id = yymsp[0].minor.yy0.Name();
	yymsp[-2].minor.yy311 = yymsp[-2].minor.yy311; /*X-overwrites-A*/
	AppendTreeNodeSibling(yymsp[-2].minor.yy311, id);
}
#line 2777 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 42: /* struct_def ::= STRUCT IDENTIFIER struct_flags LBRACE opt_struct_body RBRACE opt_semicolon */
#line 363 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Struct,def,yymsp[-6].minor.yy0);
	def->NodeName = yymsp[-5].minor.yy0.Name();
	def->Body = yymsp[-2].minor.yy392;
	def->Type = nullptr;
	def->Symbol = nullptr;
	def->Version = yymsp[-4].minor.yy271.Version;
	def->Flags = yymsp[-4].minor.yy271.Flags;
	yylhsminor.yy505 = def;
}
#line 2792 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,65,&yymsp[-3].minor);
  yy_destructor(yypParser,66,&yymsp[-1].minor);
  yymsp[-6].minor.yy505 = yylhsminor.yy505;
        break;
      case 43: /* struct_flags ::= */
#line 375 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy271.Flags = 0; yymsp[1].minor.yy271.Version = {0, 0}; }
#line 2800 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 44: /* struct_flags ::= struct_flags UI */
#line 376 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy271.Flags = yymsp[-1].minor.yy271.Flags | ZCC_UIFlag; }
#line 2805 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,57,&yymsp[0].minor);
  yymsp[-1].minor.yy271 = yylhsminor.yy271;
        break;
      case 45: /* struct_flags ::= struct_flags PLAY */
#line 377 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy271.Flags = yymsp[-1].minor.yy271.Flags | ZCC_Play; }
#line 2812 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,58,&yymsp[0].minor);
  yymsp[-1].minor.yy271 = yylhsminor.yy271;
        break;
      case 46: /* struct_flags ::= struct_flags CLEARSCOPE */
#line 378 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy271.Flags = yymsp[-1].minor.yy271.Flags | ZCC_ClearScope; }
#line 2819 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,69,&yymsp[0].minor);
  yymsp[-1].minor.yy271 = yylhsminor.yy271;
        break;
      case 47: /* struct_flags ::= struct_flags NATIVE */
#line 379 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy271.Flags = yymsp[-1].minor.yy271.Flags | ZCC_Native; }
#line 2826 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,56,&yymsp[0].minor);
  yymsp[-1].minor.yy271 = yylhsminor.yy271;
        break;
      case 48: /* struct_flags ::= struct_flags VERSION LPAREN STRCONST RPAREN */
#line 380 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy271.Flags = yymsp[-4].minor.yy271.Flags | ZCC_Version; yylhsminor.yy271.Version = yymsp[-1].minor.yy0.String->GetChars(); }
#line 2833 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,60,&yymsp[-3].minor);
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
  yymsp[-4].minor.yy271 = yylhsminor.yy271;
        break;
      case 51: /* struct_body ::= struct_body struct_member */
#line 388 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy392 = yymsp[-1].minor.yy392; /*X-overwrites-A*/ AppendTreeNodeSibling(yymsp[-1].minor.yy392, yymsp[0].minor.yy392); }
#line 2842 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 55: /* const_def ::= CONST IDENTIFIER EQ expr SEMICOLON */
#line 397 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ConstantDef,def,yymsp[-4].minor.yy0);
	def->NodeName = yymsp[-3].minor.yy0.Name();
	def->Value = yymsp[-1].minor.yy184;
	def->Symbol = NULL;
	yylhsminor.yy419 = def;
}
#line 2853 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-2].minor);
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-4].minor.yy419 = yylhsminor.yy419;
        break;
      case 56: /* enum_def ::= ENUM IDENTIFIER enum_type LBRACE opt_enum_list RBRACE opt_semicolon */
#line 414 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Enum,def,yymsp[-6].minor.yy0);
	def->NodeName = yymsp[-5].minor.yy0.Name();
	def->EnumType = (EZCCBuiltinType)yymsp[-4].minor.yy0.Int;
	def->Elements = yymsp[-2].minor.yy419;
	def->Symbol = nullptr;

	// If the first element does not have an explicit value, make it 0.
	if (yymsp[-2].minor.yy419 != NULL)
	{
		ZCC_ConstantDef *node = yymsp[-2].minor.yy419, *prev = node;

		if (node->Value == NULL)
		{
			NEW_INTCONST_NODE(zero, TypeSInt32, 0, yymsp[-2].minor.yy419);
			node->Value = zero;
		}
		for (node = static_cast<ZCC_ConstantDef *>(node->SiblingNext);
			node != yymsp[-2].minor.yy419;
			prev = node, node = static_cast<ZCC_ConstantDef *>(node->SiblingNext))
		{
			assert(node->NodeType == AST_ConstantDef);
			// Leave explicit values alone.
			if (node->Value != NULL)
			{
				continue;
			}
			// Compute implicit values by adding one to the preceding value.
			assert(prev->Value != NULL);
			// If the preceding node is a constant, then we can do this now.
			if (prev->Value->Operation == PEX_ConstValue && prev->Value->Type->isInt())
			{
				NEW_INTCONST_NODE(cval, prev->Value->Type, static_cast<ZCC_ExprConstant *>(prev->Value)->IntVal + 1, node);
				node->Value = cval;
			}
			// Otherwise, create a new addition expression to add 1.
			else
			{
				NEW_INTCONST_NODE(one, TypeSInt32, 1, yymsp[-6].minor.yy0);
				NEW_AST_NODE(ExprID, label, node);
				label->Operation = PEX_ID;
				label->Identifier = prev->NodeName;
				label->Type = NULL;

				BINARY_EXPR(label, one, PEX_Add);
				node->Value = expr2;
			}
		}
		// Add a new terminating node, to indicate that the ConstantDefs for this enum are done.
		NEW_AST_NODE(EnumTerminator,term,yymsp[-1].minor.yy0);
		AppendTreeNodeSibling(yymsp[-2].minor.yy419, term);
	}
	if (yymsp[-2].minor.yy419 != NULL)
	{
		AppendTreeNodeSibling(def, yymsp[-2].minor.yy419);
	}
	yylhsminor.yy245 = def;
}
#line 2918 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,65,&yymsp[-3].minor);
  yymsp[-6].minor.yy245 = yylhsminor.yy245;
        break;
      case 57: /* enum_type ::= */
#line 473 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy0.Int = ZCC_IntAuto; yymsp[1].minor.yy0.SourceLoc = stat->sc->GetMessageLine(); }
#line 2925 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 58: /* enum_type ::= COLON int_type */
{  yy_destructor(yypParser,14,&yymsp[-1].minor);
#line 474 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy0 = yymsp[0].minor.yy0; /*yymsp[-1].minor.yy0-overwrites-yymsp[0].minor.yy0*/ }
#line 2931 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
}
        break;
      case 59: /* enum_list ::= error */
#line 476 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy419 = NULL; }
#line 2937 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 60: /* enum_list ::= enum_list COMMA enumerator */
#line 478 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-2].minor.yy419 = yymsp[-2].minor.yy419; /*X-overwrites-A*/ AppendTreeNodeSibling(yymsp[-2].minor.yy419, yymsp[0].minor.yy419); }
#line 2942 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 61: /* opt_enum_list ::= */
#line 480 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy419 = NULL; }
#line 2948 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 62: /* enumerator ::= IDENTIFIER */
#line 484 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ConstantDef,node,yymsp[0].minor.yy0);
	node->NodeName = yymsp[0].minor.yy0.Name();
	node->Value = NULL;
	node->Symbol = NULL;
	yylhsminor.yy419 = node;
}
#line 2959 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy419 = yylhsminor.yy419;
        break;
      case 63: /* enumerator ::= IDENTIFIER EQ expr */
#line 492 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ConstantDef,node,yymsp[-2].minor.yy0);
	node->NodeName = yymsp[-2].minor.yy0.Name();
	node->Value = yymsp[0].minor.yy184;
	node->Symbol = NULL;
	yylhsminor.yy419 = node;
}
#line 2971 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-1].minor);
  yymsp[-2].minor.yy419 = yylhsminor.yy419;
        break;
      case 64: /* states_def ::= STATES states_opts scanner_mode LBRACE states_body RBRACE */
#line 517 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(States,def,yymsp[-5].minor.yy0);
	def->Flags = yymsp[-4].minor.yy311;
	def->Body = yymsp[-1].minor.yy188;
	yylhsminor.yy86 = def;
}
#line 2983 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,65,&yymsp[-2].minor);
  yy_destructor(yypParser,66,&yymsp[0].minor);
  yymsp[-5].minor.yy86 = yylhsminor.yy86;
        break;
      case 65: /* states_opts ::= */
#line 524 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy311 = nullptr; }
#line 2991 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 66: /* states_opts ::= LPAREN states_opt RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-2].minor);
#line 525 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-2].minor.yy311 = yymsp[-1].minor.yy311; /*yymsp[-2].minor.yy311-overwrites-yymsp[-1].minor.yy311*/ }
#line 2997 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,62,&yymsp[0].minor);
}
        break;
      case 69: /* scanner_mode ::= */
#line 554 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ stat->sc->SetStateMode(true); }
#line 3004 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 70: /* states_body ::= */
#line 556 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy188 = NULL; }
#line 3009 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 71: /* states_body ::= error */
#line 557 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy188 = NULL; }
#line 3014 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 72: /* states_body ::= states_body state_line */
      case 73: /*states_body ::= states_body state_label */ yytestcase(yyruleno==73);
      case 74: /*states_body ::= states_body state_flow */ yytestcase(yyruleno==74);
#line 558 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ SAFE_APPEND(yymsp[-1].minor.yy188,yymsp[0].minor.yy188); }
#line 3021 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 75: /* state_label ::= NWS COLON */
#line 563 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(StateLabel, label, yymsp[-1].minor.yy0);
	label->Label = yymsp[-1].minor.yy0.Name();
	yylhsminor.yy188 = label;
}
#line 3030 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,14,&yymsp[0].minor);
  yymsp[-1].minor.yy188 = yylhsminor.yy188;
        break;
      case 76: /* state_flow_type ::= STOP */
#line 571 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ NEW_AST_NODE(StateStop, flow, yymsp[0].minor.yy0); yylhsminor.yy188 = flow; }
#line 3037 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy188 = yylhsminor.yy188;
        break;
      case 77: /* state_flow_type ::= WAIT */
#line 572 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ NEW_AST_NODE(StateWait, flow, yymsp[0].minor.yy0); yylhsminor.yy188 = flow; }
#line 3043 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy188 = yylhsminor.yy188;
        break;
      case 78: /* state_flow_type ::= FAIL */
#line 573 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ NEW_AST_NODE(StateFail, flow, yymsp[0].minor.yy0); yylhsminor.yy188 = flow; }
#line 3049 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy188 = yylhsminor.yy188;
        break;
      case 79: /* state_flow_type ::= LOOP */
#line 574 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ NEW_AST_NODE(StateLoop, flow, yymsp[0].minor.yy0); yylhsminor.yy188 = flow; }
#line 3055 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy188 = yylhsminor.yy188;
        break;
      case 80: /* state_flow_type ::= GOTO dottable_id state_goto_offset */
#line 576 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(StateGoto, flow, yymsp[-2].minor.yy0);
	flow->Label = yymsp[-1].minor.yy311;
	flow->Offset = yymsp[0].minor.yy184;
	flow->Qualifier = nullptr;
	yylhsminor.yy188 = flow;
}
#line 3067 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[-2].minor.yy188 = yylhsminor.yy188;
        break;
      case 81: /* state_flow_type ::= GOTO IDENTIFIER SCOPE dottable_id state_goto_offset */
#line 585 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(StateGoto, flow, yymsp[-4].minor.yy0);
	flow->Label = yymsp[-1].minor.yy311;
	flow->Offset = yymsp[0].minor.yy184;

	NEW_AST_NODE(Identifier,id,yymsp[-3].minor.yy0);
	id->Id = yymsp[-3].minor.yy0.Name();
	flow->Qualifier =id;
	yylhsminor.yy188 = flow;
}
#line 3082 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,47,&yymsp[-2].minor);
  yymsp[-4].minor.yy188 = yylhsminor.yy188;
        break;
      case 82: /* state_flow_type ::= GOTO SUPER SCOPE dottable_id state_goto_offset */
#line 597 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(StateGoto, flow, yymsp[-4].minor.yy0);
	flow->Label = yymsp[-1].minor.yy311;
	flow->Offset = yymsp[0].minor.yy184;

	NEW_AST_NODE(Identifier,id,yymsp[-3].minor.yy0);
	id->Id = NAME_Super;
	flow->Qualifier =id;
	yylhsminor.yy188 = flow;
}
#line 3098 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,47,&yymsp[-2].minor);
  yymsp[-4].minor.yy188 = yylhsminor.yy188;
        break;
      case 83: /* state_goto_offset ::= */
#line 608 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy184 = NULL; }
#line 3105 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 84: /* state_goto_offset ::= ADD expr */
{  yy_destructor(yypParser,34,&yymsp[-1].minor);
#line 609 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy184 = yymsp[0].minor.yy184; /*yymsp[-1].minor.yy184-overwrites-yymsp[0].minor.yy184*/ }
#line 3111 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
}
        break;
      case 85: /* state_line ::= NWS NWS expr state_opts state_action */
#line 612 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(StateLine, line, yymsp[-4].minor.yy0);
	line->Sprite = stat->Strings.Alloc(FName(yymsp[-4].minor.yy0.Name()).GetChars());
	line->Frames = stat->Strings.Alloc(FName(yymsp[-3].minor.yy0.Name()).GetChars());
	line->Duration = yymsp[-2].minor.yy184;
	line->bBright = yymsp[-1].minor.yy72.Bright;
	line->bFast = yymsp[-1].minor.yy72.Fast;
	line->bSlow = yymsp[-1].minor.yy72.Slow;
	line->bNoDelay = yymsp[-1].minor.yy72.NoDelay;
	line->bCanRaise = yymsp[-1].minor.yy72.CanRaise;
	line->Offset = yymsp[-1].minor.yy72.Offset;
	line->Lights = yymsp[-1].minor.yy72.Lights;
	line->Action = yymsp[0].minor.yy392;
	yylhsminor.yy188 = line;
}
#line 3131 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[-4].minor.yy188 = yylhsminor.yy188;
        break;
      case 86: /* state_opts ::= */
#line 628 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ StateOpts opts; opts.Zero(); yymsp[1].minor.yy72 = opts; }
#line 3137 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 87: /* state_opts ::= state_opts BRIGHT */
#line 629 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy72.Bright = true; yymsp[-1].minor.yy72 = yymsp[-1].minor.yy72; /*X-overwrites-A*/ }
#line 3142 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,80,&yymsp[0].minor);
        break;
      case 88: /* state_opts ::= state_opts FAST */
#line 630 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy72.Fast = true; yymsp[-1].minor.yy72 = yymsp[-1].minor.yy72; /*X-overwrites-A*/ }
#line 3148 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,81,&yymsp[0].minor);
        break;
      case 89: /* state_opts ::= state_opts SLOW */
#line 631 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy72.Slow = true; yymsp[-1].minor.yy72 = yymsp[-1].minor.yy72; /*X-overwrites-A*/ }
#line 3154 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,82,&yymsp[0].minor);
        break;
      case 90: /* state_opts ::= state_opts NODELAY */
#line 632 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy72.NoDelay = true; yymsp[-1].minor.yy72 = yymsp[-1].minor.yy72; /*X-overwrites-A*/ }
#line 3160 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,83,&yymsp[0].minor);
        break;
      case 91: /* state_opts ::= state_opts CANRAISE */
#line 633 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy72.CanRaise = true; yymsp[-1].minor.yy72 = yymsp[-1].minor.yy72; /*X-overwrites-A*/ }
#line 3166 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,84,&yymsp[0].minor);
        break;
      case 92: /* state_opts ::= state_opts OFFSET LPAREN expr COMMA expr RPAREN */
#line 634 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-6].minor.yy72.Offset = yymsp[-3].minor.yy184; AppendTreeNodeSibling(yymsp[-3].minor.yy184, yymsp[-1].minor.yy184); yymsp[-6].minor.yy72 = yymsp[-6].minor.yy72; /*X-overwrites-A*/ }
#line 3172 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,85,&yymsp[-5].minor);
  yy_destructor(yypParser,45,&yymsp[-4].minor);
  yy_destructor(yypParser,50,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
        break;
      case 93: /* state_opts ::= state_opts LIGHT LPAREN light_list RPAREN */
#line 635 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-4].minor.yy72 = yymsp[-4].minor.yy72; /*X-overwrites-A*/ yymsp[-4].minor.yy72.Lights = yymsp[-1].minor.yy273; }
#line 3181 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,86,&yymsp[-3].minor);
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
        break;
      case 94: /* light_list ::= STRCONST */
      case 257: /*string_constant ::= STRCONST */ yytestcase(yyruleno==257);
#line 640 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprConstant, strconst, yymsp[0].minor.yy0);
	strconst->Operation = PEX_ConstValue;
	strconst->Type = TypeString;
	strconst->StringVal = yymsp[0].minor.yy0.String;
	yylhsminor.yy273 = strconst;
}
#line 3196 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy273 = yylhsminor.yy273;
        break;
      case 95: /* light_list ::= light_list COMMA STRCONST */
#line 649 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprConstant, strconst, yymsp[0].minor.yy0);
	strconst->Operation = PEX_ConstValue;
	strconst->Type = TypeString;
	strconst->StringVal = yymsp[0].minor.yy0.String;
	AppendTreeNodeSibling(yymsp[-2].minor.yy273, strconst); 
	yymsp[-2].minor.yy273 = yymsp[-2].minor.yy273; /*X-overwrites-A*/
}
#line 3209 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 96: /* state_action ::= LBRACE statement_list scanner_mode RBRACE */
#line 660 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(CompoundStmt,stmt,yymsp[-3].minor.yy0);
	stmt->Content = yymsp[-2].minor.yy367;
	yylhsminor.yy392 = stmt;
}
#line 3219 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
  yymsp[-3].minor.yy392 = yylhsminor.yy392;
        break;
      case 97: /* state_action ::= LBRACE scanner_mode RBRACE */
{  yy_destructor(yypParser,65,&yymsp[-2].minor);
#line 666 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	yymsp[-2].minor.yy392 = NULL;
}
#line 3229 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
}
        break;
      case 98: /* state_action ::= LBRACE error scanner_mode RBRACE */
{  yy_destructor(yypParser,65,&yymsp[-3].minor);
#line 669 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-3].minor.yy392 = NULL; }
#line 3237 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
}
        break;
      case 99: /* state_action ::= state_call scanner_mode SEMICOLON */
#line 670 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-2].minor.yy392 = yymsp[-2].minor.yy31; /*X-overwrites-A*/ }
#line 3244 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
        break;
      case 100: /* state_call ::= */
#line 672 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy31 = NULL; }
#line 3250 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 101: /* state_call ::= IDENTIFIER state_call_params */
#line 674 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprFuncCall, expr, yymsp[-1].minor.yy0);
	NEW_AST_NODE(ExprID, func, yymsp[-1].minor.yy0);

	func->Operation = PEX_ID;
	func->Identifier = yymsp[-1].minor.yy0.Name();
	expr->Operation = PEX_FuncCall;
	expr->Function = func;
	expr->Parameters = yymsp[0].minor.yy470;
	yylhsminor.yy31 = expr;
}
#line 3265 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[-1].minor.yy31 = yylhsminor.yy31;
        break;
      case 102: /* state_call_params ::= */
#line 686 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy470 = NULL; }
#line 3271 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 103: /* state_call_params ::= LPAREN func_expr_list RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-2].minor);
#line 687 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-2].minor.yy470 = yymsp[-1].minor.yy470; /*yymsp[-2].minor.yy470-overwrites-yymsp[-1].minor.yy470*/ }
#line 3277 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,62,&yymsp[0].minor);
}
        break;
      case 104: /* default_def ::= DEFAULT LBRACE RBRACE */
{  yy_destructor(yypParser,63,&yymsp[-2].minor);
#line 695 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Default,stmt,yymsp[-1].minor.yy0);
	stmt->Content = NULL;
	yymsp[-2].minor.yy45 = stmt;
}
#line 3289 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
}
        break;
      case 105: /* default_def ::= DEFAULT LBRACE default_statement_list RBRACE */
{  yy_destructor(yypParser,63,&yymsp[-3].minor);
#line 701 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Default,stmt,yymsp[-2].minor.yy0);
	stmt->Content = yymsp[-1].minor.yy367;
	yymsp[-3].minor.yy45 = stmt;
}
#line 3301 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
}
        break;
      case 106: /* default_def ::= DEFAULT LBRACE error RBRACE */
{  yy_destructor(yypParser,63,&yymsp[-3].minor);
#line 707 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Default,stmt,yymsp[-2].minor.yy0);
	stmt->Content = NULL;
	yymsp[-3].minor.yy45 = stmt;
}
#line 3313 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
}
        break;
      case 107: /* default_statement_list ::= default_statement */
      case 283: /*statement_list ::= statement */ yytestcase(yyruleno==283);
#line 714 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	yymsp[0].minor.yy367 = yymsp[0].minor.yy367; /*X-overwrites-A*/
}
#line 3323 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 108: /* default_statement_list ::= default_statement_list default_statement */
      case 284: /*statement_list ::= statement_list statement */ yytestcase(yyruleno==284);
#line 718 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	SAFE_APPEND(yymsp[-1].minor.yy367,yymsp[0].minor.yy367);
}
#line 3331 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 109: /* default_statement ::= SEMICOLON */
      case 266: /*statement ::= SEMICOLON */ yytestcase(yyruleno==266);
{  yy_destructor(yypParser,49,&yymsp[0].minor);
#line 723 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy367 = NULL; }
#line 3338 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
}
        break;
      case 110: /* default_statement ::= error SEMICOLON */
      case 272: /*statement ::= error SEMICOLON */ yytestcase(yyruleno==272);
#line 724 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy367 = NULL; }
#line 3345 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
        break;
      case 111: /* default_statement ::= property_statement */
#line 726 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy367 = yymsp[0].minor.yy447; /*X-overwrites-A*/ }
#line 3351 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 112: /* default_statement ::= flag_statement */
#line 727 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy367 = yymsp[0].minor.yy60; /*X-overwrites-A*/ }
#line 3356 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 113: /* flag_statement ::= ADD dottable_id */
{  yy_destructor(yypParser,34,&yymsp[-1].minor);
#line 732 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(FlagStmt, type, yymsp[0].minor.yy311);
	type->set = true;
	type->name = yymsp[0].minor.yy311;
	yymsp[-1].minor.yy60 = type;
}
#line 3367 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
}
        break;
      case 114: /* flag_statement ::= SUB dottable_id */
{  yy_destructor(yypParser,33,&yymsp[-1].minor);
#line 739 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(FlagStmt, type, yymsp[0].minor.yy311);
	type->set = false;
	type->name = yymsp[0].minor.yy311;
	yymsp[-1].minor.yy60 = type;
}
#line 3379 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
}
        break;
      case 115: /* property_statement ::= dottable_id expr_list SEMICOLON */
#line 749 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(PropertyStmt,stmt,yymsp[-2].minor.yy311);
	stmt->Prop = yymsp[-2].minor.yy311;
	stmt->Values = yymsp[-1].minor.yy184;
	yylhsminor.yy447 = stmt;
}
#line 3390 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-2].minor.yy447 = yylhsminor.yy447;
        break;
      case 116: /* property_statement ::= dottable_id SEMICOLON */
#line 757 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(PropertyStmt,stmt,yymsp[-1].minor.yy311);
	stmt->Prop = yymsp[-1].minor.yy311;
	stmt->Values = nullptr;
	yylhsminor.yy447 = stmt;
}
#line 3402 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-1].minor.yy447 = yylhsminor.yy447;
        break;
      case 117: /* int_type ::= SBYTE */
#line 769 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_SInt8; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3409 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 118: /* int_type ::= BYTE */
#line 770 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_UInt8; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3415 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 119: /* int_type ::= SHORT */
#line 771 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_SInt16; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3421 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 120: /* int_type ::= USHORT */
#line 772 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_UInt16; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3427 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 121: /* int_type ::= INT */
#line 773 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_SInt32; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3433 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 122: /* int_type ::= UINT */
#line 774 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_UInt32; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3439 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 123: /* type_name1 ::= BOOL */
#line 776 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Bool; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3445 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 124: /* type_name1 ::= FLOAT */
#line 778 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_FloatAuto; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3451 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 125: /* type_name1 ::= DOUBLE */
#line 779 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Float64; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3457 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 126: /* type_name1 ::= VECTOR2 */
#line 781 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Vector2; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3463 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 127: /* type_name1 ::= VECTOR3 */
#line 782 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Vector3; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3469 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 128: /* type_name1 ::= NAME */
#line 783 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Name; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3475 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 129: /* type_name1 ::= SOUND */
#line 784 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Sound; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3481 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 130: /* type_name1 ::= STATE */
#line 785 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_State; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3487 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 131: /* type_name1 ::= COLOR */
#line 786 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Color; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3493 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 132: /* type_name1 ::= LET */
#line 787 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Let; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3499 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 133: /* type_name ::= type_name1 */
#line 790 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(BasicType, type, yymsp[0].minor.yy0);
	type->Type = (EZCCBuiltinType)yymsp[0].minor.yy0.Int;
	type->UserType = NULL;
	type->isconst = false;
	yylhsminor.yy116 = type;
}
#line 3511 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy116 = yylhsminor.yy116;
        break;
      case 134: /* type_name ::= IDENTIFIER */
#line 798 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(BasicType, type, yymsp[0].minor.yy0);
	NEW_AST_NODE(Identifier, id, yymsp[0].minor.yy0);
	type->Type = ZCC_UserType;
	type->UserType = id;
	type->isconst = false;
	id->Id = yymsp[0].minor.yy0.Name();
	yylhsminor.yy116 = type;
}
#line 3525 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy116 = yylhsminor.yy116;
        break;
      case 135: /* type_name ::= ATSIGN IDENTIFIER */
{  yy_destructor(yypParser,102,&yymsp[-1].minor);
#line 809 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(BasicType, type, yymsp[0].minor.yy0);
	NEW_AST_NODE(Identifier, id, yymsp[0].minor.yy0);
	type->Type = ZCC_NativeType;
	type->UserType = id;
	type->isconst = false;
	id->Id = yymsp[0].minor.yy0.Name();
	yymsp[-1].minor.yy116 = type;
}
#line 3540 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
}
        break;
      case 136: /* type_name ::= READONLY LT IDENTIFIER GT */
{  yy_destructor(yypParser,103,&yymsp[-3].minor);
#line 820 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(BasicType, type, yymsp[-1].minor.yy0);
	NEW_AST_NODE(Identifier, id, yymsp[-1].minor.yy0);
	type->Type = ZCC_UserType;
	type->UserType = id;
	type->isconst = true;
	id->Id = yymsp[-1].minor.yy0.Name();
	yymsp[-3].minor.yy116 = type;
}
#line 3555 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,20,&yymsp[-2].minor);
  yy_destructor(yypParser,21,&yymsp[0].minor);
}
        break;
      case 137: /* type_name ::= READONLY LT ATSIGN IDENTIFIER GT */
{  yy_destructor(yypParser,103,&yymsp[-4].minor);
#line 831 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(BasicType, type, yymsp[-1].minor.yy0);
	NEW_AST_NODE(Identifier, id, yymsp[-1].minor.yy0);
	type->Type = ZCC_NativeType;
	type->UserType = id;
	type->isconst = true;
	id->Id = yymsp[-1].minor.yy0.Name();
	yymsp[-4].minor.yy116 = type;
}
#line 3572 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,20,&yymsp[-3].minor);
  yy_destructor(yypParser,102,&yymsp[-2].minor);
  yy_destructor(yypParser,21,&yymsp[0].minor);
}
        break;
      case 138: /* type_name ::= DOT dottable_id */
{  yy_destructor(yypParser,44,&yymsp[-1].minor);
#line 842 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(BasicType, type, yymsp[0].minor.yy311);
	type->Type = ZCC_UserType;
	type->UserType = yymsp[0].minor.yy311;
	type->isconst = false;
	yymsp[-1].minor.yy116 = type;
}
#line 3588 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
}
        break;
      case 139: /* aggregate_type ::= MAP LT type_or_array COMMA type_or_array GT */
#line 866 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(MapType,map,yymsp[-5].minor.yy0);
	map->KeyType = yymsp[-3].minor.yy130;
	map->ValueType = yymsp[-1].minor.yy130;
	yylhsminor.yy130 = map;
}
#line 3599 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,20,&yymsp[-4].minor);
  yy_destructor(yypParser,50,&yymsp[-2].minor);
  yy_destructor(yypParser,21,&yymsp[0].minor);
  yymsp[-5].minor.yy130 = yylhsminor.yy130;
        break;
      case 140: /* aggregate_type ::= ARRAY LT type_or_array GT */
#line 874 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(DynArrayType,arr,yymsp[-3].minor.yy0);
	arr->ElementType = yymsp[-1].minor.yy130;
	yylhsminor.yy130 = arr;
}
#line 3612 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,20,&yymsp[-2].minor);
  yy_destructor(yypParser,21,&yymsp[0].minor);
  yymsp[-3].minor.yy130 = yylhsminor.yy130;
        break;
      case 141: /* aggregate_type ::= CLASS class_restrictor */
#line 881 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ClassType,cls,yymsp[-1].minor.yy0);
	cls->Restriction = yymsp[0].minor.yy311;
	yylhsminor.yy130 = cls;
}
#line 3624 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[-1].minor.yy130 = yylhsminor.yy130;
        break;
      case 143: /* class_restrictor ::= LT dottable_id GT */
{  yy_destructor(yypParser,20,&yymsp[-2].minor);
#line 887 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-2].minor.yy311 = yymsp[-1].minor.yy311; /*yymsp[-2].minor.yy311-overwrites-yymsp[-1].minor.yy311*/ }
#line 3631 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,21,&yymsp[0].minor);
}
        break;
      case 144: /* type ::= type_name */
#line 889 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy130 = yymsp[0].minor.yy116; /*X-overwrites-A*/ yymsp[0].minor.yy130->ArraySize = NULL; }
#line 3638 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 145: /* type ::= aggregate_type */
#line 890 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy130 = yymsp[0].minor.yy130; /*X-overwrites-A*/ yymsp[0].minor.yy130->ArraySize = NULL; }
#line 3643 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 146: /* type_or_array ::= type array_size */
#line 893 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy130 = yymsp[-1].minor.yy130; /*X-overwrites-A*/ yymsp[-1].minor.yy130->ArraySize = yymsp[0].minor.yy184; }
#line 3648 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 147: /* type_list ::= type_list COMMA type_or_array */
#line 896 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-2].minor.yy130 = yymsp[-2].minor.yy130; /*X-overwrites-A*/ AppendTreeNodeSibling(yymsp[-2].minor.yy130, yymsp[0].minor.yy130); }
#line 3653 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 148: /* type_list_or_void ::= VOID */
{  yy_destructor(yypParser,107,&yymsp[0].minor);
#line 898 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy130 = NULL; }
#line 3660 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
}
        break;
      case 149: /* array_size_expr ::= LBRACKET opt_expr RBRACKET */
#line 902 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	if (yymsp[-1].minor.yy184 == NULL)
	{
		NEW_AST_NODE(Expression,nil,yymsp[-2].minor.yy0.SourceLoc);
		nil->Operation = PEX_Nil;
		nil->Type = NULL;
		yylhsminor.yy184 = nil;
	}
	else
	{
		yylhsminor.yy184 = yymsp[-1].minor.yy184;
	}
}
#line 3678 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,112,&yymsp[0].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 150: /* array_size ::= array_size array_size_expr */
#line 917 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	AppendTreeNodeSibling(yymsp[-1].minor.yy184, yymsp[0].minor.yy184);
	yymsp[-1].minor.yy184 = yymsp[-1].minor.yy184; /*X-overwrites-A*/
}
#line 3688 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 151: /* declarator ::= decl_flags type_list_or_void variables_or_function */
#line 926 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	if (yymsp[0].minor.yy372.FuncName == NAME_None && yymsp[0].minor.yy372.VarNames == NULL)
	{ // An error. yymsp[-2].minor.yy491 message was already printed.
		yylhsminor.yy401 = NULL;
	}
	else if (yymsp[0].minor.yy372.FuncName != NAME_None)
	{ // yymsp[-2].minor.yy491 function
		NEW_AST_NODE(FuncDeclarator, decl, yymsp[-2].minor.yy491 == nullptr? yymsp[0].minor.yy372.SourceLoc : yymsp[-2].minor.yy491->SourceLoc);
		decl->Type = yymsp[-1].minor.yy130;
		decl->Params = yymsp[0].minor.yy372.FuncParams;
		decl->Name = yymsp[0].minor.yy372.FuncName;
		decl->UseFlags = yymsp[-2].minor.yy491 == nullptr? nullptr : yymsp[-2].minor.yy491->Id;
		decl->Flags = (yymsp[-2].minor.yy491 == nullptr? 0 : yymsp[-2].minor.yy491->Flags) | yymsp[0].minor.yy372.FuncFlags;
		if (yymsp[-2].minor.yy491 == nullptr) decl->Version = {0,0,0};
		else decl->Version = yymsp[-2].minor.yy491->Version;

		decl->Body = yymsp[0].minor.yy372.FuncBody;
		yylhsminor.yy401 = decl;
	}
	else if (yymsp[-1].minor.yy130 != NULL && yymsp[-1].minor.yy130->SiblingNext == yymsp[-1].minor.yy130)
	{ // yymsp[-2].minor.yy491 variable
		NEW_AST_NODE(VarDeclarator, decl, yymsp[-2].minor.yy491 == nullptr? yymsp[-1].minor.yy130->SourceLoc : yymsp[-2].minor.yy491->SourceLoc);
		decl->Type = yymsp[-1].minor.yy130;
		decl->Names = yymsp[0].minor.yy372.VarNames;
		if (yymsp[-2].minor.yy491 == nullptr)
		{
			decl->Flags = 0;
			decl->Version = {0,0,0};
		}
		else
		{
			decl->Flags = yymsp[-2].minor.yy491->Flags;
			decl->Version = yymsp[-2].minor.yy491->Version;
		}
		yylhsminor.yy401 = decl;
	}
	else
	{ // An invalid
		if (yymsp[-1].minor.yy130 == NULL)
		{
			stat->sc->ScriptMessage("Variables may not be of type void.\n");
		}
		else
		{
			stat->sc->ScriptMessage("Variables may be of only one type.\n");
		}
		yylhsminor.yy401 = NULL;
	}
}
#line 3741 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[-2].minor.yy401 = yylhsminor.yy401;
        break;
      case 152: /* variables_or_function ::= IDENTIFIER LPAREN func_params RPAREN func_const opt_func_body */
#line 978 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	VarOrFun fun;

	fun.VarNames = NULL;
	fun.FuncParams = yymsp[-3].minor.yy49;
	fun.FuncFlags = yymsp[-1].minor.yy0.Int;
	fun.FuncName = yymsp[-5].minor.yy0.Name();
	fun.FuncBody = yymsp[0].minor.yy215;
	fun.SourceLoc = yymsp[-5].minor.yy0.SourceLoc;
	yylhsminor.yy372 = fun;
}
#line 3757 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-4].minor);
  yy_destructor(yypParser,62,&yymsp[-2].minor);
  yymsp[-5].minor.yy372 = yylhsminor.yy372;
        break;
      case 153: /* variables_or_function ::= variable_list SEMICOLON */
#line 990 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	VarOrFun var;

	var.VarNames = yymsp[-1].minor.yy393;
	var.FuncParams = NULL;
	var.FuncFlags = 0;
	var.FuncName = NAME_None;
	var.FuncBody = NULL;
	var.SourceLoc = yymsp[-1].minor.yy393->SourceLoc;
	yylhsminor.yy372 = var;
}
#line 3775 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-1].minor.yy372 = yylhsminor.yy372;
        break;
      case 154: /* variables_or_function ::= error SEMICOLON */
#line 1002 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	VarOrFun bad;
	bad.VarNames = NULL;
	bad.FuncParams = NULL;
	bad.FuncFlags = 0;
	bad.FuncName = NAME_None;
	bad.FuncBody = NULL;
	bad.SourceLoc = yymsp[0].minor.yy0.SourceLoc;
	yymsp[-1].minor.yy372 = bad;
}
#line 3791 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 155: /* variable_name ::= IDENTIFIER */
#line 1019 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(VarName,var,yymsp[0].minor.yy0);
	var->Name = ENamedName(yymsp[0].minor.yy0.Int);
	var->ArraySize = NULL;
	yylhsminor.yy393 = var;
}
#line 3801 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy393 = yylhsminor.yy393;
        break;
      case 156: /* variable_name ::= IDENTIFIER array_size */
#line 1026 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(VarName,var,yymsp[-1].minor.yy0);
	var->Name = ENamedName(yymsp[-1].minor.yy0.Int);
	var->ArraySize = yymsp[0].minor.yy184;
	yylhsminor.yy393 = var;
}
#line 3812 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[-1].minor.yy393 = yylhsminor.yy393;
        break;
      case 157: /* variable_list ::= variable_list COMMA variable_name */
#line 1035 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	AppendTreeNodeSibling(yymsp[-2].minor.yy393, yymsp[0].minor.yy393);
	yymsp[-2].minor.yy393 = yymsp[-2].minor.yy393; /*X-overwrites-A*/
}
#line 3821 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 158: /* decl_flags ::= */
#line 1041 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy491 = NULL; }
#line 3827 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 159: /* decl_flags ::= decl_flags decl_flag */
#line 1043 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	if (yymsp[-1].minor.yy491 == nullptr)
	{
		NEW_AST_NODE(DeclFlags,nil_f,yymsp[0].minor.yy0);
		yylhsminor.yy491 = nil_f;
		yylhsminor.yy491->Id = nullptr;
		yylhsminor.yy491->Flags = yymsp[0].minor.yy0.Int;
		yylhsminor.yy491->Version = { 0, 0 };
	}
	else
	{
		yylhsminor.yy491 = yymsp[-1].minor.yy491;
		yylhsminor.yy491->Flags |= yymsp[0].minor.yy0.Int;
	}
}
#line 3846 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[-1].minor.yy491 = yylhsminor.yy491;
        break;
      case 160: /* decl_flags ::= decl_flags ACTION states_opts */
#line 1061 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	if (yymsp[-2].minor.yy491 == nullptr)
	{
		NEW_AST_NODE(DeclFlags,nil_f,yymsp[-1].minor.yy0.SourceLoc);
		yylhsminor.yy491 = nil_f;
		yylhsminor.yy491->Flags = ZCC_Action;
		yylhsminor.yy491->Id = nullptr;
		yylhsminor.yy491->Version = { 0, 0 };
	}
	else
	{
		yylhsminor.yy491 = yymsp[-2].minor.yy491;
		yylhsminor.yy491->Flags |= ZCC_Action;
	}
	yylhsminor.yy491->Id = yymsp[0].minor.yy311;
}
#line 3867 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[-2].minor.yy491 = yylhsminor.yy491;
        break;
      case 161: /* decl_flags ::= decl_flags DEPRECATED LPAREN STRCONST RPAREN */
#line 1079 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ 
	if (yymsp[-4].minor.yy491 == nullptr)
	{
		NEW_AST_NODE(DeclFlags,nil_f,yymsp[-3].minor.yy0.SourceLoc);
		yylhsminor.yy491 = nil_f;
		yylhsminor.yy491->Flags = ZCC_Deprecated;
		yylhsminor.yy491->Id = nullptr;
		yylhsminor.yy491->Version = { 0, 0 };
	}
	else
	{
		yylhsminor.yy491 = yymsp[-4].minor.yy491;
		yylhsminor.yy491->Flags |= ZCC_Deprecated;
	}
	yylhsminor.yy491->Version = yymsp[-1].minor.yy0.String->GetChars();
}
#line 3888 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
  yymsp[-4].minor.yy491 = yylhsminor.yy491;
        break;
      case 162: /* decl_flags ::= decl_flags VERSION LPAREN STRCONST RPAREN */
#line 1097 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ 
	if (yymsp[-4].minor.yy491 == nullptr)
	{
		NEW_AST_NODE(DeclFlags,nil_f,yymsp[-3].minor.yy0.SourceLoc);
		yylhsminor.yy491 = nil_f;
		yylhsminor.yy491->Flags = ZCC_Version;
		yylhsminor.yy491->Id = nullptr;
		yylhsminor.yy491->Version = { 0, 0 };
	}
	else
	{
		yylhsminor.yy491 = yymsp[-4].minor.yy491;
		yylhsminor.yy491->Flags |= ZCC_Version;
	}
	yylhsminor.yy491->Version = yymsp[-1].minor.yy0.String->GetChars();
}
#line 3911 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
  yymsp[-4].minor.yy491 = yylhsminor.yy491;
        break;
      case 163: /* decl_flag ::= NATIVE */
#line 1114 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Native; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 3919 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 164: /* decl_flag ::= STATIC */
#line 1115 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Static; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 3925 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 165: /* decl_flag ::= PRIVATE */
#line 1116 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Private; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 3931 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 166: /* decl_flag ::= PROTECTED */
#line 1117 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Protected; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 3937 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 167: /* decl_flag ::= LATENT */
#line 1118 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Latent; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 3943 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 168: /* decl_flag ::= FINAL */
#line 1119 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Final; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 3949 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 169: /* decl_flag ::= META */
#line 1120 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Meta; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 3955 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 170: /* decl_flag ::= TRANSIENT */
#line 1121 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Transient; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 3961 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 171: /* decl_flag ::= READONLY */
#line 1122 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_ReadOnly; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 3967 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 172: /* decl_flag ::= VIRTUAL */
#line 1123 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Virtual; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 3973 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 173: /* decl_flag ::= OVERRIDE */
#line 1124 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Override; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 3979 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 174: /* decl_flag ::= VARARG */
#line 1125 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_VarArg; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3985 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 175: /* decl_flag ::= UI */
#line 1126 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_UIFlag; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3991 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 176: /* decl_flag ::= PLAY */
#line 1127 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Play; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3997 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 177: /* decl_flag ::= CLEARSCOPE */
#line 1128 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_ClearScope; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 4003 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 178: /* decl_flag ::= VIRTUALSCOPE */
#line 1129 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_VirtualScope; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 4009 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 179: /* func_const ::= */
#line 1131 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy0.Int = 0; yymsp[1].minor.yy0.SourceLoc = stat->sc->GetMessageLine(); }
#line 4015 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 180: /* func_const ::= CONST */
#line 1132 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_FuncConst; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 4020 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 181: /* opt_func_body ::= SEMICOLON */
{  yy_destructor(yypParser,49,&yymsp[0].minor);
#line 1134 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy215 = NULL; }
#line 4027 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
}
        break;
      case 182: /* func_params ::= */
#line 1141 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy49 = NULL; }
#line 4033 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 183: /* func_params ::= VOID */
{  yy_destructor(yypParser,107,&yymsp[0].minor);
#line 1142 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy49 = NULL; }
#line 4039 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
}
        break;
      case 184: /* func_params ::= func_param_list COMMA ELLIPSIS */
#line 1146 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(FuncParamDecl,parm,stat->sc->GetMessageLine());
	parm->Type = nullptr;
	parm->Name = NAME_None;
	parm->Flags = 0;
	parm->Default = nullptr;
	yymsp[-2].minor.yy49 = yymsp[-2].minor.yy49; /*X-overwrites-A*/ 
	AppendTreeNodeSibling(yymsp[-2].minor.yy49, parm);
}
#line 4053 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
  yy_destructor(yypParser,126,&yymsp[0].minor);
        break;
      case 185: /* func_param_list ::= func_param_list COMMA func_param */
#line 1157 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-2].minor.yy49 = yymsp[-2].minor.yy49; /*X-overwrites-A*/ AppendTreeNodeSibling(yymsp[-2].minor.yy49, yymsp[0].minor.yy49); }
#line 4060 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 186: /* func_param ::= func_param_flags type IDENTIFIER */
#line 1160 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(FuncParamDecl,parm,yymsp[-2].minor.yy0.SourceLoc ? yymsp[-2].minor.yy0.SourceLoc : yymsp[-1].minor.yy130->SourceLoc);
	parm->Type = yymsp[-1].minor.yy130;
	parm->Name = yymsp[0].minor.yy0.Name();
	parm->Flags = yymsp[-2].minor.yy0.Int;
	parm->Default = nullptr;
	yylhsminor.yy49 = parm;
}
#line 4073 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[-2].minor.yy49 = yylhsminor.yy49;
        break;
      case 187: /* func_param ::= func_param_flags type IDENTIFIER EQ expr */
#line 1170 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(FuncParamDecl,parm,yymsp[-4].minor.yy0.SourceLoc ? yymsp[-4].minor.yy0.SourceLoc : yymsp[-3].minor.yy130->SourceLoc);
	parm->Type = yymsp[-3].minor.yy130;
	parm->Name = yymsp[-2].minor.yy0.Name();
	parm->Flags = yymsp[-4].minor.yy0.Int;
	parm->Default = yymsp[0].minor.yy184;
	yylhsminor.yy49 = parm;
}
#line 4086 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-1].minor);
  yymsp[-4].minor.yy49 = yylhsminor.yy49;
        break;
      case 188: /* func_param_flags ::= */
#line 1179 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy0.Int = 0; yymsp[1].minor.yy0.SourceLoc = 0; }
#line 4093 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 189: /* func_param_flags ::= func_param_flags IN */
#line 1180 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = yymsp[-1].minor.yy0.Int | ZCC_In; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4098 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[-1].minor.yy0 = yylhsminor.yy0;
        break;
      case 190: /* func_param_flags ::= func_param_flags OUT */
#line 1181 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = yymsp[-1].minor.yy0.Int | ZCC_Out; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4104 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[-1].minor.yy0 = yylhsminor.yy0;
        break;
      case 191: /* func_param_flags ::= func_param_flags OPTIONAL */
#line 1182 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yylhsminor.yy0.Int = yymsp[-1].minor.yy0.Int | ZCC_Optional; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4110 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[-1].minor.yy0 = yylhsminor.yy0;
        break;
      case 192: /* primary ::= IDENTIFIER */
#line 1198 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprID, expr, yymsp[0].minor.yy0);
	expr->Operation = PEX_ID;
	expr->Identifier = yymsp[0].minor.yy0.Name();
	expr->Type = NULL;
	yylhsminor.yy184 = expr;
}
#line 4122 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy184 = yylhsminor.yy184;
        break;
      case 193: /* primary ::= SUPER */
#line 1206 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(Expression, expr, yymsp[0].minor.yy0);
	expr->Operation = PEX_Super;
	expr->Type = NULL;
	yylhsminor.yy184 = expr;
}
#line 4133 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy184 = yylhsminor.yy184;
        break;
      case 194: /* primary ::= constant */
#line 1212 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy184 = yymsp[0].minor.yy273; /*X-overwrites-A*/ }
#line 4139 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 195: /* primary ::= LPAREN expr COMMA expr COMMA expr RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-6].minor);
#line 1214 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(VectorValue, expr, yymsp[-5].minor.yy184);
	expr->Operation = PEX_Vector;
	expr->Type = TypeVector3;
	expr->X = yymsp[-5].minor.yy184;
	expr->Y = yymsp[-3].minor.yy184;
	expr->Z = yymsp[-1].minor.yy184;
	yymsp[-6].minor.yy184 = expr;
}
#line 4153 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-4].minor);
  yy_destructor(yypParser,50,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
}
        break;
      case 196: /* primary ::= LPAREN expr COMMA expr RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-4].minor);
#line 1224 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(VectorValue, expr, yymsp[-3].minor.yy184);
	expr->Operation = PEX_Vector;
	expr->Type = TypeVector2;
	expr->X = yymsp[-3].minor.yy184;
	expr->Y = yymsp[-1].minor.yy184;
	expr->Z = nullptr;
	yymsp[-4].minor.yy184 = expr;
}
#line 4171 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
}
        break;
      case 197: /* primary ::= LPAREN expr RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-2].minor);
#line 1234 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	yymsp[-2].minor.yy184 = yymsp[-1].minor.yy184; /*yymsp[-2].minor.yy184-overwrites-yymsp[-1].minor.yy184*/
}
#line 4182 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,62,&yymsp[0].minor);
}
        break;
      case 198: /* primary ::= primary LPAREN func_expr_list RPAREN */
#line 1239 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprFuncCall, expr, yymsp[-3].minor.yy184);
	expr->Operation = PEX_FuncCall;
	expr->Type = NULL;
	expr->Function = yymsp[-3].minor.yy184;
	expr->Parameters = yymsp[-1].minor.yy470;
	yylhsminor.yy184 = expr;
}
#line 4196 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
  yymsp[-3].minor.yy184 = yylhsminor.yy184;
        break;
      case 199: /* primary ::= LPAREN CLASS LT IDENTIFIER GT RPAREN LPAREN func_expr_list RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-8].minor);
#line 1248 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ClassCast, expr, yymsp[-5].minor.yy0);
	expr->Operation = PEX_ClassCast;
	expr->ClassName = ENamedName(yymsp[-5].minor.yy0.Int);
	expr->Parameters = yymsp[-1].minor.yy470;
	yymsp[-8].minor.yy184 = expr;
}
#line 4211 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,53,&yymsp[-7].minor);
  yy_destructor(yypParser,20,&yymsp[-6].minor);
  yy_destructor(yypParser,21,&yymsp[-4].minor);
  yy_destructor(yypParser,62,&yymsp[-3].minor);
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
}
        break;
      case 200: /* primary ::= primary LBRACKET expr RBRACKET */
#line 1256 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprBinary, expr, yymsp[-1].minor.yy184);
	expr->Operation = PEX_ArrayAccess;
	expr->Type = NULL;
	expr->Left = yymsp[-3].minor.yy184;
	expr->Right = yymsp[-1].minor.yy184;
	yylhsminor.yy184 = expr;
}
#line 4230 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,46,&yymsp[-2].minor);
  yy_destructor(yypParser,112,&yymsp[0].minor);
  yymsp[-3].minor.yy184 = yylhsminor.yy184;
        break;
      case 201: /* primary ::= primary DOT IDENTIFIER */
#line 1265 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprMemberAccess, expr, yymsp[0].minor.yy0);
	expr->Operation = PEX_MemberAccess;
	expr->Type = NULL;
	expr->Left = yymsp[-2].minor.yy184;
	expr->Right = ENamedName(yymsp[0].minor.yy0.Int);
	yylhsminor.yy184 = expr;
}
#line 4245 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,44,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 202: /* primary ::= primary ADDADD */
#line 1274 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[-1].minor.yy184,PEX_PostInc);
	yylhsminor.yy184 = expr1;
}
#line 4255 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,42,&yymsp[0].minor);
  yymsp[-1].minor.yy184 = yylhsminor.yy184;
        break;
      case 203: /* primary ::= primary SUBSUB */
#line 1279 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[-1].minor.yy184,PEX_PostDec);
	yylhsminor.yy184 = expr1;
}
#line 4265 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,43,&yymsp[0].minor);
  yymsp[-1].minor.yy184 = yylhsminor.yy184;
        break;
      case 204: /* unary_expr ::= SUB unary_expr */
{  yy_destructor(yypParser,33,&yymsp[-1].minor);
#line 1295 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	ZCC_ExprConstant *con = static_cast<ZCC_ExprConstant *>(yymsp[0].minor.yy184);
	if (yymsp[0].minor.yy184->Operation == PEX_ConstValue && (con->Type->isInt() || con->Type->isFloat()))
	{ // For constants, manipulate the child node directly, and don't create a new node.
		if (con->Type->isInt())
		{
			con->IntVal = -con->IntVal;
		}
		else
		{
			con->DoubleVal = -con->DoubleVal;
		}
		yymsp[-1].minor.yy184 = yymsp[0].minor.yy184;
	}
	else
	{ // For everything else, create a new node and do the negation later.
		UNARY_EXPR(yymsp[0].minor.yy184,PEX_Negate);
		yymsp[-1].minor.yy184 = expr1;
	}
}
#line 4292 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
}
        break;
      case 205: /* unary_expr ::= ADD unary_expr */
{  yy_destructor(yypParser,34,&yymsp[-1].minor);
#line 1316 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	// Even though this is really a no-op, we still need to make a node for
	// it so we can type check that it is being applied to something numeric.
	// But we can do that right now for constant numerals.
	ZCC_ExprConstant *con = static_cast<ZCC_ExprConstant *>(yymsp[0].minor.yy184);
	if (yymsp[0].minor.yy184->Operation != PEX_ConstValue || (!con->Type->isInt() && !con->Type->isFloat()))
	{
		UNARY_EXPR(yymsp[0].minor.yy184,PEX_AntiNegate);
		yymsp[-1].minor.yy184 = expr1;
	}
	else
	{
		yymsp[-1].minor.yy184 = yymsp[0].minor.yy184;
	}
}
#line 4313 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
}
        break;
      case 206: /* unary_expr ::= SUBSUB unary_expr */
{  yy_destructor(yypParser,43,&yymsp[-1].minor);
#line 1332 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[0].minor.yy184,PEX_PreDec);
	yymsp[-1].minor.yy184 = expr1;
}
#line 4323 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
}
        break;
      case 207: /* unary_expr ::= ADDADD unary_expr */
{  yy_destructor(yypParser,42,&yymsp[-1].minor);
#line 1337 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[0].minor.yy184,PEX_PreInc);
	yymsp[-1].minor.yy184 = expr1;
}
#line 4333 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
}
        break;
      case 208: /* unary_expr ::= TILDE unary_expr */
{  yy_destructor(yypParser,130,&yymsp[-1].minor);
#line 1342 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[0].minor.yy184,PEX_BitNot);
	yymsp[-1].minor.yy184 = expr1;
}
#line 4343 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
}
        break;
      case 209: /* unary_expr ::= BANG unary_expr */
{  yy_destructor(yypParser,131,&yymsp[-1].minor);
#line 1347 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[0].minor.yy184,PEX_BoolNot);
	yymsp[-1].minor.yy184 = expr1;
}
#line 4353 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
}
        break;
      case 210: /* unary_expr ::= SIZEOF unary_expr */
{  yy_destructor(yypParser,132,&yymsp[-1].minor);
#line 1352 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[0].minor.yy184,PEX_SizeOf);
	yymsp[-1].minor.yy184 = expr1;
}
#line 4363 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
}
        break;
      case 211: /* unary_expr ::= ALIGNOF unary_expr */
{  yy_destructor(yypParser,133,&yymsp[-1].minor);
#line 1357 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[0].minor.yy184,PEX_AlignOf);
	yymsp[-1].minor.yy184 = expr1;
}
#line 4373 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
}
        break;
      case 212: /* expr ::= expr ADD expr */
#line 1370 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_Add);
	yylhsminor.yy184 = expr2;
}
#line 4382 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,34,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 213: /* expr ::= expr SUB expr */
#line 1375 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_Sub);
	yylhsminor.yy184 = expr2;
}
#line 4392 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,33,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 214: /* expr ::= expr MUL expr */
#line 1380 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_Mul);
	yylhsminor.yy184 = expr2;
}
#line 4402 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,35,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 215: /* expr ::= expr DIV expr */
#line 1385 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_Div);
	yylhsminor.yy184 = expr2;
}
#line 4412 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,36,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 216: /* expr ::= expr MOD expr */
#line 1390 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_Mod);
	yylhsminor.yy184 = expr2;
}
#line 4422 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,37,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 217: /* expr ::= expr POW expr */
#line 1395 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_Pow);
	yylhsminor.yy184 = expr2;
}
#line 4432 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,40,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 218: /* expr ::= expr CROSSPROD expr */
#line 1400 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_CrossProduct);
	yylhsminor.yy184 = expr2;
}
#line 4442 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,38,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 219: /* expr ::= expr DOTPROD expr */
#line 1405 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_DotProduct);
	yylhsminor.yy184 = expr2;
}
#line 4452 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,39,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 220: /* expr ::= expr LSH expr */
#line 1410 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_LeftShift);
	yylhsminor.yy184 = expr2;
}
#line 4462 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,30,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 221: /* expr ::= expr RSH expr */
#line 1415 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_RightShift);
	yylhsminor.yy184 = expr2;
}
#line 4472 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,31,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 222: /* expr ::= expr URSH expr */
#line 1420 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_URightShift);
	yylhsminor.yy184 = expr2;
}
#line 4482 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,32,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 223: /* expr ::= expr DOTDOT expr */
#line 1425 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_Concat);
	yylhsminor.yy184 = expr2;
}
#line 4492 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,26,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 224: /* expr ::= expr LT expr */
#line 1431 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_LT);
	yylhsminor.yy184 = expr2;
}
#line 4502 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,20,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 225: /* expr ::= expr GT expr */
#line 1436 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_GT);
	yylhsminor.yy184 = expr2;
}
#line 4512 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,21,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 226: /* expr ::= expr LTEQ expr */
#line 1441 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_LTEQ);
	yylhsminor.yy184 = expr2;
}
#line 4522 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,22,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 227: /* expr ::= expr GTEQ expr */
#line 1446 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_GTEQ);
	yylhsminor.yy184 = expr2;
}
#line 4532 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,23,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 228: /* expr ::= expr LTGTEQ expr */
#line 1451 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_LTGTEQ);
	yylhsminor.yy184 = expr2;
}
#line 4542 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,24,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 229: /* expr ::= expr IS expr */
#line 1456 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_Is);
	yylhsminor.yy184 = expr2;
}
#line 4552 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,25,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 230: /* expr ::= expr EQEQ expr */
#line 1462 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_EQEQ);
	yylhsminor.yy184 = expr2;
}
#line 4562 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,17,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 231: /* expr ::= expr NEQ expr */
#line 1467 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_NEQ);
	yylhsminor.yy184 = expr2;
}
#line 4572 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,18,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 232: /* expr ::= expr APPROXEQ expr */
#line 1472 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_APREQ);
	yylhsminor.yy184 = expr2;
}
#line 4582 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,19,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 233: /* expr ::= expr AND expr */
#line 1478 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_BitAnd);
	yylhsminor.yy184 = expr2;
}
#line 4592 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,29,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 234: /* expr ::= expr XOR expr */
#line 1483 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_BitXor);
	yylhsminor.yy184 = expr2;
}
#line 4602 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,28,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 235: /* expr ::= expr OR expr */
#line 1488 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_BitOr);
	yylhsminor.yy184 = expr2;
}
#line 4612 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,27,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 236: /* expr ::= expr ANDAND expr */
#line 1493 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_BoolAnd);
	yylhsminor.yy184 = expr2;
}
#line 4622 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,16,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 237: /* expr ::= expr OROR expr */
#line 1498 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_BoolOr);
	yylhsminor.yy184 = expr2;
}
#line 4632 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,15,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 238: /* expr ::= expr EQ expr */
#line 1503 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_Assign);
	yylhsminor.yy184 = expr2;
}
#line 4642 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 239: /* expr ::= expr ADDEQ expr */
#line 1508 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_AddAssign);
	yylhsminor.yy184 = expr2;
}
#line 4652 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,5,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 240: /* expr ::= expr SUBEQ expr */
#line 1513 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_SubAssign);
	yylhsminor.yy184 = expr2;
}
#line 4662 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,6,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 241: /* expr ::= expr MULEQ expr */
#line 1518 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_MulAssign);
	yylhsminor.yy184 = expr2;
}
#line 4672 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,2,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 242: /* expr ::= expr DIVEQ expr */
#line 1523 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_DivAssign);
	yylhsminor.yy184 = expr2;
}
#line 4682 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,3,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 243: /* expr ::= expr MODEQ expr */
#line 1528 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_ModAssign);
	yylhsminor.yy184 = expr2;
}
#line 4692 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,4,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 244: /* expr ::= expr LSHEQ expr */
#line 1533 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_LshAssign);
	yylhsminor.yy184 = expr2;
}
#line 4702 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,7,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 245: /* expr ::= expr RSHEQ expr */
#line 1538 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_RshAssign);
	yylhsminor.yy184 = expr2;
}
#line 4712 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,8,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 246: /* expr ::= expr URSHEQ expr */
#line 1543 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_URshAssign);
	yylhsminor.yy184 = expr2;
}
#line 4722 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,12,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 247: /* expr ::= expr ANDEQ expr */
#line 1548 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_AndAssign);
	yylhsminor.yy184 = expr2;
}
#line 4732 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,9,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 248: /* expr ::= expr OREQ expr */
#line 1553 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_OrAssign);
	yylhsminor.yy184 = expr2;
}
#line 4742 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,10,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 249: /* expr ::= expr XOREQ expr */
#line 1558 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_XorAssign);
	yylhsminor.yy184 = expr2;
}
#line 4752 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,11,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 250: /* expr ::= expr SCOPE expr */
#line 1565 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy184,yymsp[0].minor.yy184,PEX_Scope);
	yylhsminor.yy184 = expr2;
}
#line 4762 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,47,&yymsp[-1].minor);
  yymsp[-2].minor.yy184 = yylhsminor.yy184;
        break;
      case 251: /* expr ::= expr QUESTION expr COLON expr */
#line 1573 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprTrinary, expr, yymsp[-4].minor.yy184);
	expr->Operation = PEX_Trinary;
	expr->Type = NULL;
	expr->Test = yymsp[-4].minor.yy184;
	expr->Left = yymsp[-2].minor.yy184;
	expr->Right = yymsp[0].minor.yy184;
	yylhsminor.yy184 = expr;
}
#line 4777 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,13,&yymsp[-3].minor);
  yy_destructor(yypParser,14,&yymsp[-1].minor);
  yymsp[-4].minor.yy184 = yylhsminor.yy184;
        break;
      case 252: /* expr_list ::= expr_list COMMA expr */
#line 1589 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	yymsp[-2].minor.yy184 = yymsp[-2].minor.yy184;	/*X-overwrites-A*/
	AppendTreeNodeSibling(yymsp[-2].minor.yy184, yymsp[0].minor.yy184);
}
#line 4788 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 253: /* func_expr_list ::= func_expr_list COMMA func_expr_item */
#line 1605 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	// Omitted parameters still need to appear as nodes in the list.
	if (yymsp[-2].minor.yy470 == NULL)
	{
		NEW_AST_NODE(FuncParm,nil_a,yymsp[-1].minor.yy0);
		nil_a->Value = NULL;
		nil_a->Label = NAME_None;
		yymsp[-2].minor.yy470 = nil_a;
	}
	if (yymsp[0].minor.yy470 == NULL)
	{
		NEW_AST_NODE(FuncParm,nil_b,yymsp[-1].minor.yy0);
		nil_b->Value = NULL;
		nil_b->Label = NAME_None;
		yymsp[0].minor.yy470 = nil_b;
	}
	yymsp[-2].minor.yy470 = yymsp[-2].minor.yy470;	/*X-overwrites-A*/
	AppendTreeNodeSibling(yymsp[-2].minor.yy470, yymsp[0].minor.yy470);
}
#line 4812 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 254: /* func_expr_item ::= */
#line 1626 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	yymsp[1].minor.yy470 = NULL;
}
#line 4819 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 255: /* named_expr ::= IDENTIFIER COLON expr */
#line 1632 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(FuncParm, parm, yymsp[-2].minor.yy0);
	parm->Value = yymsp[0].minor.yy184;
	parm->Label = ENamedName(yymsp[-2].minor.yy0.Int);
	yylhsminor.yy470 = parm;
}
#line 4829 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,14,&yymsp[-1].minor);
  yymsp[-2].minor.yy470 = yylhsminor.yy470;
        break;
      case 256: /* named_expr ::= expr */
#line 1639 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(FuncParm, parm, yymsp[0].minor.yy184);
	parm->Value = yymsp[0].minor.yy184;
	parm->Label = NAME_None;
	yylhsminor.yy470 = parm;
}
#line 4841 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy470 = yylhsminor.yy470;
        break;
      case 258: /* string_constant ::= string_constant STRCONST */
#line 1660 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprConstant, strconst, yymsp[-1].minor.yy273);
	strconst->Operation = PEX_ConstValue;
	strconst->Type = TypeString;
	strconst->StringVal = stat->Strings.Alloc(*(yymsp[-1].minor.yy273->StringVal) + *(yymsp[0].minor.yy0.String));
	yylhsminor.yy273 = strconst;
}
#line 4853 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[-1].minor.yy273 = yylhsminor.yy273;
        break;
      case 259: /* constant ::= INTCONST */
#line 1670 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_INTCONST_NODE(intconst, TypeSInt32, yymsp[0].minor.yy0.Int, yymsp[0].minor.yy0);
	yylhsminor.yy273 = intconst;
}
#line 4862 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy273 = yylhsminor.yy273;
        break;
      case 260: /* constant ::= UINTCONST */
#line 1675 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_INTCONST_NODE(intconst, TypeUInt32, yymsp[0].minor.yy0.Int, yymsp[0].minor.yy0);
	yylhsminor.yy273 = intconst;
}
#line 4871 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy273 = yylhsminor.yy273;
        break;
      case 261: /* constant ::= FLOATCONST */
#line 1680 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprConstant, floatconst, yymsp[0].minor.yy0);
	floatconst->Operation = PEX_ConstValue;
	floatconst->Type = TypeFloat64;
	floatconst->DoubleVal = yymsp[0].minor.yy0.Float;
	yylhsminor.yy273 = floatconst;
}
#line 4883 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy273 = yylhsminor.yy273;
        break;
      case 262: /* constant ::= NAMECONST */
#line 1688 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprConstant, floatconst, yymsp[0].minor.yy0);
	floatconst->Operation = PEX_ConstValue;
	floatconst->Type = TypeName;
	floatconst->IntVal = yymsp[0].minor.yy0.Int;
	yylhsminor.yy273 = floatconst;
}
#line 4895 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy273 = yylhsminor.yy273;
        break;
      case 263: /* constant ::= FALSE */
#line 1696 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_INTCONST_NODE(boolconst, TypeBool, false, yymsp[0].minor.yy0);
	yylhsminor.yy273 = boolconst;
}
#line 4904 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy273 = yylhsminor.yy273;
        break;
      case 264: /* constant ::= TRUE */
#line 1701 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_INTCONST_NODE(boolconst, TypeBool, true, yymsp[0].minor.yy0);
	yylhsminor.yy273 = boolconst;
}
#line 4913 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy273 = yylhsminor.yy273;
        break;
      case 265: /* constant ::= NULLPTR */
#line 1706 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprConstant, nullptrconst, yymsp[0].minor.yy0);
	nullptrconst->Operation = PEX_ConstValue;
	nullptrconst->Type = TypeNullPtr;
	nullptrconst->StringVal = nullptr;
	yylhsminor.yy273 = nullptrconst;
}
#line 4925 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy273 = yylhsminor.yy273;
        break;
      case 267: /* statement ::= labeled_statement */
#line 1720 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy367 = yymsp[0].minor.yy304; /*X-overwrites-A*/ }
#line 4931 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 268: /* statement ::= compound_statement */
#line 1721 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy367 = yymsp[0].minor.yy215; /*X-overwrites-A*/ }
#line 4936 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 269: /* statement ::= expression_statement SEMICOLON */
#line 1722 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy367 = yymsp[-1].minor.yy124; /*X-overwrites-A*/ }
#line 4941 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
        break;
      case 270: /* statement ::= assign_statement SEMICOLON */
#line 1726 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy367 = yymsp[-1].minor.yy263; /*X-overwrites-A*/ }
#line 4947 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
        break;
      case 271: /* statement ::= local_var SEMICOLON */
#line 1727 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-1].minor.yy367 = yymsp[-1].minor.yy164; /*X-overwrites-A*/ }
#line 4953 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
        break;
      case 273: /* statement ::= staticarray_statement */
#line 1729 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy367 = yymsp[0].minor.yy82; /*X-overwrites-A*/ }
#line 4959 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 274: /* staticarray_statement ::= STATICCONST type IDENTIFIER LBRACKET RBRACKET EQ LBRACE expr_list RBRACE SEMICOLON */
{  yy_destructor(yypParser,141,&yymsp[-9].minor);
#line 1736 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(StaticArrayStatement, stmt, yymsp[-8].minor.yy130);
	stmt->Type = yymsp[-8].minor.yy130;
	stmt->Id = ENamedName(yymsp[-7].minor.yy0.Int);
	stmt->Values = yymsp[-2].minor.yy184;
	yymsp[-9].minor.yy82 = stmt;
}
#line 4971 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,46,&yymsp[-6].minor);
  yy_destructor(yypParser,112,&yymsp[-5].minor);
  yy_destructor(yypParser,1,&yymsp[-4].minor);
  yy_destructor(yypParser,65,&yymsp[-3].minor);
  yy_destructor(yypParser,66,&yymsp[-1].minor);
  yy_destructor(yypParser,49,&yymsp[0].minor);
}
        break;
      case 275: /* staticarray_statement ::= STATICCONST type LBRACKET RBRACKET IDENTIFIER EQ LBRACE expr_list RBRACE SEMICOLON */
{  yy_destructor(yypParser,141,&yymsp[-9].minor);
#line 1745 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(StaticArrayStatement, stmt, yymsp[-8].minor.yy130);
	stmt->Type = yymsp[-8].minor.yy130;
	stmt->Id = ENamedName(yymsp[-5].minor.yy0.Int);
	stmt->Values = yymsp[-2].minor.yy184;
	yymsp[-9].minor.yy82 = stmt;
}
#line 4990 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,46,&yymsp[-7].minor);
  yy_destructor(yypParser,112,&yymsp[-6].minor);
  yy_destructor(yypParser,1,&yymsp[-4].minor);
  yy_destructor(yypParser,65,&yymsp[-3].minor);
  yy_destructor(yypParser,66,&yymsp[-1].minor);
  yy_destructor(yypParser,49,&yymsp[0].minor);
}
        break;
      case 276: /* jump_statement ::= CONTINUE SEMICOLON */
#line 1758 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ContinueStmt, stmt, yymsp[-1].minor.yy0);
	yylhsminor.yy367 = stmt;
}
#line 5005 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-1].minor.yy367 = yylhsminor.yy367;
        break;
      case 277: /* jump_statement ::= BREAK SEMICOLON */
#line 1763 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(BreakStmt, stmt, yymsp[-1].minor.yy0);
	yylhsminor.yy367 = stmt;
}
#line 5015 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-1].minor.yy367 = yylhsminor.yy367;
        break;
      case 278: /* jump_statement ::= RETURN SEMICOLON */
#line 1768 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ReturnStmt, stmt, yymsp[-1].minor.yy0);
	stmt->Values = NULL;
	yylhsminor.yy367 = stmt;
}
#line 5026 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-1].minor.yy367 = yylhsminor.yy367;
        break;
      case 279: /* jump_statement ::= RETURN expr_list SEMICOLON */
#line 1774 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ReturnStmt, stmt, yymsp[-2].minor.yy0);
	stmt->Values = yymsp[-1].minor.yy184;
	yylhsminor.yy367 = stmt;
}
#line 5037 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-2].minor.yy367 = yylhsminor.yy367;
        break;
      case 280: /* compound_statement ::= LBRACE RBRACE */
#line 1786 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(CompoundStmt,stmt,yymsp[-1].minor.yy0);
	stmt->Content = NULL;
	yylhsminor.yy215 = stmt;
}
#line 5048 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
  yymsp[-1].minor.yy215 = yylhsminor.yy215;
        break;
      case 281: /* compound_statement ::= LBRACE statement_list RBRACE */
#line 1792 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(CompoundStmt,stmt,yymsp[-2].minor.yy0);
	stmt->Content = yymsp[-1].minor.yy367;
	yylhsminor.yy215 = stmt;
}
#line 5059 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
  yymsp[-2].minor.yy215 = yylhsminor.yy215;
        break;
      case 282: /* compound_statement ::= LBRACE error RBRACE */
#line 1798 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(CompoundStmt,stmt,yymsp[-2].minor.yy0);
	stmt->Content = NULL;
	yylhsminor.yy215 = stmt;
}
#line 5070 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[0].minor);
  yymsp[-2].minor.yy215 = yylhsminor.yy215;
        break;
      case 285: /* expression_statement ::= expr */
#line 1818 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(ExpressionStmt, stmt, yymsp[0].minor.yy184);
	stmt->Expression = yymsp[0].minor.yy184;
	yylhsminor.yy124 = stmt;
}
#line 5081 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy124 = yylhsminor.yy124;
        break;
      case 286: /* iteration_statement ::= while_or_until LPAREN expr RPAREN statement */
#line 1830 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(IterationStmt, iter, yymsp[-4].minor.yy0);
	if (yymsp[-4].minor.yy0.Int == ZCC_UNTIL)
	{ // Negate the loop condition
		UNARY_EXPR(yymsp[-2].minor.yy184,PEX_BoolNot);
		iter->LoopCondition = expr1;
	}
	else
	{
		iter->LoopCondition = yymsp[-2].minor.yy184;
	}
	iter->LoopStatement = yymsp[0].minor.yy367;
	iter->LoopBumper = NULL;
	iter->CheckAt = ZCC_IterationStmt::Start;
	yylhsminor.yy367 = iter;
}
#line 5102 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-3].minor);
  yy_destructor(yypParser,62,&yymsp[-1].minor);
  yymsp[-4].minor.yy367 = yylhsminor.yy367;
        break;
      case 287: /* iteration_statement ::= DO statement while_or_until LPAREN expr RPAREN */
#line 1848 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(IterationStmt, iter, yymsp[-5].minor.yy0);
	if (yymsp[-3].minor.yy0.Int == ZCC_UNTIL)
	{ // Negate the loop condition
		UNARY_EXPR(yymsp[-1].minor.yy184,PEX_BoolNot);
		iter->LoopCondition = expr1;
	}
	else
	{
		iter->LoopCondition = yymsp[-1].minor.yy184;
	}
	iter->LoopStatement = yymsp[-4].minor.yy367;
	iter->LoopBumper = NULL;
	iter->CheckAt = ZCC_IterationStmt::End;
	yylhsminor.yy367 = iter;
}
#line 5125 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
  yymsp[-5].minor.yy367 = yylhsminor.yy367;
        break;
      case 288: /* iteration_statement ::= FOR LPAREN for_init SEMICOLON opt_expr SEMICOLON for_bump RPAREN statement */
#line 1866 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(IterationStmt, iter, yymsp[-8].minor.yy0);
	iter->LoopCondition = yymsp[-4].minor.yy184;
	iter->LoopStatement = yymsp[0].minor.yy367;
	iter->LoopBumper = yymsp[-2].minor.yy367;
	iter->CheckAt = ZCC_IterationStmt::Start;
	// The initialization expression appears outside the loop
	// for_init may be NULL if there is no initialization.
	SAFE_APPEND(yymsp[-6].minor.yy367, iter);
	// And the whole thing gets wrapped inside a compound statement in case the loop
	// initializer defined any variables.
	NEW_AST_NODE(CompoundStmt, wrap, yymsp[-8].minor.yy0);
	wrap->Content = yymsp[-6].minor.yy367;
	yylhsminor.yy367 = wrap;
}
#line 5147 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-7].minor);
  yy_destructor(yypParser,49,&yymsp[-5].minor);
  yy_destructor(yypParser,49,&yymsp[-3].minor);
  yy_destructor(yypParser,62,&yymsp[-1].minor);
  yymsp[-8].minor.yy367 = yylhsminor.yy367;
        break;
      case 289: /* while_or_until ::= WHILE */
#line 1883 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	yylhsminor.yy0.Int = ZCC_WHILE;
	yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc;
}
#line 5160 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 290: /* while_or_until ::= UNTIL */
#line 1888 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	yylhsminor.yy0.Int = ZCC_UNTIL;
	yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc;
}
#line 5169 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 291: /* for_init ::= local_var */
#line 1894 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy367 = yymsp[0].minor.yy164 /*X-overwrites-A*/; }
#line 5175 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 292: /* for_init ::= for_bump */
#line 1895 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy367 = yymsp[0].minor.yy367 /*X-overwrites-A*/; }
#line 5180 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 293: /* for_bump ::= */
#line 1898 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[1].minor.yy367 = NULL; }
#line 5185 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 294: /* for_bump ::= expression_statement */
#line 1899 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[0].minor.yy367 = yymsp[0].minor.yy124; /*X-overwrites-A*/ }
#line 5190 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 295: /* for_bump ::= for_bump COMMA expression_statement */
#line 1900 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ yymsp[-2].minor.yy367 = yymsp[-2].minor.yy367; /*X-overwrites-A*/ AppendTreeNodeSibling(yymsp[-2].minor.yy367, yymsp[0].minor.yy124); }
#line 5195 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 296: /* selection_statement ::= if_front */
#line 1914 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	yymsp[0].minor.yy367 = yymsp[0].minor.yy312; /*X-overwrites-A*/
}
#line 5203 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
        break;
      case 297: /* selection_statement ::= if_front ELSE statement */
#line 1918 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	yymsp[-2].minor.yy312->FalsePath = yymsp[0].minor.yy367;
	yymsp[-2].minor.yy367 = yymsp[-2].minor.yy312; /*X-overwrites-A*/
}
#line 5211 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,150,&yymsp[-1].minor);
        break;
      case 298: /* if_front ::= IF LPAREN expr RPAREN statement */
#line 1924 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(IfStmt,stmt,yymsp[-4].minor.yy0);
	stmt->Condition = yymsp[-2].minor.yy184;
	stmt->TruePath = yymsp[0].minor.yy367;
	stmt->FalsePath = NULL;
	yylhsminor.yy312 = stmt;
}
#line 5223 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-3].minor);
  yy_destructor(yypParser,62,&yymsp[-1].minor);
  yymsp[-4].minor.yy312 = yylhsminor.yy312;
        break;
      case 299: /* selection_statement ::= SWITCH LPAREN expr RPAREN statement */
#line 1935 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(SwitchStmt,stmt,yymsp[-4].minor.yy0);
	stmt->Condition = yymsp[-2].minor.yy184;
	stmt->Content = yymsp[0].minor.yy367;
	yylhsminor.yy367 = stmt;
}
#line 5236 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-3].minor);
  yy_destructor(yypParser,62,&yymsp[-1].minor);
  yymsp[-4].minor.yy367 = yylhsminor.yy367;
        break;
      case 300: /* labeled_statement ::= CASE expr COLON */
#line 1947 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(CaseStmt,stmt,yymsp[-2].minor.yy0);
	stmt->Condition = yymsp[-1].minor.yy184;
	yylhsminor.yy304 = stmt;
}
#line 5248 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,14,&yymsp[0].minor);
  yymsp[-2].minor.yy304 = yylhsminor.yy304;
        break;
      case 301: /* labeled_statement ::= DEFAULT COLON */
#line 1953 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(CaseStmt,stmt,yymsp[-1].minor.yy0);
	stmt->Condition = NULL;
	yylhsminor.yy304 = stmt;
}
#line 5259 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,14,&yymsp[0].minor);
  yymsp[-1].minor.yy304 = yylhsminor.yy304;
        break;
      case 302: /* assign_statement ::= LBRACKET expr_list RBRACKET EQ expr */
{  yy_destructor(yypParser,46,&yymsp[-4].minor);
#line 1966 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(AssignStmt,stmt,yymsp[-3].minor.yy184);
	stmt->AssignOp = ZCC_EQ;
	stmt->Dests = yymsp[-3].minor.yy184;
	stmt->Sources = yymsp[0].minor.yy184;
	yymsp[-4].minor.yy263 = stmt;
}
#line 5273 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,112,&yymsp[-2].minor);
  yy_destructor(yypParser,1,&yymsp[-1].minor);
}
        break;
      case 303: /* local_var ::= type variable_list_with_init */
#line 1979 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(LocalVarStmt,vardef,yymsp[-1].minor.yy130);
	vardef->Type = yymsp[-1].minor.yy130;
	vardef->Vars = yymsp[0].minor.yy161;
	yylhsminor.yy164 = vardef;
}
#line 5286 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[-1].minor.yy164 = yylhsminor.yy164;
        break;
      case 304: /* var_init ::= IDENTIFIER */
#line 1988 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ 
	NEW_AST_NODE(VarInit,var,yymsp[0].minor.yy0);
	var->Name = ENamedName(yymsp[0].minor.yy0.Int);
	var->ArraySize = NULL;
	var->Init = NULL;
	var->InitIsArray = false;
	yylhsminor.yy161 = var;
}
#line 5299 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[0].minor.yy161 = yylhsminor.yy161;
        break;
      case 305: /* var_init ::= IDENTIFIER array_size */
#line 1998 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	NEW_AST_NODE(VarInit,var,yymsp[-1].minor.yy0);
	var->Name = ENamedName(yymsp[-1].minor.yy0.Int);
	var->ArraySize = yymsp[0].minor.yy184;
	var->Init = NULL;
	var->InitIsArray = false;
	yylhsminor.yy161 = var;
}
#line 5312 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yymsp[-1].minor.yy161 = yylhsminor.yy161;
        break;
      case 306: /* var_init ::= IDENTIFIER EQ expr */
#line 2008 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ 
	NEW_AST_NODE(VarInit,var,yymsp[-2].minor.yy0);
	var->Name = ENamedName(yymsp[-2].minor.yy0.Int);
	var->ArraySize = NULL;
	var->Init = yymsp[0].minor.yy184;
	var->InitIsArray = false;
	yylhsminor.yy161 = var;
}
#line 5325 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-1].minor);
  yymsp[-2].minor.yy161 = yylhsminor.yy161;
        break;
      case 307: /* var_init ::= IDENTIFIER EQ LBRACE expr_list RBRACE */
#line 2018 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ 
	NEW_AST_NODE(VarInit,var,yymsp[-4].minor.yy0);
	var->Name = ENamedName(yymsp[-4].minor.yy0.Int);
	var->ArraySize = NULL;
	var->Init = yymsp[-1].minor.yy184;
	var->InitIsArray = true;
	yylhsminor.yy161 = var;
}
#line 5339 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-3].minor);
  yy_destructor(yypParser,65,&yymsp[-2].minor);
  yy_destructor(yypParser,66,&yymsp[0].minor);
  yymsp[-4].minor.yy161 = yylhsminor.yy161;
        break;
      case 308: /* var_init ::= IDENTIFIER array_size EQ LBRACE expr_list RBRACE */
#line 2028 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ 
	NEW_AST_NODE(VarInit,var,yymsp[-5].minor.yy0);
	var->Name = ENamedName(yymsp[-5].minor.yy0.Int);
	var->ArraySize = yymsp[-4].minor.yy184;
	var->Init = yymsp[-1].minor.yy184;
	var->InitIsArray = true;
	yylhsminor.yy161 = var;
}
#line 5355 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-3].minor);
  yy_destructor(yypParser,65,&yymsp[-2].minor);
  yy_destructor(yypParser,66,&yymsp[0].minor);
  yymsp[-5].minor.yy161 = yylhsminor.yy161;
        break;
      case 309: /* var_init ::= IDENTIFIER EQ LBRACE error RBRACE */
{  yy_destructor(yypParser,54,&yymsp[-4].minor);
#line 2038 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{ 
	yymsp[-4].minor.yy161 = NULL;
}
#line 5367 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-3].minor);
  yy_destructor(yypParser,65,&yymsp[-2].minor);
  yy_destructor(yypParser,66,&yymsp[0].minor);
}
        break;
      case 310: /* variable_list_with_init ::= variable_list_with_init COMMA var_init */
#line 2046 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
	AppendTreeNodeSibling(yymsp[-2].minor.yy161, yymsp[0].minor.yy161);
	yymsp[-2].minor.yy161 = yymsp[-2].minor.yy161; /*X-overwrites-A*/
}
#line 5379 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 311: /* translation_unit ::= translation_unit EOF */
#line 178 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
}
#line 5386 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,48,&yymsp[0].minor);
        break;
      case 313: /* opt_semicolon ::= SEMICOLON */
{  yy_destructor(yypParser,49,&yymsp[0].minor);
#line 190 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
}
#line 5394 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
}
        break;
      case 315: /* opt_comma ::= COMMA */
{  yy_destructor(yypParser,50,&yymsp[0].minor);
#line 193 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
}
#line 5402 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
}
        break;
      case 321: /* state_flow ::= state_flow_type scanner_mode SEMICOLON */
#line 569 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
}
#line 5409 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
        break;
      case 331: /* primary ::= LPAREN error RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-2].minor);
#line 1237 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
{
}
#line 5417 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
  yy_destructor(yypParser,62,&yymsp[0].minor);
}
        break;
      default:
      /* (312) opt_semicolon ::= */ yytestcase(yyruleno==312);
      /* (314) opt_comma ::= */ yytestcase(yyruleno==314);
      /* (316) opt_expr ::= expr */ yytestcase(yyruleno==316);
      /* (317) opt_struct_body ::= struct_body */ yytestcase(yyruleno==317);
      /* (318) struct_body ::= struct_member */ yytestcase(yyruleno==318);
      /* (319) enum_list ::= enumerator */ yytestcase(yyruleno==319);
      /* (320) opt_enum_list ::= enum_list opt_comma */ yytestcase(yyruleno==320);
      /* (322) type_name1 ::= int_type */ yytestcase(yyruleno==322);
      /* (323) type_or_array ::= type */ yytestcase(yyruleno==323);
      /* (324) type_list ::= type_or_array */ yytestcase(yyruleno==324);
      /* (325) type_list_or_void ::= type_list */ yytestcase(yyruleno==325);
      /* (326) array_size ::= array_size_expr */ yytestcase(yyruleno==326);
      /* (327) variable_list ::= variable_name */ yytestcase(yyruleno==327);
      /* (328) opt_func_body ::= function_body */ yytestcase(yyruleno==328);
      /* (329) func_params ::= func_param_list */ yytestcase(yyruleno==329);
      /* (330) func_param_list ::= func_param */ yytestcase(yyruleno==330);
      /* (332) unary_expr ::= primary */ yytestcase(yyruleno==332);
      /* (333) expr ::= unary_expr */ yytestcase(yyruleno==333);
      /* (334) expr_list ::= expr */ yytestcase(yyruleno==334);
      /* (335) func_expr_list ::= func_expr_item */ yytestcase(yyruleno==335);
      /* (336) func_expr_item ::= named_expr */ yytestcase(yyruleno==336);
      /* (337) constant ::= string_constant */ yytestcase(yyruleno==337);
      /* (338) function_body ::= compound_statement */ yytestcase(yyruleno==338);
      /* (339) statement ::= selection_statement */ yytestcase(yyruleno==339);
      /* (340) statement ::= iteration_statement */ yytestcase(yyruleno==340);
      /* (341) statement ::= jump_statement */ yytestcase(yyruleno==341);
      /* (342) variable_list_with_init ::= var_init */ yytestcase(yyruleno==342);
       break;
/********** End reduce actions ************************************************/
  };
  assert( yyruleno<sizeof(yyRuleInfo)/sizeof(yyRuleInfo[0]) );
  yygoto = yyRuleInfo[yyruleno].lhs;
  yysize = yyRuleInfo[yyruleno].nrhs;
  yyact = yy_find_reduce_action(yymsp[-yysize].stateno,(YYCODETYPE)yygoto);
  if( yyact <= YY_MAX_SHIFTREDUCE ){
    if( yyact>YY_MAX_SHIFT ){
      yyact += YY_MIN_REDUCE - YY_MIN_SHIFTREDUCE;
    }
    yymsp -= yysize-1;
    yypParser->yytos = yymsp;
    yymsp->stateno = (YYACTIONTYPE)yyact;
    yymsp->major = (YYCODETYPE)yygoto;
    yyTraceShift(yypParser, yyact);
  }else{
    assert( yyact == YY_ACCEPT_ACTION );
    yypParser->yytos -= yysize;
    yy_accept(yypParser);
  }
}

/*
** The following code executes when the parse fails
*/
#ifndef YYNOERRORRECOVERY
static void yy_parse_failed(
  yyParser *yypParser           /* The parser */
){
  ZCCParseARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sFail!\n",yyTracePrompt);
    fflush(yyTraceFILE);
  }
#endif
  while( yypParser->yytos>yypParser->yystack ) yy_pop_parser_stack(yypParser);
  /* Here code is inserted which will be executed whenever the
  ** parser fails */
/************ Begin %parse_failure code ***************************************/
#line 148 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
 /**failed = true;*/ 
#line 5492 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
/************ End %parse_failure code *****************************************/
  ZCCParseARG_STORE; /* Suppress warning about unused %extra_argument variable */
}
#endif /* YYNOERRORRECOVERY */

/*
** The following code executes when a syntax error first occurs.
*/
static void yy_syntax_error(
  yyParser *yypParser,           /* The parser */
  int yymajor,                   /* The major type of the error token */
  ZCCParseTOKENTYPE yyminor         /* The minor type of the error token */
){
  ZCCParseARG_FETCH;
#define TOKEN yyminor
/************ Begin %syntax_error code ****************************************/
#line 121 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"

	FString unexpected, expecting;

	int i;
	int stateno = yypParser->yytos->stateno;

	unexpected << "Unexpected " << ZCCTokenName(yymajor);

	// Determine all the terminals that the parser would have accepted at this point
	// (see yy_find_shift_action). This list can get quite long. Is it worthwhile to
	// print it when not debugging the grammar, or would that be too confusing to
	// the average user?
	if (stateno < YY_SHIFT_MAX && (i = yy_shift_ofst[stateno])!=YY_SHIFT_USE_DFLT)
	{
		for (int j = 1; j < YYERRORSYMBOL; ++j)
		{
			int k = i + j;
			if (k >= 0 && k < YY_ACTTAB_COUNT && yy_lookahead[k] == j)
			{
				expecting << (expecting.IsEmpty() ? "Expecting " : " or ") << ZCCTokenName(j);
			}
		}
	}
	stat->sc->ScriptMessage("%s\n%s\n", unexpected.GetChars(), expecting.GetChars());
	FScriptPosition::ErrorCounter++;
#line 5535 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
/************ End %syntax_error code ******************************************/
  ZCCParseARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/*
** The following is executed when the parser accepts
*/
static void yy_accept(
  yyParser *yypParser           /* The parser */
){
  ZCCParseARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sAccept!\n",yyTracePrompt);
    fflush(yyTraceFILE);
  }
#endif
#ifndef YYNOERRORRECOVERY
  yypParser->yyerrcnt = -1;
#endif
#if 0
  assert( yypParser->yytos==yypParser->yystack );
#else
  while (yypParser->yytos>yypParser->yystack) yy_pop_parser_stack(yypParser);
#endif
  /* Here code is inserted which will be executed whenever the
  ** parser accepts */
/*********** Begin %parse_accept code *****************************************/
#line 147 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/src/scripting/zscript/zcc-parse.lemon"
 DPrintf(DMSG_SPAMMY, "Input accepted\n"); 
#line 5566 "/home/abuild/rpmbuild/BUILD/gzdoom-3.2.5/build/src/zcc-parse.c"
/*********** End %parse_accept code *******************************************/
  ZCCParseARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/* The main parser program.
** The first argument is a pointer to a structure obtained from
** "ZCCParseAlloc" which describes the current state of the parser.
** The second argument is the major token number.  The third is
** the minor token.  The fourth optional argument is whatever the
** user wants (and specified in the grammar) and is available for
** use by the action routines.
**
** Inputs:
** <ul>
** <li> A pointer to the parser (an opaque structure.)
** <li> The major token number.
** <li> The minor token number.
** <li> An option argument of a grammar-specified type.
** </ul>
**
** Outputs:
** None.
*/
void ZCCParse(
  void *yyp,                   /* The parser */
  int yymajor,                 /* The major token code number */
  ZCCParseTOKENTYPE yyminor       /* The value for the token */
  ZCCParseARG_PDECL               /* Optional %extra_argument parameter */
){
  YYMINORTYPE yyminorunion;
  unsigned int yyact;   /* The parser action. */
#if !defined(YYERRORSYMBOL) && !defined(YYNOERRORRECOVERY)
  int yyendofinput;     /* True if we are at the end of input */
#endif
#ifdef YYERRORSYMBOL
  int yyerrorhit = 0;   /* True if yymajor has invoked an error */
#endif
  yyParser *yypParser;  /* The parser */

  yypParser = (yyParser*)yyp;
  assert( yypParser->yytos!=0 );
#if !defined(YYERRORSYMBOL) && !defined(YYNOERRORRECOVERY)
  yyendofinput = (yymajor==0);
#endif
  ZCCParseARG_STORE;

#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sInput '%s'\n",yyTracePrompt,yyTokenName[yymajor]);
    fflush(yyTraceFILE);
  }
#endif

  do{
    yyact = yy_find_shift_action(yypParser,(YYCODETYPE)yymajor);
    if( yyact <= YY_MAX_SHIFTREDUCE ){
      yy_shift(yypParser,yyact,yymajor,yyminor);
#ifndef YYNOERRORRECOVERY
      yypParser->yyerrcnt--;
#endif
      yymajor = YYNOCODE;
    }else if( yyact <= YY_MAX_REDUCE ){
      yy_reduce(yypParser,yyact-YY_MIN_REDUCE);
    }else{
      assert( yyact == YY_ERROR_ACTION );
      yyminorunion.yy0 = yyminor;
#ifdef YYERRORSYMBOL
      int yymx;
#endif
#ifndef NDEBUG
      if( yyTraceFILE ){
        fprintf(yyTraceFILE,"%sSyntax Error!\n",yyTracePrompt);
        fflush(yyTraceFILE);
      }
#endif
#ifdef YYERRORSYMBOL
      /* A syntax error has occurred.
      ** The response to an error depends upon whether or not the
      ** grammar defines an error token "ERROR".  
      **
      ** This is what we do if the grammar does define ERROR:
      **
      **  * Call the %syntax_error function.
      **
      **  * Begin popping the stack until we enter a state where
      **    it is legal to shift the error symbol, then shift
      **    the error symbol.
      **
      **  * Set the error count to three.
      **
      **  * Begin accepting and shifting new tokens.  No new error
      **    processing will occur until three tokens have been
      **    shifted successfully.
      **
      */
      if( yypParser->yyerrcnt<0 ){
        yy_syntax_error(yypParser,yymajor,yyminor);
      }
      yymx = yypParser->yytos->major;
      if( yymx==YYERRORSYMBOL || yyerrorhit ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE,"%sDiscard input token %s\n",
             yyTracePrompt,yyTokenName[yymajor]);
          fflush(yyTraceFILE);
        }
#endif
        yy_destructor(yypParser, (YYCODETYPE)yymajor, &yyminorunion);
        yymajor = YYNOCODE;
      }else{
        while( yypParser->yytos >= yypParser->yystack
            && yymx != YYERRORSYMBOL
            && (yyact = yy_find_reduce_action(
                        yypParser->yytos->stateno,
                        YYERRORSYMBOL)) >= YY_MIN_REDUCE
        ){
          yy_pop_parser_stack(yypParser);
        }
        if( yypParser->yytos < yypParser->yystack || yymajor==0 ){
          yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
          yy_parse_failed(yypParser);
#ifndef YYNOERRORRECOVERY
          yypParser->yyerrcnt = -1;
#endif
          yymajor = YYNOCODE;
        }else if( yymx!=YYERRORSYMBOL ){
          yy_shift(yypParser,yyact,YYERRORSYMBOL,yyminor);
        }
      }
      yypParser->yyerrcnt = 3;
      yyerrorhit = 1;
#elif defined(YYNOERRORRECOVERY)
      /* If the YYNOERRORRECOVERY macro is defined, then do not attempt to
      ** do any kind of error recovery.  Instead, simply invoke the syntax
      ** error routine and continue going as if nothing had happened.
      **
      ** Applications can set this macro (for example inside %include) if
      ** they intend to abandon the parse upon the first syntax error seen.
      */
      yy_syntax_error(yypParser,yymajor, yyminor);
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      yymajor = YYNOCODE;
      
#else  /* YYERRORSYMBOL is not defined */
      /* This is what we do if the grammar does not define ERROR:
      **
      **  * Report an error message, and throw away the input token.
      **
      **  * If the input token is $, then fail the parse.
      **
      ** As before, subsequent error messages are suppressed until
      ** three input tokens have been successfully shifted.
      */
      if( yypParser->yyerrcnt<=0 ){
        yy_syntax_error(yypParser,yymajor, yyminor);
      }
      yypParser->yyerrcnt = 3;
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      if( yyendofinput ){
        yy_parse_failed(yypParser);
#ifndef YYNOERRORRECOVERY
        yypParser->yyerrcnt = -1;
#endif
      }
      yymajor = YYNOCODE;
#endif
    }
  }while( yymajor!=YYNOCODE && yypParser->yytos>yypParser->yystack );
#ifndef NDEBUG
  if( yyTraceFILE ){
    yyStackEntry *i;
    char cDiv = '[';
    fprintf(yyTraceFILE,"%sReturn. Stack=",yyTracePrompt);
    for(i=&yypParser->yystack[1]; i<=yypParser->yytos; i++){
      fprintf(yyTraceFILE,"%c%s", cDiv, yyTokenName[i->major]);
      cDiv = ' ';
    }
    fprintf(yyTraceFILE,"]\n");
    fflush(yyTraceFILE);
  }
#endif
  return;
}
